# C 语言中的标记

> 原文：<https://learnetutorials.com/c-programming/c-tokens>

在本教程中，您将了解 C 语言中使用的六个标记，如关键字、标识符、常量、字符串、特殊字符和运算符及其示例。你已经在我们之前的教程中掌握了 C 程序的[基本语法，这将有助于你理解 C 程序的结构。](../c-programming/c-basic-syntax)

## C 语言中的标记

在编程领域，术语“标记”意味着程序的基本元素。在英语中，动词、副词、名词是一个句子的最小成分；类似地，计算机程序由不同类型的标记组成。下面是一个示例程序，它将帮助您理解标记的基本语法和属性。

```c
int main()
{
int a,b,c;
a=2,b=3;
c=a+b;
printf("\n Total= %d",c); 
getch();
} 

```

**输出:**

```c
Total= 5 
```

在上面提到的程序中，使用了以下标记- int、a、b、c、{、}、(、)、%、=、+、；。代币可以大致分为六类，我们将在下一节中了解它们:

## C 语言中的关键词

关键词是一组专门用于特定功能的词。在 C 语言中，有 char、int、do、while、sizeof 等 32 个关键字。

```c
int a,b,c; 

```

在上述例子中，“int”是表示整数值的关键字。该语句暗示 a、b、c 可以有整数值(即它们的值可以是 1、2、3 或-1、-2、-3，但永远不能像 0.1、0.2、-0.1、0.2 那样)。

另外重要的一点是这些**关键词不能在程序**内部用于其他目的。例如“int car，char”不是有效的语句；而“int jar，far”是一个有效的语句。这是因为“char”是一个函数的名称，它是一个保留的关键字，意味着一个特定的字符。

下面的列表显示了 c 中的关键字。这些单词严格保留用于特殊目的，不得用作常量或变量或任何其他标识符名称。c 是一种区分大小写的语言，它的所有关键字都是小写的。

| 汽车 | 其他 | 长的 | 转换 |
| 破裂 | 列举型别 | 注册 | typedef(类型定义) |
| 情况 | 走读生 | 返回 | 联合 |
| 茶 | 漂浮物 | 短的 | 无符号的 |
| 常量 | 为 | 签名 | 空的 |
| 继续 | 转到 | 西泽夫 | 不稳定的 |
| 系统默认值 | 如果 | 静电 | 正在… |

## C 语言中的标识符

在每个 C 程序中，都有一些定义程序元素特征的实体。变量、数组、函数都属于这一类。

```c
int a =2,b =3,c;
c=a+b;
printf("\n Total= %d",c); 
getch(); 

```

在上述程序中，a、b、c、printf、getch 是程序标识符。这里 a、b、c 是可变的，因为它们的值可以在任何时候赋值。如果在程序中的任何地方写了 a=2 之后写了任何像 a=5 这样的语句，编译器将只考虑最新的赋值，即 5。

### C 语言中标识符的命名规则

1.  有效的标识符必须以字母(大写或小写)或下划线(_)开头，后跟字母数字或下划线。
2.  标识符不能是 C 语言中的关键字
3.  标识符可以是任何长度

| 有效标识符 | 无效的标识符 |
| _ 年龄 | 17 岁 |
| 一，一 | int，float |
| 螺柱 _1、螺柱 _2 | 哈希# |

Num 和 NUM 作为两个不同的变量，因为 C 区分大小写。

## C 语言中的常量

顾名思义，常量代表一些固定值，这些值在程序的任何地方都不能更改。常量由关键字“**常量**声明。

```c
const pi = 3.14; 

```

如果你写一个语句‘const int Z = 10；’，以后永远不能将 Z 的值更改为 11 或 12。这对于用复杂的数学算法(例如π=3.1414)最小化程序中的错误非常有帮助

## C 语言中的字符串

字符串只不过是一个字符数组。在英语中，一组字母被称为单词。类似地，这里的一组字母、数字或符号称为字符串。在上述程序中， **Total** 是一个字符串。

```c
printf("\n Total= %d",c); 

```

## C 语言中的特殊字符

在 C 语言中，特殊字符意味着一组符号告诉编译器执行特定的任务。这里的' \n '表示下一行。在`printf()`部分，无论您在哪里键入它，编译器都会将光标放在下一行。

```c
printf("\n Total= %d",c); 

```

## C 语言中的运算符

我们知道计算机的中央处理器与算术逻辑单元一起工作。同样，C 编译器使用算术和逻辑运算符执行所有操作。

```c
c=a+b; 

```

C 语言中使用的算术运算符有+、-、/、*。在示例程序中显示了“+”的用法。C 的逻辑运算符有等。所有这些操作人员都与芯片组的逻辑门广泛合作，以产生所需的输出。

## C 语言中的分号

C 中的分号表示每个语句的**结尾，它与英语中句号结尾对称。如果在语句后留下空白，编译器将不会将其识别为语句的结尾。此外，在编程中。用作扩展名(stdio.h)。这就是为什么这里引入分号来标记语句结束。**

## C 语言中的空白

C 中的空白是指一系列的' **null** '字符，在程序运行时显示一个空白。空格、制表符、换行符和注释在 C 语言中常见于空格。

通常 printf(" ")会给出一个空格作为输出。如果我们想移到下一行，我们可以使用' \n '或' \n\n '(如示例程序所示)。我们也可以写“\t”将光标移动到下一个选项卡。

| 空白/特殊字符 | 意义 | 描述 |
| \n | 新行 | 将光标移动到下一行的开头。 |
| \t | 标签 | 将光标移动到下一个制表位。 |
| \b | 退格键 | 在当前行上将光标向后移动一个空格。 |
| \r | 回车 | 将光标移动到当前行的开头。 |
| \a | 铃声(警报) | 发出嘟嘟声。 |
| \\ | 反斜线符号 | 打印反斜杠(\)字符。 |
| \0 | 空 | 指示空字符。 |
| \' | 单引号 | 打印单引号(')字符。 |