# C 语言中的变量

> 原文：<https://learnetutorials.com/c-programming/variables>

在这个 C 教程中，你将学习所有关于变量的知识，变量是编程语言的基本单位。我们将借助例子详细讨论什么是 C 语言中的变量，如何命名、声明和初始化变量。除此之外，您还将浏览 C 语言中的左值和右值以及 C 语言中的变量类型

## C 语言中的变量是什么？

变量是计算机内存中可以存储数据的保留空间，您可以为每个存储位置指定一个特定的名称。在随机存取存储器中，每个字节的数据都以一个确定的地址顺序存储。它的值从“0”开始，并随着内存分配顺序的进行而继续增加。

## 如何用 C 语言命名变量？

虽然“C”提供了根据您的意愿和方便使用变量名的自由，但您必须遵守某些规则。

1.  变量名只能是字母(A，A，B，B)、数字(0，1，2)和下划线(_)的组合。
2.  变量名应该以字母开头，一些编译器也支持下划线。但不能以数字开头。
3.  由于 C 是一种区分大小写的语言，所以大写(num)和小写(NUM)字母被区别对待。
4.  根据 ANSI 标准，使用简短、简单和有意义(不超过 31 个字符)的变量名更安全。
5.  特殊字符(/，；命名变量时，不允许使用，:)和符号(#，@)。
6.  变量名必须不同于 C 关键字(printf，scanf)。
7.  不允许有空格。

| 有效变量名称 | 无效变量名称 |
| _ 年龄 | 17 岁 |
| 一，一 | 打印 |
| 螺柱 1、螺柱 2 | 螺柱#、螺柱 1、螺柱@2 |

## 如何声明变量？

在 C 程序设计中，所有将要在程序中使用的变量都必须首先声明。正是因为这两个原因

1.  编译器必须知道要为变量保留多少空间才能正常运行。分配的空间必须足够，并且不能过大，以免造成内存滥用。
2.  编译器必须识别数据，无论它是数字还是字母，这就是为什么必须声明“类型”。除此之外，为了便于操作，应该给它一个有意义的名称(称为标识符)。

变量声明语法涉及两个重要部分，如下所示，一个是**数据类型**，另一个是**变量名**。变量声明应该总是以**分号**结束，除非编译器会引发终止错误。另外，如果多个变量拥有相同的数据类型，C 可以自由地在一行中声明它们。

```c

datatype variable_name; 

```

基本上，有三种经常使用的数据类型声明。它们可以用这个例子来说明:

```c

int num, no; 
char a, b; 
float f1,f2; 

```

这里，' **int** '表示整数， **char** '表示单个字符， **float** '表示分数 number.int，char，float 是数据类型，num，no，a，b，f1，f2 是标识符(变量名)。当用特定数据类型声明变量时，它只能接受该特定数据类型的值。这里 **num** 只能取整数值，如果我们试图存储任何其他值，比如字符到 num，那么它会产生一个错误。

## 如何初始化一个变量？

声明完成后，您可以根据需要自由使用分配的空间(即变量)。这个声明的变量最初包含垃圾值，即未定义的值。如果您希望最初分配一些值，可以在赋值运算符“=”的帮助下完成。变量初始化可以在声明时执行。语法如下。

```c

datatype variable_name = value;

```

变量初始化的一些示例如下所示:

```c

int num = 10, no =20; 
char a = ‘A’, b = ‘B’; 
float f1 = 2.5 ,f2 = 5.2;

```

## C 语言中的左值和右值是什么？

**左值**实际上是指变量的地址位置。它通常出现在操作员的左侧(=，>)。所以你可以说一个标识符是一个可变的左值。

```c

#include <stdio.h>
main()
{
     int num1,num2,total;
     num1=4;
     num2=5;
     total=num1+num2;
     printf("Total number is %d",total);
} 

```

在本程序中 **num1、num2、total** 分别作为第 5、6、7 行的左值。

**值**通常是分配的值，即存储在分配地址中的数据。它可以是任何字符或数字，通常位于运算符的右侧。在上述程序中 **4，5** 分别为第 5 行和第 6 行的右值。

所以，最后，我们可以说左值意味着对象的身份，右值表示对象的价值。

## C 语言中变量的类型

作为一种静态语言，C 语言包含 5 种类型的变量。它们如下所示:

1.  局部变量
2.  全局变量
3.  静态变量
4.  自动变量
5.  外变量

### 局部变量

局部变量是在函数或代码块中定义的变量。变量的范围仅限于该函数或代码。因此，我们可以说这种类型的变量只有局部范围。

```c

void funct()
{
      int num = 5;   // Local Variable 
} 

```

### 全局变量

全局变量是在函数或代码块之外定义的变量。全局变量的作用域在整个程序中是有效的，它可以被任何函数或代码块使用。全局变量的值可以在函数内部修改。

```c

int g = 10;   // Global Variable
void funct()
{
      int num = 5;   // Local Variable 
} 

```

### 静态变量

如果变量以关键字 static 作为前缀，则称其为静态变量。静态变量在函数调用期间很有用，因为声明为静态的变量会保留每次函数调用的值。下面的代码片段将说明静态变量和局部变量的工作原理。

```c

#include <stdio.h>
int main()
{
void funct()
{
      static int a =10; // Static Variable
      int num = 5;     // Local Variable
      num = num + 1;
      a = a + 1;
      printf("a = %d\t and Num =%d\n",a,num);
}
  funct();
  funct();
  funct();

}

```

**输出:**

```c

a = 11   and Num =6
a = 12   and Num =6
a = 13   and Num =6 
```

### 自动变量

默认情况下，在 C 语言中，所有局部变量都是自动变量，因为当它们位于代码块内部时，它们会分配内存，当内存退出代码块时，它们会释放内存。使用关键字“auto”，我们可以显式地将变量声明为自动变量。

```c

void funct()
{
      int num1 = 5;   // implicitly automatic  Variable 
      auto int num2 = 10;   // Explicitly automatic variable
} 

```

### 外变量

前面加上关键字“extern”的变量称为外部变量，其作用域在 C 语言的源文件中有效。更具体地说，变量作用域不绑定到单个文件，而是其作用域可用于外部文件。外部变量也是全局变量。

### file.h

```c

extern int num1 = 10;  //external variable 

```

### program.h

```c

#include <file.h>
#include <stdio.h>
main()
{
       int num2,total;
       num2=5;
       total=num1+num2;
       printf("Total is %d",total);
} 

```

**输出:**

```c

Total is 15 
```