# C 语言中的字面值和常量

> 原文：<https://learnetutorials.com/c-programming/constants-literals>

在本教程中，您将学习 C 语言中的所有字面值和常量。借助简单的例子，您还会注意到字面值和常量之间的细微差别。

## C 语言中的字面值是什么？

在 C 语言编程中，常量和字面值表示在程序运行过程中不变的固定值。我们经常混淆识别常量和字面值，因为它们之间有一条细线。**字面值本身不过是一个常量值**。例如:

```c

int X = 10;
printf(“ Learn C through Learn eTutorials!”); 

```

这里的数字“10”和“通过学习学习 C”都是字面值。

## C 语言中不同类型的字面值

在 c 编程中，字面值大致分为四种类型:

1.  整数字面值
2.  浮点字面值
3.  字符字面值
4.  字符串字面值

### 整数字面值

C 语言中的整数字面值是仅代表整数类型值的数值。没有分数或指数值可以表示。整数字面值可以有三种类型:

| 整数字面值 | 例子 |
| 十进制字面值 | 10，3369，555u |
| 八进制字面值 | 036，099，024 升 |
| 十六进制字面值 | 0xdEbL，0x5Au |

当你观察上面的例子时，你可以看到下面的发现

*   没有前缀且以 10 为基数的字面值称为**十进制整数**。
*   前缀为“0”的字面值表示该数字是一个**八进制整数**。数字的基础值是 8。
*   前缀为“0x”的字面值表示一个**十六进制类型号**。该数字的基础值是 16。十六进制数包含数字和字母。

#### 附加了限定符的整数字面值:

**符号限定符(U 或 u)** :以字面值为后缀，表示值为无符号整数类型。
**大小限定符 L 或 l )** :以字面值为后缀，表示整数类型的长度。

另一个重要的特点是整数字面值中使用的所有字母都不区分大小写，即“X”和“X”或“E”和“E”都是相同的意思。

### 浮点字面值

浮点字面值表示包含分数或指数的字面值。这些字面值主要有两种类型——实数和复数。真实的包含以下部分:

一、整数部分
二。真实部分
三世。
分数部分 iv。指数部分

浮点字面值可以用两种形式表示:

| 浮点字面值形式 | 例子 |
| 十进制形式 | +10.50, -3.3, 6.19 |
| 指数形式 | +1.6e28，-2.4e12，3.4e-25 |

### 字符字面值

C 语言中的字符字面值是用单引号括起来的单个字符。

```c

char x ='a'; 

```

在这个例子中，单个字符“a”存储在变量(或地址)x 中，所以“a”只是一个字符字面值。

当我们试图将一个以上的字符存储到一个字符变量中时，编译器将生成一个警告，声明多字符字符常量，如下面的代码片段所示。

### 单字符字面值

```c

#include <stdio.h&rt;
int main()
{
 char v = 'v';
 printf("%c",v);
} 

```

**输出:**

```c

v 
```

### 具有多个字符的字符字面值

```c

#include <stdio.h&rt;
int main()
{
 char v = 'var';
 printf("%c",v);
} 

```

**输出:**

```c

r 
```

C 程序不仅依赖于简单的字符，还依赖于特殊的转义序列。例如，' \t '代表一个表空间，或' \n '代表将光标移动到下一行。

### 字符串字面值

在 C 语言中，当字母构成单词时，字符数组在 C 语言中被称为字符串。因此，字符串由字符、转义序列、符号和空格组成。

C 语言中的字符串字面值是用双引号括起来的字面值。例如，

```c

x = “Learn”;
y = “C programming”; 

```

在这个例子中，x 和 y 是存储字符串字面值“Learn”和“C 编程”的字符串变量。

注意:“C”为字符字面值分配空间，而“C”为字符串字面值分配空间

## C 语言中的常量是什么？

C 中的常量是定义后值不能改变的变量。在编程中，使用常量而不是字面值是一种很好的做法。

假设您正在为银行软件编写一个程序，其中最低余额为 1000 卢比。您可以定义一个常量，比如“min_bal”，并给它一个值 1000。所以以后上节目，就不用一次次回忆价值了。相反，您可以随时调用常量“min_bal”。此外，还有未来改变的机会。假设银行决定将最低余额提高到 2500 卢比，您不需要更改所有的整数文本。你要做的只是到声明常量的那一行，用“2500”替换值“1000”。这就是为什么程序员总是更喜欢常量而不是字面值。

## 如何在 C 语言中定义常量？

常量可以通过两种方式定义:

*   使用#define 预处理器
*   使用关键字 const。

### 使用#定义预处理器:

#define 的工作方式类似于一个函数，它声明了一个常量名称，并在不使用“=”的情况下立即赋值。

语法是:

```c

#define constant_name constant_value 

```

```c

// Example
#define pi 3.14 

```

以下示例将说明如何使用#define 预处理器来分配一个常量值

```c

#include <stdio.h>
#define a 5
#define b 6
#define jump '\n'
main()
{
       int c;
       c=a+b;
       printf("The sum is %c %d",jump,c);
       getch();
}

```

**输出:**

```c

The sum is 
11 
```

### 使用关键字 const:

“const”是一个简单的关键字，通过它可以使用以下语法声明一个常量:

```c

 const  data_type  c 

```

```c

// Example
const float pi = 3.14; 

```

所以不像预处理器这里我们要放分号(；)作为“const”声明被认为是一个语句，赋值运算符“=”用于给常量赋值。上面的程序可以这样写:

```c

#include <stdio.h&rt;
const int a = 5;
const int b = 6;
const char jump= '\n';

main()
{
       int c;
       c=a+b;
       printf("The sum is %c %d",jump,c);
       getch();
}

```

**输出:**

```c

The sum is 
11 
```