# C 语言中的存储类

> 原文：<https://learnetutorials.com/c-programming/storage-classes>

在本教程中，您将学习关于 C 语言中存储类的一切，以及存储类的不同分类，如 auto、register、static 和 extern，并用一些简单的例子进行解释。

## C 语言中的存储类是什么？

C 语言中的存储类描述了存储变量或函数的地址的属性。这意味着存储类用于确定变量的位置、范围或生存期以及初始化值。内存、中央处理器寄存器是这些值通常保存的位置，用于程序的未来范围和可见性。在 C 编程语言中，存储类可以通过将变量分类为“全局”或“局部”来确定变量的生存期。它们基本上有四个存储类别:

1.  汽车
2.  注册
3.  静电
4.  xtern

还有与每个类相关的存储类说明符。任何存储类的工作都是告诉或命令编译器- ' **如何存储特定的变量或函数**。说明符的声明语法如下:

```c
 storage_class_specifier variable_type variable name; 

```

在一个声明语句中只能声明一个存储类说明符。
在没有存储类说明符的情况下，内存分配按以下规则进行:

1.  在函数中声明的变量被认为是“自动的”。
2.  在函数内部声明的函数被认为是“extern”。
3.  在函数外部声明的变量和函数被归类为具有“外部链接”的“静态”。

带有外部链接的“静态”文件范围变量只能在后续文件中使用。而具有“外部链接”的文件对程序中的所有文件都是免费的。局部变量是其中之一，因为它们没有任何类型的联系。所以它们只能在声明它们的代码块中使用。

## C 语言自动存储类

用“auto”说明符声明的变量在自动存储类中有一席之地。默认情况下，没有任何说明符的所有类型或变量都被认为是这种类型。自动变量的范围和可见性受限于定义它的函数。所以当退出功能块时，分配给自动变量的内存被释放。由此，我们可以推断自动变量的内存分配是动态完成的。在考虑初始化部分时，默认情况下，c 中的自动变量被初始化并赋给一个垃圾值。

考虑以下程序:

```c
 #include <stdio.h>

main() {
  auto int a = 1; {
    auto int a = 2; {
      auto int a = 3;
      printf("\n%d ", a);
    }
    printf("%d ", a);
  }
  printf("%d", a);
} 

```

**输出为‘3 2 1’。**

在这个程序中，一个整数变量用相同的名字定义了三次' **a** '，但是编译器没有显示错误。这是因为“ **a=3** 的存在只保留在第三个街区内。一旦执行完成并且块的第二层(其中 a=2)取得控制权，变量“a”或“a=3”的名称就不再存在。现在“a”是一个全新的标识符，您可以自由指定任何您想要的值。因此，循环继续，并使用相同的变量“a”打印“3 2 1”。

## C 语言中的寄存器存储类

寄存器存储类属于自动存储类的类型，因为这里声明的存储类也只对声明的块起作用。区别在于访问速度。我们知道，计算机内存或随机存取存储器的工作速度比寄存器慢一点，寄存器的存储容量很小。因此，将存储类声明为‘register’会告诉编译器将其存储在 CPU 寄存器中，它们在未来将被频繁访问。但缺点是这个存储类中只能存储几个选定的变量，并且不能访问确切的地址位置(使用' & ')。另一个**限制**是不能分配初始值，但是使用这个存储类可以显著减少编译时间。

## C 语言中的静态存储类

C 中的静态存储类用于声明静态变量，这些变量被分配到一个初始值**零**。静态变量的关键字说明符是**静态**。虽然这些变量不能在已经定义的函数之外使用，但最重要的特性是，即使块的执行完成，它也不会丢失它的值，而是保持它，直到主函数运行。

```c
#include <stdio.h>

int show() {
  int a = 10;
  static int s = 10;
  printf("a=%d\t s=%d\n", a, s);
  a = a + 1;
  s = s + 1;
}

main() {
  show();
  show();
  show();
} 

```

**输出:**

```c
a=10   s=10
a=10   s=11
a=10   s=12 
```

因此，每次在执行“`show()`”静态变量的值时，都会根据每个周期的最后一个赋值来打印该值，而不是初始值。而自动存储类将每次“a”定义为 10，并相应地打印出来。

## C 语言的外部存储类

属于外部存储类的任何变量都可以在一个块中定义，并同时在另一个块或段中使用。外部说明符向编译器指示存在外部链接。因此，它就像一个具有初始赋值的全局变量一样工作。它能够在一个大程序中处理两个不同的文件。它由关键字' extern '定义，如
extern int x；
extern `show()`；