# C 语言中的动态内存分配

> 原文：<https://learnetutorials.com/c-programming/dynamic-memory-allocation>

在本教程中，您将学习如何有效地管理内存。您将介绍 C 语言中内存分配的类型，以及 C 语言中动态内存分配的意义，以及动态分配内存的不同方式，如使用`malloc`、 `calloc`、`realloc` 和`free`。

内存管理是 C 编程的一个重要方面。在编写程序时，我们必须确保分配的内存足以存储相关变量，并且空间不会被垃圾字节获取。基本上，C 编程语言以 3 种不同的方式管理内存。他们是

*   静态内存分配
*   自动内存分配
*   动态存储分配

到目前为止，我们已经了解了如何在静态模式下为变量分配内存空间，这将导致空间的误用。假设我们想要存储一个名称，我们声明了一个由 100 个字符组成的字符串来存储它。如果我们存储“蒂姆·库克”这个名字，只使用 8 个字符。如果有办法根据用户输入的数据来分配空间，那就太好了。幸运的是，C 语言确实支持这种类型的空间管理，通常称为“动态内存分配”。"

动态存储分配

动态内存分配是一种手动管理内存的方法，在运行程序时，我们可以随时分配或释放内存。每当调用这些函数时，它们都会从堆(内存区域)中获取内存，并在不需要时释放内存，以便可以重用。主要有两个功能，动态执行内存分配:`calloc` 和`malloc`。
下面是对他们的简短介绍。

## C `malloc()`

术语“malloc”代表“内存分配”。C 语言中的 Malloc 用于在运行时分配指定字节数的内存。

**语法:**

`malloc()`函数的原型如下:

```c
 ptr = (int*) malloc(10 * sizeof(int)); 

```

现在一切都取决于整数的性质。如果整数包含两个字节，分配的空间将是 20 个字节。如果整数的大小为 4 字节，将保留 40 字节的空间。现在我们将尝试用一个相关的例子来把握这个概念。请注意，我们包含了一个库文件`stdlib.h`，因为这些函数是在这个特定的头文件中定义的。

**示例:**

```c
 #include <string.h>
#include <stdlib.h>

main()
{
 char name[50];
 char *define;
 strcpy(name, "Thomas Edison ");
 define = malloc(50* sizeof(char));

 if (define == NULL)
 {
  fprintf(stderr, "Error - Memory allocation failed. \n");
 }
 else
 {
  strcpy(define, " Thomas Edison invented incandescent lights.");
 }

 printf("Name is %s\n", name);
 printf("Invention : %s\n", define);
} 

```

**输出:**

```c
Name : Thomas Edison
Invention :  Thomas Edison invented incandescent lights. 
```

因此，程序给予程序对内存分配的完全控制。他可以根据情况的需要将值‘50’改为 20 或 100。在这个例子中，我们包含了一个字符串头文件来操作字符串操作，您将在后面的教程中详细学习。

## C `calloc()`

C 语言支持的另一个动态分配内存的库函数是`calloc()`函数，它被认为比`malloc`更好。功能“**胼胝体**”是指“连续分配”或相邻细胞的连续分配。

**语法:**

这个函数的原型声明是:

```c
 pointer = (data_type*) calloc( memory_units, size_of_element); 

```

这里`calloc()`接受两个参数:

*   存储单元表示元素的数量
*   元素的大小表示元素的大小

假设我们想为 10 个单位的浮点数分配空间。我们知道浮点变量占用 4 字节的空间，因此 10 个单位的空间意味着 40 个存储元素。因此，它的内存分配如下所示:

```c
 pntr = (float*) calloc(10, sizeof(float)); 

```

**示例:**

```c
 #include <stdio.h>

int main()
{
 int n;
 int *p;
 int i;

 printf("Enter the number of elements in array :\n");
 scanf("%d", &n);

 p = (int*) calloc(n, sizeof(int));
 printf("\nEnter the elements in array :\n");
 if (p == NULL)
 {
  printf("\n Error : Memory allocation failed");
  exit(1);
 }
 else
 {
  for (i = 0; i < n; i++)
  {
   scanf("%d", p + i);
  }

  printf("The array is :\n");
  for (i = 0; i < n; i++)
  {
   printf("%d\t", *(p + i));
  }
 }

 printf("\n\nThe array in reversed order is:\n");
 for (i = n - 1; i >= 0; i--)
 {
  printf("%d\t", *(p + i));
 }

 return 0;
} 

```

**输出:**

```c
 Enter the number of elements in array :
4

Enter the elements in the array :
2
5
6
9
The array is :
2       5       6       9

The array in reversed order is:
9       6       5       2 
```

## malloc 和胼胝体功能的主要区别

a `calloc`和`malloc`的关键区别在于前者分配一些相同大小的多个内存块。而后者分配单个内存块。Calloc 函数总是将分配的内存位初始化为零，而 malloc 函数不会，因此包含垃圾值。Calloc 函数接受两个参数，而 malloc 只需要一个参数来分配内存。

### 调整大小和释放内存

当程序执行完成时，可能会出现两种情况。一是您可能不再需要分配的空间，二是我们必须重新定义大小(即增加或减少)。为了在运行时服务于这些目的，在 C 语言中有两个独立的函数，分别是自由和重新分配。

## C `realloc()`

顾名思义，它为数据存储重新分配了空间。换句话说，`reallocate()`函数支持在不丢失旧数据的情况下修改先前分配的内存大小的功能。

**语法:**

`realloc()`功能的原型是:

```c
 pointer_name = realloc(pointer_name, new_size) 

```

与`calloc()`类似，`realloc()`也有两个参数，一个参数给出了之前使用`malloc()`或`calloc()`分配的内存的第一个字节，第二个参数指定了新的大小(比原始大小大或小)。考虑以下场景

```c
 pntr = (float*) calloc(10, sizeof(float)); 

```

假设我们想将分配的内存增加 5 个浮点，我们要做的是为额外的 5 个浮点单位重新分配空间。我们知道 float 变量占据了 4 个字节的空间，因此 10 个单元和另外 5 个单元意味着(15*4 =60)个存储单元。因此，它的内存重新分配如下所示:

```c
 pntr = (float*) realloc(pntr, 15*sizeof(float)); 

```

**例**:

下面是一个演示`realloc()`工作的例子:

```c
#include <stdio.h>
#include <stdlib.h>
 main()
{
    int *p,s,ns,i;
    printf("Enter the size of the array :");
    scanf("%d", &s);

    p = (int*) malloc(s * sizeof(int));
    for(i= 0; i < s; ++i)
    {
      printf("\nAddress of each element in array at index %d ==> %u ",i,p+i);
    }

    printf("\n\nEnter new size of the data: ");
    scanf("%d", &ns);
    p = realloc(p, ns);
    for(i = 0; i < ns; ++i)
           printf("\nAddress of each element in array at index %d ==> %u ",i,p+i);
} 

```

**输出:**

```c
Enter the size of the array :6

Address of each element in array at index 0 ==> 1731824
Address of each element in array at index 1 ==> 1731828
Address of each element in array at index 2 ==> 1731832
Address of each element in array at index 3 ==> 1731836
Address of each element in array at index 4 ==> 1731840
Address of each element in array at index 5 ==> 1731844

Enter the new size of the data: 2

Address of each element in array at index 0 ==> 1731824
Address of each element in array at index 1 ==> 1731828 
```

## C `免费()`

这个函数的任务是释放分配的内存。实际上，由`calloc`或`malloc`等函数分配的内存在程序执行后并不会自动空闲。为了显式地释放空间，我们只需要调用`free()`函数，用适当的指针保存要释放的地址作为参数。

**语法:**

该函数的原型是

```c
 free (pointer); 

```

示例演示`free()`:

```c
 #include <stdio.h>
#include <stdlib.h>

int main()

{
 int *ptr;
 //creating memory allocation dynamically

 ptr = (int*) malloc(sizeof(int));
 printf("\n Memory allocated...");
 *ptr = 100; //assigning value  printf("\n ptr c *(ptr));
 free(ptr);
 printf("\n Memory is deallocated...\n ");  printf("ptr c *(ptr));
 return 0;

} 

```

**输出:**

```c
 Memory allocated... ptr c

Memory is deallocated... ptr c 
```

在本例中，首先使用`malloc()`函数动态分配内存，并为其分配一个整数值。稍后我们已经使用`free()`功能释放了内存。

## 动态内存分配的优缺点

使用动态分配的主要优点是避免了内存的浪费。动态内存分配使用户可以根据需要灵活地更改内存大小，如果用户事先不知道内存大小的话。

动态分配带来的唯一限制是显式解除分配。这意味着用户必须花费额外的精力来管理内存，在不再需要时释放空间，否则可能会导致内存泄漏。