# C 语言中的枚举

> 原文：<https://learnetutorials.com/c-programming/enumeration>

在本教程中，您将学习关于另一种类型的用户定义数据类型的一切——C 语言中的枚举数据类型。借助简单的示例，您将了解 C 语言中枚举的必要性及其基本事实。

## C 语言中什么是枚举数据类型？

让我们从理解“枚举”这个词的字面意思开始。**列举**是指将一个事物的清单一一提及的过程。在编程世界中，枚举数据类型只是由一组命名值组成的用户定义数据类型。这些命名值被称为**枚举**。关键字“enum”定义了枚举数据类型，就像 struct 和 union 一样。

语法:

定义的原型是:

```c
 enum flag { int_const1,int_const2, . . . . . , int_const n }; 

```

这里我们定义了一个名为`flag`的枚举，它有`n`个整数常量。这些整数常量默认情况下，编译器给`int_const1`设置的值是 0，`int_const2`是 1，依此类推。

让我们举个例子

```c
 enum Status{unmarried, married ,divorced}; 

```

## 如何声明枚举数据类型？

就像我们对其他用户数据类型所做的那样，我们也可以用两种不同的格式为这个用户定义的数据类型 enum 创建一个变量。

1.  ### 在枚举器定义期间

    ```c
     enum flag { int_const1,int_const2, . . . . . , int_const n } Var; 

    ```

    例子

    ```c
     enum Status{unmarried, married ,divorced} S; 

    ```

2.  ### 在`main()`函数中使用关键字 enum

    声明枚举数的另一种方法是使用 enum 关键字在主函数中声明枚举数，就像我们声明结构和联合一样。原型是:

    ```c
     enum flag Var;  // inside main function 

    ```

    下面是演示枚举声明的示例。

    ```c
     enum Status{unmarried, married ,divorced};

    int main()

    {
      enum Status S;
    } 

    ```

在这两种情况下，`S`是我们为枚举`Status`声明的变量。这意味着变量`S`可以包含这些值`unmarried`或`married`或`divorced`中的任何一个。

## ENUM 的自动赋值

关于 enum 的一个有趣的事实是它对其枚举的自动赋值。更清楚的是，编译器将自动按照 0，1.2，...当没有给元素显式赋值时。

```c
 #include<stdio.h>

enum Status{unmarried, married ,divorced};

int main()

{
  enum Status S;
  S = married;
  printf("INTEGRAL CONSTANT OF MARRIED :%d",S);

  return 0;
} 

```

**输出:**

```c
 INTEGRAL CONSTANT OF MARRIED :1 
```

所以在我们的例子中，未婚被赋值 0，已婚被赋值 1，离婚被赋值 2。因此输出 1。

## 如何初始化枚举数据类型？

但是，如果需要，用户可以更改默认值，并可以在声明时为枚举元素设置新值。枚举类型的初始化如下:

```c
 enum Status{unmarried = 3, married= 6 ,divorced = 5}; 

```

### 示例:如何初始化枚举数据类型？

```c
 #include<stdio.h>

enum Status{unmarried =3, married=6 ,divorced=5};

int main()

{
  enum Status S;
  S = married;
  printf("INTEGRAL CONSTANT OF DIVORCED :%d",S);

  return 0;
} 

```

**输出:**

```c
 INTEGRAL CONSTANT OF DIVORCED :5 
```

在这个例子中，我们为枚举元素显式赋值，因此它输出相应的值。

让我们深入了解一些关于枚举元素初始化的有趣事实。

### 1.相同的值可以初始化为多个元素

在上面的示例中，我们为每个元素分配了不同的值，因此出现了一个问题:是否有可能为多个枚举元素分配相同的值。通过阅读下面给出的程序，你会得到这个问题的答案。

```c
 #include<stdio.h>

enum Signal{Green = 1, Orange = 0, Red = 0};

int main()

{
  enum Signal S;
  printf("%d %d %d",Green, Orange, Red);

  return 0;
} 

```

**输出:**

```c
 1 0 0 
```

在上面的代码中，橙色和红色都被赋值为“0”。所以我们可以得出结论，在 C 语言中，多个枚举名称可以有相同的值。

### 2.价值分配的顺序并不重要

在枚举数据类型中，赋值的顺序不是一个大问题。Enum 在赋值方面提供了更好的灵活性，因此用户可以给某些元素赋值，而让其他元素保持未赋值状态。未分配的元素取前一个元素的值加 1。

下面是一个例子:

```c
 #include<stdio.h>

enum Rainbow{Violet= 22, Indigo , Blue = 2,Green = 7, Yellow,Orange,Red =18 };

int main()

{
  enum Rainbow R;
  printf("Violet = %d \nIndigo = %d \nBlue=%d\nGreen = %d\nYellow= %d\nOrange= %d\nRed = %d",Violet , Indigo, Blue,Green,Yellow, Orange, Red);

  return 0;
} 

```

**输出:**

```c
 Violet = 22
Indigo = 23
Blue=2
Green = 7
Yellow= 8
Orange= 9
Red = 18 
```

在上面的例子中，indigo、Yellow 和 Orange 是未赋值的值，它们遵循它们之前元素的值。靛蓝跟随紫罗兰色的值，所以它被自动赋值为 23(22+1)。类似地，黄色和橙色跟随绿色的值 7，因此分别设置值 8 和 9。

### 3.赋值必须是一个整数常量

到目前为止，我们已经在所有示例中看到，分配给枚举元素的值都是积分常量，并且它们工作得很好。如果我们指定一个不是积分常量的值。

```c
 #include<stdio.h>

enum Rainbow{Violet= 22.55, Indigo , Blue = 2,Green = 7, Yellow,Orange,Red =18 };

int main()

{
  enum Rainbow R;
  printf("Violet = %d \nIndigo = %d \nBlue=%d\nGreen = %d\nYellow= %d\nOrange= %d\nRed = %d",Violet , Indigo, Blue,Green,Yellow, Orange, Red);

  return 0;
} 

```

**输出:**

```c
error: enumerator value for 'Violet' is not an integer constant| 
```

我们稍微改变了前面的例子，为枚举值提供了一个非整数值。这里，Violet 被赋值为‘22.55’，这是一个非整数值，因此如上所述，输出是一个错误。

因此，从这个结果中，我们可以得出这样的结论:枚举数据类型是类型受限的，并且将只采用整数常量作为其元素，并且取值范围必须尽可能在最小整数值和最大整数值之间。

## 枚举和范围规则

枚举器遵循作用域规则，即每个枚举器必须是不同的。每个枚举数中的枚举常量必须是唯一的，如果两个不同的枚举数具有相同的枚举常量，那么程序将会出错。

下面是一个例子:

```c
 #include<stdio.h>

enum color{Green, Yellow,Blue };
enum signal{Green,Orange ,Red};

int main()

{
  enum color C;
  enum signal S;

} 

```

**输出:**

```c
 error: redeclaration of enumerator 'Green'| 
```

## 枚举 VS #DEFINE

| **ENUM** | **#定义** |
| 

### Syntax

```c
 enum Signal { Green , Orange, Red}; 

```

 | 

### Syntax

```c
 #define Green 0
#define Orange 1
#define Red 2 

```

 |
| 枚举是一种用户定义的数据类型，它为整数常量赋值 | #define 是一个宏预处理器指令，它用一个值替换一个标记。 |
| 枚举由编译器执行 | #define 由预处理器执行，编译器不可见 |
| 枚举是类型受限的，即枚举的类型总是带符号的整数。 | #define is 可以是任何类型。 |
| 枚举遵循范围规则 | #定义不遵循范围规则 |
| 枚举提供自动赋值。 | #define 提供明确的赋值。 |