# C 语言中的头文件

> 原文：<https://learnetutorials.com/c-programming/header-files>

在本教程中，我们将学习 C 语言中的头文件。主要集中在-为什么我们在每个程序中使用头文件，然后讨论头文件的工作和 C 语言中不同类型的头文件。

## C 语言中的头文件是什么？

你一定注意到了，所有的 C 程序都是以文件`stdio.h`开始的。这些类型的文件扩展名为“**”。h** 被称为头文件。头文件通常包括所有类型的常用函数、变量和常量的定义。除了这些头文件之外，还包含要在文件之间共享的宏定义。使用 **#include** 指令在程序中声明它意味着程序可以在任何需要的时候访问所提到的头文件的所有内容。

例如 **stdio.h** 就是一个头文件，其中 **stdio** 代表标准输入输出，**。h** 是头文件扩展名这个头文件基本上是取用户从键盘给定的输入，借助一些预定义的功能如`printf()`、`scanf()`、`getc()`、 `putc()`、 `gets()`、`puts()`等在显示器上显示输出。在上一个教程中，我们已经看到了像`fprintf()`、`fscanf()`、`fgetc()`、 `fputc()`、`fgets()`、`fputs()`等文件输入输出功能的使用。由于所有这些功能都封装在 **stdio.h** 中，因此有必要将 **stdio.h** 包含在程序中以实现特定任务。

## 为什么需要头文件？

不可能编写每一段基本代码，并在我们编写的每个程序中编译它们。此外，几乎在每个程序中都需要一些常见的功能。所以习惯上把所有需要的代码写在一个单独的文件中，并随时准备使用。

例如，出于访问和显示的目的，我们经常需要`scanf`和`printf`功能。显然，应该有一堆代码负责它们的正常运行。这些原始源代码写在头文件“ **stdio.h** ”中，这就是为什么我们几乎每个程序都要写“#include < stdio.h >”的原因。

## 头文件的语法

我们现在非常熟悉`#include`语法和预处理器指令的功能。实际上，头文件有两种类型:

1.  预定义的库文件
2.  用户定义的头文件。

顾名思义，预定义库文件是已经在系统中定义的文件，如 **stdio.h** 、 **math.h、**等。预定义的头文件用尖括号括起来，语法如下

```c
 #include <file_name.h> 

```

用户定义的头文件包含用户定义的文件，通常用双引号括起来，语法如下:

```c
 #include "file_name"  
OR
#include "file_name.h" 

```

在这里，编译器将在当前目录中查找提到的文件并导入它。

## 如何在 C 语言中创建并包含用户定义的头文件？

#include 指令的操作特点是只扫描写在头文件中的内容，并将其嵌入程序中。它还与维护程序中定义的序列一起工作。假设我们想要创建一个名为“ **sum.h** ”的头文件，其中包含前 n 个自然数的求和代码。为了实现这一点，我们首先需要在编辑器中编写我们想要的代码，并用**保存它。h** 扩展名因为这里我们创建的是一个头文件。头文件的名称将是带有。扩展，在我们的例子中是 sum.h。

### 总和

```c
 int sum(int num)
{
  int iter,num =0;
  for(iter = 1; iter <= num; iter++)
  {
    sum = sum + iter;
  }
  return sum;
} 

```

这里我们使用了记事本编辑器，并在其中编写了我们的代码，并将其保存为 sum.h。现在，我们可以使用如下所示的#include 指令将该文件导入到我们的程序中。

```c
 #include <stdio.h>#include "sum.h"

int main()
{
    int number;
    printf("Enter the number:");
    scanf("%d",&number);
    printf("\nSum of first %d numbers is : %d ",number,sum(number));
    return 0;

}</stdio.h> 

```

代码执行将按顺序执行，输出将是

```c
 Enter the number: 200

Sum of first 200 numbers is : 20100 
```

这样我们就可以增强代码的功能和可读性，而不是创建一个庞大而复杂的程序。

注意:头文件和程序应该存储在同一个位置。

## C 语言中的一次性标题

这是一个我们可以克服重复错误的过程。如果我们在一个程序中包含相同的头文件两次，编译器将运行相同的代码两次。这肯定会导致编译错误。在大型程序中，检查头文件是否已经包含变得非常困难。因此，如果有一种机制来保护程序免受这些错误的影响，那就太好了。这种机制是在条件预处理器指令的帮助下实现的，如`#ifndef`、`#define`和`#endif`。这些是常用的带条件的代码集，经常用来完成它，语法如下。

```c
 #ifndef HEADER_FILE_NAME
#define HEADER_FILE_NAME
   Header file content
#endif 

```

示例:

```c
 #ifndef "test.h"
#define "test.h"
THE CONTENT OF THE HEADER FILE 
#endif 

```

所以这里`test. h`是头文件，首先检查程序中是否已经存在`test.h`的定义。如果是，编译器将退出“If”循环，并将控制直接转移到结束端。如果答案是否定的，那么`test.h`将被定义，然后到结束端。这整个机制在 C 编程中通常被称为 **#ifndef 包装器**，因为它通过将代码放在 **#ifndef** 和 **#endif** 之间来确保代码只读一次。

## C 语言中的宏

到目前为止，我们已经学会了如何包含头文件，但没有任何条件。但有时情况要求根据情况或程序要求包含多个文件。在这些中，我们可能会用#include 指令强加一系列条件，例如:

毫无疑问，编写一系列复杂的代码将是一项麻烦的工作，尤其是当有许多条件需要应用时。C 编程的预处理器指令能够在每个头文件中使用一个宏，并利用这些特性使程序更加紧凑。在#include 后面放一个宏名，而不是参数，会容易得多。这个有条件包含头文件的过程称为“**计算包含**”。

下面是一个演示使用宏的简单例子。
定义文件 1“file _ 1 . h”
#包含文件 1
.....
这里 FILE1 是头文件“file_1.h”的宏名。因此，宏简化了头文件的包含。

## C 语言头文件的类型

最初，我们已经看到头文件分为两种类型，即。标准头文件和用户定义的头文件。基于几个功能，这些标准头文件被进一步分类，一些常用头文件在下表中列出。

| **Sl 号** | **头文件** | **描述** | **功能 ex。** |
| one | stdio.h | 标准输入输出标题 | `printf()`、`scanf()`、`scanf()`、`scanf()` |
| Two | 字符串. h | 字符串标题 | strlen（），strcpy（），strcat（），strcmp（） |
| three | 科尼厄斯 | 控制台输入输出标题 | `clrscr()`、`getch()`函数 |
| four | stdlib.h .标准版 | 标准库标题 | `calloc()`、`malloc()`、`malloc()`、`malloc()` |
| five | 数学 h | 数学标题 | [sqrt()](../../c-programming/library-functions/sqrt)[pow()](../../c-programming/library-functions/pow)[exp()](../../c-programming/library-functions/exp)[floor()](../../c-programming/library-functions/floor) |
| six | 类型 h . h | 字符类型标题 | [isalpha()](../../c-programming/library-functions/isalpha) 、[【isdigt()](../../c-programming/library-functions/isdigit)、[【isper()](../../c-programming/library-functions/isupper)、[【islapower()](../../c-programming/library-functions/islower) |
| seven | assert.h | 断言头 | [assert()](../../c-programming/library-functions/assert) |
| eight | time.h | 时间标题 | `getdate()`，`setdate()`，`setdate()`，`setdate()` |
| nine | 本地. h | 本地化标题 | [7 local()](../../c-programming/library-functions/setlocale)、 [localeconv()](../../c-programming/library-functions/localeconv) |
| Ten | 信号. h | 信号标题 | [信号()](../../c-programming/library-functions/signal)，[上升()](../../c-programming/library-functions/raise) |
| Eleven | 标准 arg.h | 标准参数标题 | va_start（），va_arg（） |
| Twelve | setjmp.h | 跳转标题 | [setjmp()](../../c-programming/library-functions/longjmp)long jmp() |
| Thirteen | errno.h | 错误处理标题 | errno() |