# C 程序：计算二次方程根

> 原文：<https://learnetutorials.com/c-programming/programs/quadratic-equation-roots>

为了更好地理解这个 C 程序示例，我们始终建议您学习下面列出的 [C 编程](../ "C programming")的基本主题:

*   [C 程序操作员](../../c-programming/operators "C program tokens")
*   [C 编程决策](../../c-programming/decision-making-statements "C programming decision making")
*   [C 数据类型](../../c-programming/data-types-modifiers "C data types")

## 什么是二次方程？

在代数中，二次方程是一个可以以 **'ax^2+bx+c=0** 的形式重新排列的方程，其中**‘x’**代表未知量，**‘a’**、**‘b’**、**‘c’**是不等于 **0** 的数。如果' **a = 0** '，那么它就不是二次方程，它叫线性方程。数字**‘a’**、**‘b’**、**‘c’**是方程的系数，**‘x’**是方程中需要找出的未知值。在这个 C 程序中，我们需要求解二次方程并求其根。

## 如何求二次方程的根

寻找非零系数二次方程的所有根的 C 程序是一个有点冗长的程序，但是如果你知道程序背后的逻辑，它是非常简单的。我们使用公式**“圆盘= b*b - 4.0*a*c** 找到**圆盘**后，我们可以根据圆盘的值是大于还是小于零来检查根是实的还是虚的。

**注:**查二次方程，如果' **a=0** '那么就不是二次方程。现在检查**‘A’**或**‘B’**或**‘C’**是否为零。如果是这样，我们就无法确定根源。否则应用公式**“b * B- 4 * a * c”**。最后，检查结果大于或小于零或零本身。

*   如果圆盘小于零，那么可以使用公式**“B/(2.0 * A)”**找出真正的根。虚根由“ **sqrt(abs(disc))/(2.0*A)** 找出。
*   如果圆盘为零，那么根是相同的，这可以通过“ **-B/(2.0*A)** ”找到。
*   如果圆盘大于零，那么根将是 **(-B+sqrt(圆盘))/(2.0*A)** 和 **(-B-sqrt(圆盘))/(2.0*A)** 。

## 算法

**STEP 1:** 将需要的头库导入 C 程序，使用需要的内置函数。

**第二步:**使用`printf`和`scanf`内置功能接受 **A** 和 **B** 和 **C** 的值。

**步骤 3:** 检查 **A** 的值是否不等于零。如果是这样，那就不是二次方程了。

**步骤 4:** 使用“`else`”检查“**圆盘**的值，使用公式“ **B*B - 4.0*A*C** ”。

**STEP 5:** 如果**圆盘**小于零，那么它将是虚根。

**STEP 6:** 用公式找出实根和虚根，用`printf`打印根。

**STEP 7:** 使用“`else if`”语句检查圆盘是否等于零，然后根将相等且真实。

**步骤 8:** 使用公式计算根，并使用打印语句打印根。

**步骤 9:** 使用“`else if`”检查阀瓣是否大于零。如果是这样，把根印得真实而清晰。

**STEP 10:** 使用特定公式计算两个根，并使用 C 编程中的`printf`内置函数打印结果。

## c 源代码

```c
#include <stdio.h>
#include <stdlib.h>
#include <math.h>

void main() {
  float A, B, C, root1, root2;
  float realp, imagp, disc;
  printf("Enter the values of A, B and C\n");
  scanf("%f %f %f", & A, & B, & C); /* If A = 0, it is not a quadratic equation */
  if (A == 0 || B == 0 || C == 0) {
    printf("Error: Roots cannot be determined\n");
    exit(1);
  } else {
    disc = B * B - 4.0 * A * C;
    if (disc < 0) {
      printf("Imaginary Roots\n");
      realp = -B / (2.0 * A);
      imagp = sqrt(abs(disc)) / (2.0 * A);
      printf("Root1 = %f  +i %f\n", realp, imagp);
      printf("Root2 = %f  -i %f\n", realp, imagp);
    } else if (disc == 0) {
      printf("Roots are real and equal\n");
      root1 = -B / (2.0 * A);
      root2 = root1;
      printf("Root1 = %f  \n", root1);
      printf("Root2 = %f  \n", root2);
    } else if (disc > 0) {
      printf("Roots are real and distinct\n");
      root1 = (-B + sqrt(disc)) / (2.0 * A);
      root2 = (-B - sqrt(disc)) / (2.0 * A);
      printf("Root1 = %f  \n", root1);
      printf("Root2 = %f  \n", root2);
    }
  }
}

```

## 输出

```c
RUN 1

 Enter the values of A, B and C
 3 2 1
 Imaginary Roots
 Root1 = -0.333333  +i 0.471405
 Root2 = -0.333333  -i 0.471405

 RUN 2

 Enter the values of A, B and C
 1 2 1
 Roots are real and equal
 Root1 = -1.000000
 Root2 = -1.000000

 RUN 3

 Enter the values of A, B and C
 3 5 2
 Roots are real and distinct
 Root1 = -0.666667
 Root2 = -1.000000
```