# C 程序：使用欧几里德算法求 GCD 和 LCM 

> 原文：<https://learnetutorials.com/c-programming/programs/find-gcd-lcm-euclid>

为了更好地理解这个 C 程序示例，我们始终建议您学习下面列出的 [C 编程](../ "C programming")的基本主题:

*   [C 程序操作员](../../c-programming/operators "C program tokens")
*   [C 编程决策](../../c-programming/decision-making-statements "C programming decision making")
*   [循环](../../c-programming/loops "loops in C")

## 什么是 GCD 或 HCF？

这是一个寻找两个数的 **GCD** 的 C 程序。**两个数字的 GCD** 表示将两个数字相除的最大数字。假设我们有两个数字 **36** 和 **60** ，那么 gcd 就是。

## C 程序中 GCD 或 HCF 是如何计算的？

这个 C 程序使用[欧几里德算法](https://en.wikipedia.org/wiki/Euclidean_algorithm)来寻找给定输入的 **GCD(HCF)** 和 lcm。**欧几里德算法说两个数的最大公约数，如果用其与较小数的差代替较大的数，则不变。**在这个 C 程序中，我们首先检查哪个是最大的数字，并将其作为分子，另一个作为分母，然后在`while`循环中使用 **mod** 运算符来查找 **GCD** 或 **HCF** 。

## 什么是 LCM？LCM 是如何用 C 语言计算的？

**LCM** 是两个数的最小公倍数。能被两个数整除的最小正整数，假设我们有两个数 **4** 和 **6** 有倍数，最小公倍数为 **12** 。找到 **GCD** 或 **HCF** 后，对于 **LCM** 我们有了一个定义明确的公式。

**【LCM = num 1 * num 2/gcd】。**

假设当我们取 2 个数字时，说“ **a** ”和“ **b** ”。让我们取另一个数“ **d** ”，这样“ **a/d** ”和“ **b/d** ”就不会留下任何余数或者余数为零，这类数称为公约数。公约数， **s** 不能太大，因为约数不能大于它们所划分的数。所以“ **d < =a** ”和“ **d < =b** 条件应该满足。

## 算法

**STEP 1:** 将头库导入 C 程序，使用内置函数。

**STEP 2:** 使用`void`开始主程序执行，表示不返回任何东西。

**步骤 3:** 初始化**余数**、 **LCM** 、 **GCD** 、**分子**、**分母**等的变量

**步骤 4:** 使用`printf`和`scanf`语句接受用户的两个数字。

**步骤 5:** 使用`if`语句检查 **num1** 是否大于 **num2**

**步骤 6:** 如果是，将分子指定为 **num1** ，分母指定为 **num2** 。

**步骤 7:** 如果 **num2** 更大，则使用 else 指定反之。

**步骤 8:** 使用 **num1** 和 **num 2** 之间的 **MOD** 运算符计算余数。

**步骤 9:** 使用`while`循环，直到余数不等于零。

**步骤 10:** 将分子换成分母，分母换成余数。

**步骤 11:** 将分母指定为 **GCD** 。

**步骤 12:** 使用公式 **num1 * num2 / GCD** 计算**LCM**；

**步骤 13:** 打印 **GCD** 和 **LCM** 的结果。

## c 源代码

```c
#include <stdio.h>

void main() {
  int num1, num2, GCD, LCM, remainder, numerator, denominator; /* declares the variables gcd, lcm, remainder etc as integers  */
  printf("Enter two numbers\n");
  scanf("%d %d", & num1, & num2); /*  accepts two numbers from the user  */
  if (num1 > num2) {
    numerator = num1;
    denominator = num2;
  } else {
    /* checks and assigns the value for numerator and denominator  */
    numerator = num2;
    denominator = num1;
  }
  remainder = num1 % num2; /* use mod operator to find the remainder  */
  while (remainder != 0) {
    numerator = denominator; /* using Euclid's algorithm to interchange the values of variables  */
    denominator = remainder;
    remainder = numerator % denominator;
  }
  GCD = denominator;
  LCM = num1 * num2 / GCD;
  printf("GCD of %d and %d = %d \n", num1, num2, GCD); /* after gcd we find out the value of lcm */
  printf("LCM of %d and %d = %d \n", num1, num2, LCM);
} /* End of main() */

```

## 输出

```c
RUN 1

Enter two numbers
5
15

GCD of 5 and 15 = 5
LCM of 5 and 15 = 15
```