# C `setlocale()`

> 原文：<https://learnetutorials.com/c-programming/library-functions/setlocale>

在 locale.h 头文件中定义的`setlocale()`函数。它有助于设置或读取当前程序的位置相关信息。

```c
 **char *setlocale(int category, const char *locale)** #where category will be any of the macro 

```

## `setlocale()`参数:

`setlocale()`函数接受两个参数。`setlocale()`的类别宏如下。

*   **LC_ALL** -选择所有 C 语言环境
*   **LC_COLLATE** -选择排序类别
*   **LC_CTYPE** -选择字符分类类别
*   **LC_MONETARY** -选择货币格式类别
*   **LC_NUMERIC** -选择数字格式类别
*   **LC_TIME** -选择时间格式类别

| 参数 | 描述 | 必需/可选 |
| --- | --- | --- |
| 种类 | 指示程序的区域设置信息将受到影响 | 需要 |
| 现场 | 系统特定的区域设置标识符。`setlocale()`查询当前的 C 区域设置，如果它是空指针。 | 需要 |

## `setlocale()`返回值

在应用更改后，它返回一个指向标识 C 语言环境的字符串的指针。

| 投入 | 返回值 |
| 论成功 | 指向字符串的指针 |
| 失败时 | 空指针 |

## `setlocale()`的示例

### 示例 1:在 C 语言中使用`setlocale()`函数

```c
 #include <stdio.h>
#include <locale.h>
#include <time.h>
int main () {
   time_t ctime;
   struct tm *timer;
   char ar[80];

   time( &ctime;);
   timer = localtime( &ctime; );

   printf("Locale : %s\n", setlocale(LC_ALL, "en_GB"));
   strftime(ar,80,"%c", timer );
   printf("Date : %s\n", ar);

   printf("Locale : %s\n", setlocale(LC_ALL, "de_DE"));
   strftime(ar,80,"%c", timer );
   printf("Date : %s\n", ar);

   return(0);
} 

```

**输出:**

```c
 Locale : en_GB                                                            
Date : Fri 05 Dec 2014 10:35:02 UTC                                       
Locale : de_DE                                                            
Date : Fr 05 Dez 2014 10:35:02 UTC 
```

### 示例`setlocale()`函数在 C 语言中是如何工作的？

```c
 #include <stdio.h>
#include <locale.h>
#include <time.h>
int main()
{
 char *st;
 setlocale(LC_ALL, "en_US.utf8");

 st = setlocale(LC_ALL, NULL);
    printf("Current locale: %s\n", st);
    printf("Changing locale\n");

 setlocale(LC_ALL, "en_GB.utf8");
 st = setlocale(LC_ALL, NULL);
 printf("Current locale: %s\n", st);

 return 0;
} 

```

**输出:**

```c
 Current locale: en_US.utf8
Changing locale
Current locale: en_GB.utf8 
```