# C `acos()`

> 原文：<https://learnetutorials.com/c-programming/library-functions/acos>

在 math.h 头文件中定义的`acos()`函数。它有助于以弧度为单位返回给定数字的弧余弦值。弧余弦表示反余弦值。

```c
 **double acos(double x);** #where x can be in int, float or long double 

```

另外，两个函数`acosf()`和`acosf()`分别用于类型 float 和 long double。

```c
 **float acosf(float x);** 
**long double acosl(long double x);** 

```

## `acos()`参数:

`acos()`函数接受 1 ≥ x ≥ -1 范围内的单个参数。使用 cast 运算符，我们可以显式地将类型转换为 double，以找到 int、float 或 long double 类型的弧余弦。

| 参数 | 描述 | 必需/可选 |
| --- | --- | --- |
| 赔偿损失时的加倍付给 | 介于- 1 和+1 之间的双精度值 | 需要 |

## `acos()`返回值

`acos()`函数的返回值在弧度为[0.0，π]的范围内。

| 投入 | 返回值 |
| x = [-1，+1] | [0，π]弧度 |
| -1 > x 或 x > 1 | NaN(不是数字) |

## acos 的示例()

### 例`acos()`函数在 C 语言中的工作？

```c
 #include <stdio.h>
#include <math.h>
int main()
{

    const double PI =  3.1415926;
    double v, output;

    v =  -0.5;
    output = acos(v);
    printf("The Inverse of cos(%.2f) = %.2lf in radians\n", v, output);

    //radians to degree convertion
    output = acos(v)*180/PI;
    printf("The Inverse of cos(%.2f) = %.2lf in degrees\n", v, output);

    // paramter not in range
    v = 1.2;
    output = acos(v);
    printf("The Inverse of cos(%.2f) = %.2lf", v, output);

    return 0;
} 

```

**输出:**

```c
 The Inverse of cos(-0.50) = 2.09 in radians
The Inverse of cos(-0.50) = 120.00 in degrees
The Inverse of cos(1.20) = nan 
```

### 示例`acosf()`和`acosf()`函数在 C 语言中是如何工作的？

```c
 #include <stdio.h>
#include <math.h>
int main()
{
    float f, fcosx;
    long double l, lcosx;

    // type float
    f = -0.505405;
    fcosx = acosf(f);

    //type long double
    l = -0.50540593;
    lcosx = acosl(l);

    printf("acosf(x) is equal to %f in radians\n", fcosx);
    printf("acosl(x) is equal to %Lf in radians", lcosx);

    return 0;
} 

```

**输出:**

```c
 acosf(x) is equal to 2.100648 in radians
acosl(x) is equal to 2.100649 in radians 
```