# C `asin()`

> 原文：<https://learnetutorials.com/c-programming/library-functions/asin>

在 math.h 头文件中定义的`asin()`函数。它有助于返回给定弧度数的反正弦值。反正弦表示反正弦值。

```c
 **double asin(double x);** #where x can be in int, float or long double 

```

另外，两个函数`asinf()`和`asinf()`分别用于类型 float 和 long double。

```c
 **float asinf(float x);** 
**long double asinl(long double x);** 

```

## `asin()`参数:

`asin()`函数接受 1 ≥ x ≥ -1 范围内的单个参数。使用 cast 运算符，我们可以显式地将类型转换为 double，以找到 int、float 或 long double 类型的反正弦。

| 参数 | 描述 | 必需/可选 |
| --- | --- | --- |
| 赔偿损失时的加倍付给 | 介于- 1 和+1 之间的双精度值 | 需要 |

## `asin()`返回值

`asin()`函数的返回值在弧度[-π/2，+π/2]的范围内。

| 投入 | 返回值 |
| x = [-1，+1] | [-π/2，+π/2]弧度 |
| -1 > x 或 x > 1 | NaN(不是数字) |

## `asin()`的示例

### 例`asin()`函数在 C 语言中的工作？

```c
 #include <stdio.h>
#include <math.h>
int main()
{

    const double PI =  3.1415926;
    double v, output;

    v =  -0.5;
    output = asin(v);
    printf("The Inverse of sin(%.2f) = %.2lf in radians\n", v, output);

    //radians to degree convertion
    output = asin(v)*180/PI;
    printf("The Inverse of sin(%.2f) = %.2lf in degrees\n", v, output);

    // paramter not in range
    v = 1.2;
    output = asin(v);
    printf("The Inverse of sin(%.2f) = %.2lf", v, output);

    return 0;
} 

```

**输出:**

```c
 The Inverse of sin(-0.50) = -0.52 in radians
The Inverse of sin(-0.50) = -30.00 in degrees
the Inverse of sin(1.20) = nan 
```

### 示例`asinf()`和`asinf()`函数在 C 语言中是如何工作的？

```c
 #include <stdio.h>
#include <math.h>
int main()
{
    float f, fsinx;
    long double l, lsinx;

    // type float
    f = -0.505405;
    fsinx = asinf(f);

    //type long double
    l = -0.50540593;
    lsinx = asinl(l);

    printf("asinf(x) is equal to %f in radians\n", fsinx);
    printf("asinl(x) is equal to %Lf in radians", lsinx);

    return 0;
} 

```

**输出:**

```c
 asinf(x) is equal to -0.529851 in radians
asinl(x) is equal to -0.529852 in radians 
```