# C `acosh()`

> 原文：<https://learnetutorials.com/c-programming/library-functions/acosh>

在 math.h 头文件中定义的`acosh()`函数。它有助于以弧度为单位返回给定数字的弧双曲余弦值。弧形双曲余弦表示反双曲余弦值。

```c
 **double acosh(double x);** #where x can be in int, float or long double 

```

另外，两个函数`acoshf()`和`acoshf()`分别用于类型 float 和 long double。

```c
 **float acoshf(float x);** 
**long double acoshl(long double x);** 

```

## 参数:

`acosh()`函数接受 x ≥ 1 范围内的单个参数。使用 cast 运算符，我们可以显式地将类型转换为 double，以找到 int、float 或 long double 类型的弧形双曲余弦。

| 参数 | 描述 | 必需/可选 |
| --- | --- | --- |
| 赔偿损失时的加倍付给 | 大于或等于 1 的双精度值(x ≥ 1) | 需要 |

## 返回值

`acosh()`函数的返回值是以弧度表示的大于或等于 0 的数字。

| 投入 | 返回值 |
| x ≥ 1 | 大于或等于 0 的数字 |
| x < 1 | NaN(不是数字) |

## `acosh()`的示例

### 例 1:C 语言中`acosh()`函数的工作原理？

```c
 #include <stdio.h>
#include <math.h>
int main()
{

    const double PI =  3.1415926;
    double v, output;

    v =  5.9;
    output = acosh(v);
    printf("The acosh(%.2f) = %.2lf in radians\n", v, output);

    //radians to degree convertion
    output = acosh(v)*180/PI;
    printf("The acosh(%.2f) = %.2lf in degrees\n", v, output);

    // paramter not in range
    v = 0.5;
    output = acosh(v);
    printf("The acosh(%.2f) = %.2lf", v, output);

    return 0;
} 

```

**输出:**

```c
 The acosh(5.90) = 2.46 in radians
The acosh(5.90) = 141.00 in degrees
The acosh(0.50) = nan 
```

### 示例`acoshf()`和`acoshf()`函数在 C 语言中是如何工作的？

```c
 #include <stdio.h>
#include <math.h>
int main()
{
    float f, fcosx;
    long double l, lcosx;

    // type float
    f = 5.5054;
    fcosx = acoshf(f);

    //type long double
    l = 5.50540593;
    lcosx = acoshl(l);

    printf("acoshf(x) is equal to %f in radians\n", fcosx);
    printf("acoshl(x) is equal to %Lf in radians", lcosx);

    return 0;
} 

```

**输出:**

```c
 acoshf(x) is equal to 2.390524 in radians
acoshl(x) is equal to 2.390525 in radians 
```