# C `raise()`

> 原文：<https://learnetutorials.com/c-programming/library-functions/raise>

signal.h 头文件中定义的`raise()`函数。它有助于提高参数中指定的信号，并且与 SIG 宏兼容。

```c
**int raise(int sig);** #where sig should be in integer 

```

## 提升()参数:

函数的作用是:用一个信号数作为参数。一些重要的标准信号数字是。

*   异常终止，如由函数引发的
*   错误的算术运算，如零除或导致溢出的运算
*   无效的函数图像，如非法指令。
*   互动注意信号。通常由应用程序用户生成。
*   对存储器的无效访问——当一个程序试图在分配给它的内存之外读写时。
*   终止请求发送到程序。

| 参数 | 描述 | 必需/可选 |
| --- | --- | --- |
| 签名 | 要发送的信号数字 | 需要 |

## 提升()返回值

函数的作用是:成功时返回零，失败时返回非零。如果传递的参数不是有效信号，则调用无效参数处理程序。

| 投入 | 返回值 |
| 如果成功 | 零 |
| 如果失败 | 非零的 |

## `raise()`示例

### 例 1:C 语言中`raise()`函数的工作原理？

```c
 #include <stdio.h>
#include <signal.h>
void signal_catchfunc(int);

int main () {
   int output;

   output = signal(SIGINT, signal_catchfunc);

   if( output == SIG_ERR) {
      printf("Error: unable to set signal handler.\n");
      exit(0);
   }
   printf("Signal is raising...\n");
   output = raise(SIGINT);

   if( output !=0 ) {
      printf("Error: unable to raise SIGINT signal.\n");
      exit(0);
   }

   printf("Going to Exit...\n");
   return(0);
}

void signal_catchfunc(int signal) {
   printf("! The is signal caught !\n");
} 

```

**输出:**

```c
 Signal is raising...
! The is signal caught !
Going to Exit... 
```

### 示例`raise()`函数在 C 语言中是如何工作的？

```c
 #include <stdio.h>
#include <signal.h>
void signal_handler(int sig)
{

    if (sig == SIGUSR1) printf("SIGUSR1 signal is Received..   \n");

    exit(0);
}

int main(int argc, const char * argv[])
{

    printf("Signal handler is registering..\n");

    signal(SIGUSR1, signal_handler);

    printf("SIGUSR1 signal is Raising..\n");

    raise(SIGUSR1);

    printf("Finished main\n");

    return 0;
} 

```

**输出:**

```c
 Signal handler is registering..
SIGUSR1 signal is Raising..
SIGUSR1 signal is Received.. 
```