# C `va_arg()`

> 原文：<https://learnetutorials.com/c-programming/library-functions/va_arg>

`va_arg()`是在 stdarg.h 头文件中定义的**宏**。这个**宏**有助于从函数的参数列表中获取下一个带类型的参数。但是这个函数不能确定检索到的参数是否是最后一个。

```c
 **type va_arg(va_list ap, type);** #where ap is the object of va_list 

```

## `va_arg()`参数:

`va_arg()`函数接受两个参数。参数“ap”保存检索状态的附加参数所需的信息。在 va_start 的初始调用和 va_arg 的第一次调用之前，这个“ap”对象被初始化。

| ****参数**** | ****描述**** | ****必选/可选**** |
| --- | --- | --- |
| 美国联合通讯社（Associated Press 的缩写） | va_list 的对象，它将保存信息 | 需要 |
| 类型 | 类型名称用作表达式的类型，该宏扩展为 | 需要 |

## `va_arg()`返回值

宏`va_arg()`返回表达式类型的下一个参数列表。我们可以多次调用宏 va_arg 来从列表中检索参数。

| 投入 | 返回值 |
| if 参数 | 下一个参数列表 |

## `va_arg()`的示例

### 例 1:va _ `arg()`函数在 C 语言中的工作？

```c
 #include <stdio.h>
#include <stdarg.h>

int getsum(int, ...);

int main () {
   printf("Sum of 23 and 45 is %d\n",  getsum(2, 23, 45) );
   return 0;
}

int getsum(int num_args, ...) {
   int value = 0;
   va_list ap;
   int i;

   va_start(ap, num_args);
   for(i = 0; i < num_args; i++) {
      value += va_arg(ap, int);
   }
   va_end(ap);

   return value;
} 

```

输出:

```c
 Sum of 23 and 45 is 68 
```

### 示例 2:va _ `arg()`在 C 语言中是如何工作的？

```c
 #include <stdio.h>
#include <stdarg.h>

void runcode (int i, ...)
{
    va_list pntr;
    va_start(pntr, i);

    if (i == 0)
    {
        int n = va_arg(pntr, int);
        printf("%d\n", n);
    }
    else
    {
        char *s = va_arg(pntr, char*);
        printf("%s\n", s);
    }

    va_end(pntr);
}

int main()
{
    runcode(0, 0xFFFFFFFF); // 0xffffffff is not an int
    runcode(1, NULL);       // NULL is not a char*
} 

```

输出:

```c
 -1

(null) 
```