# Golang 常量

> 原文：<https://learnetutorials.com/golang/constants>

在本 Golang 教程中，您将学习 Go 常量的所有知识。Golang 常量类似于变量，只是条件是一旦变量被声明为常量，就不能对其值进行更改。在本教程中，您将深入了解什么是 Go 中的常量、用于常量变量声明的不同语法、命名约定、常量类型及其多重声明。

## 什么是 Golang 常量？

Go 编程语言常量是一个值保持不变的变量。常量变量的赋值保持固定或不变，直到成功执行 Golang 程序或用户更改变量的赋值。Go 语言是只读的，不能修改。

## Go 常量是如何声明的？

在 Go 编程语言中，常量变量的声明就像我们在前面的教程中讨论的任何其他变量声明一样简单易行(变量声明的链接)。

*   关键字`const`将 Go 编程语言中的一个变量声明为常量。
*   关键字`const`后面是变量名及其类型，以标识常量变量存储的值的类型。

## Go 常量的语法

语法 1

```go
 Const  <variable_name> <type> = <value> 

```

```go
 const PLACE string = "Europe"
const street_no int = 3456 

```

该语法声明了一个名为 PLACE、street_no 的常量变量，并根据常量变量的值类型为其赋值。

### 程序 1:使用语法 1

```go
 package main
import "fmt"

const PLACE string = "Europe"
const street_no int =3456

func main() {
 fmt.Println(PLACE)
 fmt.Println(street_no)
} 

```

*   关键字`const`使字符串类型的欧洲和整数类型的数字 3456 在执行 Go 程序期间作为常量变量保持不变。
*   此语法是显式类型。

**输出:**

```go
 Europe
3456 
```

语法 2:

```go
 Const  <variable_name> = <value> 

```

在这种语法中，常量变量的类型是在程序执行期间推断出来的，不需要预先定义常量变量包含的变量值的类型。这里 const 关键字将变量声明为常量。该语法是隐式类型。

```go
 const PLACE1 = “Germany”
const street1 = 45 

```

### 程序 2:使用语法 2

```go
 package main
import "fmt"

const PLACE1=”Germany”  //Type inferred
const street1  = 45     //Type inferred

func main() {
 fmt.Println( PLACE1)
 fmt.Println(street1)
} 

```

*   PLACE1 是字符串类型的常量变量，变量在其内存位置保存“Germany”作为其值。
*   street1 是另一个常量变量，整数类型保存数字，如 45。

**输出:**

```go
 Germany
45 
```

## Golang 常量中的规则

*   常量变量的命名约定与[前一教程](../golang/variables)中讨论的变量命名规则相同。
*   大写字母最适合表示常量变量，因为它们易于识别。
*   常量变量在函数内部和外部都有声明。

## Golang 常量有哪些类型？

两类 Golang 常量

*   打字
*   untyped(不适用)

1.  ### 类型化常量

    类型化常量是用特定类型声明的常量变量。类型化常量也称为**显式类型。**

    ### 程序 3:

    ```go
     package main
    import ("fmt")
    /* const declared outside a function */
    const name string = "Typed Constant"
     func main() {
    fmt.Println( name)
    } 

    ```

    *   用值“类型常量”声明的类型字符串的常量变量名
    *   常量变量是用 const 关键字创建的。
    *   常量变量的类型被提到，所以它属于类型常量的范畴。

    **输出:**

    ```go
     Typed const 
    ```

2.  ### 非类型化常量

    非类型化常量是用未知类型声明的常量变量。非类型化常量被称为**隐式类型化。**

    ### 程序 4

    ```go
     package main
    import ("fmt")
    /* const declared outside a function */
    const z = 100

    func main() {
       fmt.Println(z)
    } 

    ```

    **输出:**

    ```go
     100 
    ```

    *   常量变量 z 使用 const 关键字声明，值为 100。
    *   常量的类型没有被定义，但是在程序执行期间被识别。/li >
    *   因此，中的变量类型是未知的，仅在代码编译期间被推断为整数类型，结果输出显示为 100。
    *   所以它被称为非类型化常量。

**注意:**在常量没有类型化的情况下，编译器决定常量变量的类型。

*   程序 3 和程序 4 都是在函数外声明的常量变量的例子。
*   考虑另一个例子，其中常量变量在函数内部声明

### 程序 5:

```go
 package main
import ("fmt")

func main() {
/* const declared inside function */
          const value =10
          const z = 3.14
          const u = "Hi!"

           fmt.Println(value)
           fmt.Println(z)
           fmt.Println(u)

    } 

```

## 如何声明多个 Golang 常量？

多个常量被分组到一个块中。使用以下语法定义多个常量变量

句法

```go
 Const (
 A = “ one“
 B = 90
 C = 78.90
 D = false 
) 

```

**const** 关键字后面是括号“()”，括号内定义了多个假定为常量的变量

### 计划 6:

```go
 const (
 PRODUCT  = "Dress "
 QUANTITY = 2
 PRICE    = 1550.50
 STOCK  = true
)
package main
import "fmt"
const (
 PRODUCT  = "Dress "
 QUANTITY = 2
 PRICE    = 1550.50
 STOCK  = true
)
func main() {
 fmt.Println(QUANTITY)
 fmt.Println(PRICE)
 fmt.Println(PRODUCT)
 fmt.Println(STOCK)
} 

```

**输出:**

```go
 2
1550.5
Dress
true 
```

## 常量变量可以重新声明吗？

不，常量变量的重新声明会导致编译错误。

让我们用一个例子来理解

```go
 package main
import ("fmt")
func main() {
    const value =10
    const z = 3.14      //  z declared as constant
    const u = "Hi!"
    var z = 3          // z redeclared as variable

    fmt.Println(value)
    fmt.Println(z)
    fmt.Println(u)
    fmt.Println(z)
} 

```

**输出:**

```go
 #_/home/y4zQxY
./prog.go:8:9 z reclared in this book previous declaration at ./prog.go:6:15 
```

**注意:**常量变量不能重新声明，这会导致编译错误