# Golang 循环

> 原文：<https://learnetutorials.com/golang/loops-with-examples>

在本教程中，您将了解另一种控制流结构，这种结构在 Go 编程语言中称为循环。在上一个教程中，您学习了两种引入分支逻辑的方法，如带有 if、if-else、if-else if 等的决策语句。、和 switch 语句([提供了到上一教程](../golang/control-flow-statements)的链接)。我们将在 Go 程序中学习 for 循环和 for range 循环的语法用法。

## 对于 Golang 中的循环语句

对于循环，语句允许多次执行语句集合。对于循环，语句被分解成三个不同的部分。此外，这三个部分可以形成成功循环迭代的各种语法。

一般来说，在 Golang 循环可以有两种类型

*   for 循环
*   对于范围循环

您将了解什么是简单循环，如何退出循环&如何循环遍历集合。

## Golang 中的简单循环

在开始使用 Go 语言的循环之前，让我们先了解 for 循环的基础知识。关键字的后跟三个语句

*   第一个语句是初始值设定项。该语句在第一次迭代之前首先执行。
*   第二个语句是用于检查条件的任何比较操作，它会生成一个布尔结果。
*   最后一个/第三个语句是 incrementor。通常用于递增计数器变量。

循环的基本语法:-

```go
 for    initializer; condition;   incrementor {
} 

```

简单循环程序

```go
 package main
import ("fmt")

func main() {
  for i:=0; i<=6; i++ {
    fmt.Println(i)
  }
} 

```

**输出:**

```go
 0
1
2
3
4
5
6 
```

解释:

初始化部分用值 0 初始化变量 I。条件部分是 i<=6，直到 I 的值小于 6，我们需要打印对应于 I 的值。下表介绍了如何在每次迭代期间检查迭代和条件。当 I 的值变为 7 时，条件变为假，最终退出循环。在每次迭代过程中，打印输出，显示输出中显示的 I 的当前值。

### 如何在 Golang 中增加两个变量

Golang 允许在 for 循环中像在其他语言中一样进行多个变量增量，但是您需要知道在 for 循环内部编码多个变量初始化和增量的语法。
多变量增量和初始化的语法:

```go
 for i , j :=0 , 0 ;   I <= 6;    i, j = i+1, j+1 {
} 

```

让我们用一个例子来理解

```go
 package main
import ("fmt")

func main() {
  for i , j :=0,0 ;i<=6; i,j = i+1,j+1 {
    fmt.Println(i,j)
  }
} 

```

**输出:**

```go
 0 0
1 1
2 2
3 3
4 4
5 5
6 6 
```

### 对于只有条件和增量的循环

在上面的程序中，我们讨论了循环语法的一般规则。在 Golang 中，for 循环可以用另一种格式或语法声明。没有必要在 for 循环中给出所有三个语句()。我在我们心中的价值

示例或任何要初始化的变量都可以在 for 循环之外初始化。所以第一条语句在 for 循环中变成空的，只有分号“；”应正确放置，否则将导致编译器错误。

语法:-

```go
 Initialize
for      ;  condition ; increment 

```

让我们用一个程序来理解

```go
 package main
import "fmt"

func main() {
    i := 0           //initializing i
    for ; i < 5; i++ { //for loop with condition part & incrementor
        fmt.Println(i)

    } 

```

**输出:**

```go
 0
1
2
3
4 
```

### 对于只有一个条件的循环

Golang 中的另一种 for 循环语法和上面的语法一样简单。
语法:

```go
 Initialize
for condition {
}
incrementor 

```

让我们用一个例子来理解

```go
 package main
import "fmt"

func main() {
    i := 0
    for i < 6 {
        fmt.Println(i)
        i++
    }
} 

```

**输出:**

```go
 0
1
2
3
4
5 
```

## Golang 循环的中断语句

在 Go 语言中，break 语句退出 for 循环。break 语句之后的代码不会在之后执行。

语法:一个关键字**打破**。

```go
 package main

import (
    "fmt"
)

func main() {
    i := 0
    for {
        fmt.Println(i)
        i++
        if i >= 4 {
            break
        }
    }
} 

```

**输出:**

```go
 0
1
2
3 
```

对于只有条件的循环，语法在上面的程序中使用。if 语句中给出的条件是 I 的值超过 3 时，break 语句将停止执行。这里，当满足上述条件时，break 语句退出 for 循环。

## 在 Golang 的 for 循环中继续语句

continue 语句省略 for 循环的指定迭代，并移到紧接其后的下一个迭代。

语法:一个关键字**继续**

### 带有继续语句的程序

```go
 package main
import ("fmt")

func main() {
  for i:=0; i < 8; i++ {    //for  loop
    if i == 6 {
      continue            //continue statement
    }
   fmt.Println(i)
  }
} 

```

**输出:**

```go
 0
1
2
3
4
5
7 
```

上面给出的程序跳过第 6 次迭代，并在 for 循环中前进到下一次迭代，以打印 I 的值。

## 循环嵌套

嵌套循环由一个内部循环和一个外部循环组成，即一个 for 循环内部有另一个 for 循环。

语法:

```go
 For loop outer {
       For loop inner {
            }
} 

```

### 理解循环嵌套的程序

```go
 package main
import ("fmt")

func main() {
language := [2]string{"Go", "Python"}
tutorials := [3]string{"learn eTutotials", "site1", "site2"}
for i:=0; i < len( language); i++ {
for j:=0; j < len( tutorials); j++ {
fmt.Printf("i= %d j=%d\n", i, j)
fmt.Println( language[i], tutorials[j])
}
}
} 

```

**输出:**

```go
 i= 0 j=0
Go learn eTutotials
i= 0 j=1
Go site1
i= 0 j=2
Go site2
i= 1 j=0
Python learn eTutotials
i= 1 j=1
Python site1
i= 1 j=2
Python site2 
```

说明

在上面的例子中，创建了两个数组，字符串数据类型的语言和教程。外部 for 循环由三个语句组成。lens (language)函数包含语言长度 ie 2 和教程长度 ie 3。我们已经讨论了数组中的[透镜()函数。
`for i:=0; i <2; i++ { // outer loop`](../golang/array)

`   for j:=0; j < 3; j++ { //inner loop`

`      fmt.Println( language[i], tutorials[j])`

`  }`

`}`

对于 i=0 时的第一次外部循环迭代，内部循环迭代并打印 Go learn etutorials。这里语言[0]是 Go&教程[0]是学习 Go。所以印刷品去学习电子旅行。这里，内部循环继续迭代，直到它退出循环。例如，再次 j 递增，j 变为 1，条件被检查 1 < 3, increments j and print language [0] tutorials [1] so the output will be Go site1 and continues till exit out of the inner loop for first outer iteration.
下一次外部循环递增，并执行上述相同的步骤，打印输出中显示的其余部分。

## Golang 的范围环路

Golang 中的 For range 循环用于迭代不同的数据结构集合，如数组、映射等。range 关键字迭代数组、映射或切片(链接到这些教程的)。

句法

```go
 for index, value := range map/slice/array {
//Code to execute
} 

```

### 了解范围概念的程序

```go
 package main
import ("fmt")

func main() {
  s := [ ]int{1,2,3}
  for index,value := range s {   // for range loop
     fmt.Printf("%v\t%v\n", index, value)
  }
} 

```

**输出:**

```go
 0 1
1 2
2 3 
```

解释:

上面给出的代码使用切片([链接到切片教程](../golang/slice))。语法以 for 关键字开始，从索引 0 开始迭代切片 s。range 关键字遍历每个切片元素，并将相应的值存储在 value 中。
例如，当索引为 0 时，range 关键字迭代第一个切片元素，这里它是 1。因此，值 1 存储在一个变量中，该变量声明为分配/存储切片元素的值。重复相同的过程，直到到达索引的末尾，即最后一个是 2。上面显示的输出使概念更加清晰。