# Golang 闭包

> 原文：<https://learnetutorials.com/golang/closures>

在本教程中，您将学习如何在 Golang 中使用闭包。在讨论闭包之前，我们需要理解变量作用域和生存期的概念。你将涵盖封闭的需要和它独特的环境。

### Golang 闭包中的可变作用域和生存期思想

考虑一个函数，该函数中声明了一个变量，该变量在该函数中可见。作用域是静态的，这是我们编写的编程代码的一个特征&它基于编译时，而生存期取决于程序执行(运行时)。

## 什么是 Golang 的封闭？

闭包是另一个函数内部的函数“覆盖”外部函数的一个或多个局部变量。高朗支持`nested functions`。嵌套函数是在另一个函数中定义的函数。
考虑下面的示例代码

```go
 func  fib()  func()  int {
a, b := 0,1
return  func()  int {
a, b = b, a+b
return b
}
} 

```

闭包涉及使用另一个函数作用域中的变量的函数

*   显然，有一个外部作用域，如图中所示的 F2。有一个函数 F1 在另一个函数 F2 的范围内。
*   这里 F1 和 F2 是嵌套函数。(另一个函数中的函数)
*   F1 指的是局部 F2 的一些变量，这将涉及到闭包。
*   函数 F1 闭包函数 F2 中的变量“b”。

让我们用对上面给出的代码的实际解释来理解:

*   代码包含一个函数 fib (fib())。Fib 不返回值，而是返回一个名为 func (func())的函数。
*   `fib()`是 F1 & `fib()`是 F2。
*   `fib()`的返回类型是返回整数类型 int 的`func()`函数。
*   因此`fib()`是一个返回另一个函数的函数。(外部功能)
*   内部函数是一个`anonymous function`它没有名字。它只是一个带有一些代码的函数文字，它使用变量 a & b，它没有声明一个& b。
*   变量 a & b 在 fib (F1)中声明。当内部函数返回时，它将继续引用 a & b，即使函数 fib 正在消失。
*   当 fib 运行时，它返回 a & b，它们将继续运行，因为返回的内部函数闭包 a & b，所以它保持 a & b 运行。

请看下图

该图左侧显示了功能，右侧显示了闭合。假设有一个变量赋值
f:= fib
f 被声明并赋值为 fib 的值，这里 fib 的使用没有任何括号，只取 fib 这个名字，它指的是函数而不是函数小腿这里充当指向代码的指针，即它将指向函数 fib
如果 f 被调用为带有括号的函数，即像`fib()`函数调用一样. f & fib 是同一事物的两个名字。这些由上图的左侧表示。

接下来在右侧，调用函数`fib()`，并赋值给变量 f。
f:= fib()
f 不是函数，而是闭包。有两部分 env & fp。在上面讨论的代码中，有一个匿名函数(F2)，它实际上是从 fib 的第一部分返回的。第二部分保存了在哪里可以找到 a & b 的信息。因为匿名内部函数改变了 a & b 的值，并且它返回了 b。
所以闭包是程序后台的一个运行时不可见的实践。

**NOTE:**-f is closure on the right-hand side because it got a pointer to the anonymous function (fp) and a pointer to the environment(env) & on the left-hand side it is just a pointer to the function (fp)

### 闭包程序

```go
 // Anonymous functions are useful when you want to define
// a function inline without having to name it.

package main
import "fmt"

// This function `fib` returns another function, which
// we define anonymously in the body of `fib`. The
// returned function _closes over_ the variable `a & b` to
// form a closure.
func  fib()  func()  int {
a, b := 0,1
return  func() int {
a, b = b, a+b
return b
}
}

func main() {
f := fib()
for x:=f();x<100;x=f() {
fmt.Println(x);           // 1 2,3,4,8,13,21,34,55,89

}
} 

```

**输出:**

```go
 1
2
3
5
8
13
21
34
55
89 
```

### Golang 需要封闭什么？

Golang 中需要闭包，即一个函数返回另一个函数是作用域。假设有一个函数，其中一些值被初始化为一个变量。函数只是一组要执行的指令。该函数中的内部函数将使用外部函数初始化的值。

## 如何在 Golang 创建闭包？

闭包的创建是通过在已经声明的外部函数中声明一个匿名函数来完成的。该函数可以访问其周围的状态并形成唯一的。
示例

下面的代码是包含 I 的函数 f 的闭包，闭包属性满足，匿名函数 f 可以直接访问 I 的值。

```go
 package main

import (
    "fmt"
)

func main() {

    i := 40
    f := func() {
                // has access to i
        j := i - 2
        fmt.Println(j)
    }

    f()      // 38
} 

```

**输出:**

```go
 38 
```

## Golang 独特的封城环境？

Golang 支持闭包函数中可用的数据隔离属性。无论何时创建闭包，它的状态都是唯一的。这使得他们每个人都有自己的状态。内部变量对于每个闭包都是唯一的。让我们用一个例子来理解

```go
 package main
import "fmt"

func  fib()  func()  int {
  a, b := 0, 1
       // return a closure over a & b
       return  func() int {
  a, b = b, a+b
  return b
  }

      }

func main(){

f , g := fib(), fib()  
// f & g have their own copies of a & b
fmt.Println(f(),f(),f())
fmt.Println(g(),g(),g())  //f() , g()   prints  identical lines 1,2,3

} 

```

**输出:**

```go
 1 2 3
1 2 3 
```