# Golang 通道

> 原文：<https://learnetutorials.com/golang/channels>

在本教程中，您将学习 Golang 中的通道概念。Go 编程语言中的 Channel 与 Golang 中的 Goroutine 相关，这在我们之前的教程中讨论过。你可以参考 [Goroutine](../golang/goroutines) 然后只有你才会理解我们在本教程中要讨论的通道。

## Golang 有哪些通道？

在 Golang 中，通道是一种允许在[和](../golang/goroutines)之间共享数据的机制。Goroutine 允许在 Goroutine 之间共享数据或资源的 Go 程序中并发执行活动。Golang 支持 1000 个 Goroutines，这些 Goroutines 在执行过程中共享数据或资源以实现并发。(我们已经在[戈罗廷](../golang/goroutines)教程中讨论过这一点)

*   Golang 的一个通道是戈罗提人相互交流的媒介。
*   换句话说，通道是一个管道，允许 Goroutine 执行某些操作，如读/写等。
*   通过通道，Goroutine 传输它们的数据或资源，其中一个 Goroutine 将数据写入通道，另一个 Goroutine 将从同一通道读取数据。

Goroutine A 向通道写入一些数据，Goroutine B 从同一通道读取数据。因此，信道(路径)有助于 Goroutines 之间的数据传输或通信。

## Golang 对通道有什么需求？

为了更好地理解通道的概念，我们将简单地看看戈罗廷发生了什么。
让我们用我们在[戈罗廷](../golang/goroutines)教程中讨论的同一个例子来理解。

```go
 package main
import (
  "fmt"
  "time"
)

func main() {

    fmt.Println("Go program starts")
    msg :="learn eTutorial"
    go func(){  //anonymous function
    fmt.Println(msg)
    }()
    msg = "hello users"
    fmt.Println("Go program ends")
    time.Sleep(100 * time.Millisecond)
    } 

```

上面给出的程序由两个代码块组成。

1.  `main()`函数
2.  你好

这两段代码彼此独立执行。由于独立执行`main()`和`main()`函数 Goroutine，出现了以下问题:

1.  有时程序在没有执行 hello () Goroutine 的情况下结束/终止，所以我们通过`sleep()`语句来解决这个问题。
2.  另一个问题是您不能在`main()`函数中访问`main()`函数的结果。

## 如何在 Golang 申报通道？

一个名为`chan`的新`keyword`在 Golang 宣布了一个通道。
声明语法

```go
 var <variable name> chan <data type> 

```

这里 c 是一个通道类型的变量，用整数(int)数据类型的 chan 关键字声明

**注意:**通道的默认值在声明时为零，与我们在 Goroutine 中讨论的相同

## 如何在 Goroutines 之间添加通道？

在 Golang 中，通道是允许我们的 Go 程序中明确的 Goroutines 之间进行有效通信的结构。go channel 的概念从 20 世纪 70 年代中期就已经存在了，让我们来看看如何实例化一个 channel &并将其用于不同 Goroutines 之间的通信。
一步一步我们就明白了。

1.  第一步是打开`main()`函数&实例化一个名为`msgs`的新通道。
2.  为了实例化或创建一个通道，我们使用关键字“`make`”后跟`chan`关键字，并声明其`type`。在给定的程序中，数据类型是整数。
3.  接下来在程序中，调用[delay](../golang/defer)关键字关闭通道。
4.  关闭的动作会阻止 Goroutines 发送或接收到该通道。
5.  为了与 go 中的通道进行交互，我们使用发送或接收操作符。
6.  创建了一个发送消息到通道的函数&定义了`send operator ( <- )`向该通道发送值。
7.  这是通过在主功能内调用`go SendMsg(msgs)`发送到通道的。
8.  然后将接收来自发送消息的值以便接收，接收操作符用于阻塞直到一个值被发送到那个通道。
9.  当我们运行代码时，我们可以看到该值成功地从 Goroutine 函数发送到`variable msg`。这将显示在输出中。这是一个整数通道的简单示例

**注意:**使用 make 函数创建通道，该函数指定 chan 关键字和通道的元素类型。

当我们创建一个通道而不指定通道的大小时，它被称为无缓冲通道。你将在下一节学到同样的东西。

```go
 package main

import (
    "fmt"
)

func SendMsg(c chan int){
 c <-0
}
func main() {
    fmt.Println("Learn eTutorial")

   msgs := make(chan int) // instantiating a channel
   defer close(msgs)
    go SendMsg(msgs)

    msg := <-msgs
    fmt.Println(msg)
} 

```

**输出:**

```go
 Learn eTutorial
0 
```

## Golang 有哪些类型的通道？

基于 Goroutines 之间的数据传输，有两种类型的通道。他们是

1.  无缓冲通道
2.  缓冲通道

## Golang 有哪些无缓冲渠道？

让我们考虑上述相同的程序，但唯一的区别是我们创建了一个字符串数据类型的通道。

*   当创建通道时，技术上没有指定通道的大小，这种通道称为无缓冲通道。
*   在无缓冲信道中，只有当发送方和接收方都准备就绪时，Goroutines 之间的通信才会成功。
*   在传统渠道的任何 Go 程序中，都可能会出现一些意想不到的行为。
*   在无缓冲信道中，每当一个 goro tine 说 A 向一个信道发送一个值时，Goroutine A 将被阻塞，直到从该信道接收到该值。

为了更好地理解相同的概念，对下面给出的上述代码进行了一些修改

```go
 package main

import (
    "fmt"
    "time"
)

func SendMsg(c chan string){   
fmt.Println("start Goroutine execution")
time.Sleep(1 * time.Second)
 c <-"hello world"
 fmt.Println("finished Goroutine execution")
}

func main() {
    fmt.Println("Learn eTutorial")

   msgs := make(chan string)    //created channel of string type.
   defer close(msgs)

    go SendMsg(msgs)
    go SendMsg(msgs)

    msg := <-msgs
    fmt.Println(msg)
} 

```

**输出:**

```go
 Learn eTutorial
start Goroutine execution
start Goroutine execution
finished Goroutine execution
hello world 
```

```go
 func SendMsg(c chan string){   
fmt.Println("start Goroutine execution")
time.Sleep(1 * time.Second)
 c <-"hello world"
 fmt.Println("finished Goroutine execution")
} 

```

在这部分代码中，定义了两个打印语句(“`start Goroutine execution`”&(“`finished Goroutine execution`”)。允许 Goroutine 睡眠几秒钟的睡眠语句。向通道(即`c <-"hello world"`发送操作后，打印 Goroutine 执行完成。
也重复了`go SendMsg(msgs)`的说法。有两个 Goroutines 试图发送同一个通道。
在上面的程序中，只有一个通道的接收语句`msg := <-msgs`，所以只有一个 Goroutine 有望完成它的执行。只有一个 Goroutine 将执行并打印最后一条打印语句。

第二个 Goroutine 不会完成它的执行，在主函数中被阻塞。程序将在第二个 Goroutine 完成执行之前终止

## Golang 有哪些缓冲通道？

为了消除阻塞行为，我们指定了通道的大小。当创建一个通道并指定通道的大小时，它被称为缓冲通道。
语法

```go
 Buffered channel: = make (chan datatype, size) 

```

例子

```go
 msgs: = make (chan string, 2) 

```

通过将此更改为缓冲通道，发送操作，c

```go
 import (
    "fmt"
    "time"
)

func SendMsg(c chan string){   
fmt.Println("start Goroutine execution")
time.Sleep(1 * time.Second)
 c <-"hello world"
 fmt.Println("finished Goroutine execution")
}

func main() {
    fmt.Println("Learn eTutorial")

 msgs := make(chan string,2)    //created channel of string type.
  defer close(msgs)

    go SendMsg(msgs)
    go SendMsg(msgs)

    msg := <-msgs
    fmt.Println(msg)
    time.Sleep(1 * time.Second)
} 

```

**输出:**

```go
 Learn eTutorial
start Goroutine execution
start Goroutine execution
finished Goroutine execution
hello world
finished Goroutine execution 
```

最后提供了`sleep()`语句，因为不能保证第二个 goro tine 会在第一个 goro tine 退出之前完成。

从输出来看，很明显第一个和第二个 Goroutine 开始执行&类似地，两者都终止。
如果没有可用的接收器，我们不希望 channel 语句阻塞，则使用缓冲通道。添加一个缓冲区允许我们在不阻塞发送代码的情况下等待一些接收器被释放。

### I Golang 有哪些渠道属性？

*   通道提供阻止和解除阻止 Goroutines 的功能。
*   先进先出语义由通道提供
*   Goroutines 之间安全可靠的数据传输。
*   易于创建和使用

## 一个 Golang 的渠道运营是什么？

通道中提供的基本操作是读和写。对通道的读写用左箭头 **< -** 表示

**注意:**同一个运算符表示通道中的发送/接收操作。

*   Goroutines 之间的通信是基于这两个操作工作的，分别是发送和接收。

*   默认情况下，发送和接收操作处于阻塞状态，直到另一端准备好运行。
*   这种具有块状态的操作允许实现 Goroutines 之间的同步
*   没有条件变量或锁用于同步，只是这两个操作成功地执行了同步。

在这里，信道发送和接收数据。让蓝色圆圈成为一串“你好世界”的信息。

发送操作:这表示消息“hello world”(数据)被发送到创建为 c 的通道(已经讨论过让通道参考上面的部分)。
`c <-"hello world"`

接收操作:在此操作中，通过创建一个名为 msg 的新变量，由 Goroutine A 馈送到通道的消息被另一个 Goroutine B 接收。
`msg  := <-c`

### // Go 程序说明发送和接收操作

```go
 package main

import (
"fmt"
"time"
)  
func myfunc(c chan string) {

    fmt.Println("start Goroutine execution")
   time.Sleep(1 * time.Second)
   c <-"hello world"                             //send msg hello world to channel c
   fmt.Println("finished Goroutine execution")

}
func main() {
    fmt.Println("start Main method")
                                                               // Creating a channel
    c := make(chan string)

    go myfunc(c)
    msg := <-c                                        //receive msg helloworld from channel c
    fmt.Println(msg)
    fmt.Println("End Main method")
} 

```

**输出:**

```go
 start Main method
start Goroutine execution
finished Goroutine execution
hello world
End Main method 
```