# Go 程序：实现二分搜索

> 原文：<https://learnetutorials.com/golang/programs/binary-search>

这里我们解释如何编写一个 GO 程序来从任何数据结构中搜索一个元素。有不同类型的搜索算法。在这种情况下，我们使用二分搜索法从数组中查找或搜索元素。

二分搜索法是一种快速搜索算法，最重要的是二分搜索法技术只在元素按排序顺序排列时有效。它基于分而治之的原则。这意味着它通过将搜索空间分成两半并在该部分中查找元素来搜索排序数组中的元素。重复此过程，直到找到值或间隔为空。

在这种技术中，第一次搜索从覆盖整个数组的一个区间开始，它通过比较集合的中间项来寻找特定的项。如果匹配，则返回该特定项目，否则继续搜索。假设搜索关键字的值大于中间元素，那么搜索关键字只能位于中间元素之后的右半子数组中。所以我们重复中间元素的右半部分。否则，搜索关键字小于中间元素。所以我们重复中间元素的左半部分。继续这个过程，直到找到值或者子数组的大小减小到零。

## 如何实现二分搜索法

在这个 GO 程序中，我们正在导入“fmt”包，以将一些标准库包含到程序中。在 main 函数启动之后，在 Main 内部，我们正在执行整个程序。注意，二进制搜索算法的时间复杂度是ο(log n)。

在这个 GO 程序中，我们使用 fmt 包中定义的`fmt.scanln()`和`fmt.println()`方法接受用户的值。为了使用这些功能，我们需要导入“fmt”包。

这里变量 A 保存数组元素。其他变量 **n，x** 分别作为数组和搜索元素的大小。用于循环读取数组元素。请注意，二分搜索法仅在元素按排序顺序排列时有效。因此，对数组元素进行冒泡排序，并使用“**表示循环**”和“`fmt.Println`”来显示排序后的数组。

变量“低”和“高”用作函数参数。分配 `Low=0, High=n-1`并通过调用功能`binarySearch(A, Low, High, num)`执行二分搜索法。在此功能中，将搜索元素 **x** 与中间元素 m 进行比较。这里，如果低<=高，我们使用公式计算中间元素 m。如果搜索元素 **x** 与中间元素匹配，我们返回中间元素索引。否则，勾选 x 大于中间元素，则 **x** 只能位于中间元素后的右半子数组。所以我们重复右半部分。因此分配`low = m + 1`并调用函数`binarySearch(A, low, high, x`。否则， **x** 只能位于中间元素之前的左半子数组中。如果是，分配 high = m -1 并调用函数 `binarySearch(A, low, high, x)`。

下面给出了在 Go 计划中实现二分搜索法的步骤。

算法:

**第一步**:导入包裹 **fmt**

**STEP 2** :打开主()启动程序，GO 程序执行从主()开始

**步骤 3** :声明变量 **n，x，temp，Low，High 和结果**

**步骤 4** :将数组的大小读取为 n

**步骤 5** :定义数组 **A[]。**

**第 6 步:使用`for loop.`读取**数组元素****

**步骤 7:** 打开嵌套的“`for loop`”来实现冒泡排序算法。

**步骤 8:** 使用 if 条件检查，比较元素大于被比较元素

**步骤 9:** 如果是，使用临时变量交换元素。

**步骤 10:** 使用“`for loop`”和`fmt`打印排序后的数组。

**第 11 步:**把要搜索的号码读为 x。

**步骤 12:** 将低指定为 **0** ，将高指定为项 n-1 的数量。

**步骤 13:** 调用函数 binarySearch ( `A`、Low、`High`、`x`)并将返回值赋给结果。

**第 14 步**:使用“`if `条件”检查结果是否等于-1。如果是，打印元素未找到

**步骤 15:** 否则打印找到的元素的位置。即:`result` +1

**第 16 步:**出口

**实现二进制搜索(`A`、低、`High`、`x`)功能的步骤**

**STEP 1:** 声明变量 m 为中间元素。

**STEP 2:** 如果 low=high，则使用公式(low + high) / 2 计算中间元素 m。否则，返回-1 并退出该函数。

**步骤 3:** 使用“`if`”条件检查搜索关键字 x 是否等于数组中间元素 m。如果是，返回 m 的值并退出该功能。

**STEP 4:** 使用'`if`&39；条件检查，搜索关键字 x 小于 Array 中间元素 m，如果是，high = mid -1 并调用函数 binarySearch ( `A`、Low、`High`、`x`)。

**步骤 5:** 否则检查搜索关键字 x 是否小于数组中间元素，如果是，则低=中间+ 1，并调用函数 binarySearch ( `A`、`low`、`high`、`x`)。

>

## GO 源代码

```go
package main
import  "fmt"
func binarySearch(A[]int, low int, high int, x int) int {
 if low <= high {
  var m int
  m = (high + low) / 2

  if A[m] == x {
   return m
  }

  if A[m] > x {
   return binarySearch(A, low, m-1, x)
  } else {
   return binarySearch(A, m+1, high, x)
  }
 }

 return -1
}

func main() {
 fmt.Println("Enter the size of the array")
 var n int
 fmt.Scan(&n)
 var x int
 A := make([]int, n, 100)
        fmt.Println("Enter elements:")
 for i := 0; i < n; i++ {
  fmt.Scan(&A[i])
 }
 var temp int
        for i := 0; i < n; i++ {
 for j := 0; j <(n-i-1); j++ {
   if A[j] > A[j + 1]{
           temp = A[j];
           A[j] = A[j + 1];
           A[j + 1] = temp;
         }
      }
         }
        fmt.Println("Sorted array:")
 for i := 0; i < n; i++ {
  fmt. Println (A[i])
 }
        fmt.Println("Enter the number to be searched:")
 fmt.Scan(&x)
 var result int
 result = binarySearch(A, 0, n-1, x)
 if result == -1 {
  fmt.Println("Search element not found !")
 } else {
  fmt.Println("Search element found at position: ", result+1)
 }
} 

```

## 输出

```go
Enter the size of the array
5
Enter elements: 
52
32
45
10
90
Sorted array: 
10
32
45
52
90
Enter the number to be searched:
45
Search element found at position:  3 
```