# Go 程序：实现插值搜索

> 原文：<https://learnetutorials.com/golang/programs/interpolation-search>

有不同类型的搜索算法。但是在这一部分，我们将讨论对传统的二分搜索法方法的改进，称为插值搜索。这里我们解释如何编写一个 GO 程序，使用插值搜索从数组中搜索一个元素。

插值搜索算法和二分搜索法的主要区别在于，在二分搜索法的情况下，它从数组的中间开始搜索。但是插值搜索算法试图找到更有可能出现的元素。为了算法的正常工作，数组的元素必须排序并均匀分布。

插值搜索几乎类似于在电话簿中搜索一个特定的名字或在英语词典中搜索一个特定的单词，其中数据必须均匀分布。例如，在电话号码簿的情况下，所有以 a 或 b 开头的名字都在号码簿的开头，所有以 o 和 p 开头的名字都可能在中间的某个地方。另一方面，以 x、y 和 z 开头的名称将位于目录的最末尾。因此，我们可以根据需要搜索的元素，每次在不同的位置开始搜索。

在均匀分布的排序数组中，较小的数字位于数组的开头，而较大的数字应该位于数组的末尾。因此，每当插值搜索想要从这个数组中搜索一个更大的数字时，它将在数组末尾的某个地方开始搜索，如果是更小的数字；从数组的开头开始搜索。

## 如何实现插值搜索

在这个 GO 程序中，我们正在导入“fmt”包，以将一些标准库包含到程序中。在 main 函数启动之后，在 Main 内部，我们正在执行整个程序。注意，插值搜索算法的时间复杂度是ο(log(log n))。

在这个 GO 程序中，我们使用`fmt.scanln()`和`fmt.scanln()`方法接受用户的值，这些方法在 fmt 包中定义。为了使用这些功能，我们需要导入“fmt”包。

这里变量 **A** 保存数组元素。其他变量 **n** 和**键**分别用作数组和搜索元素的大小。用于循环读取数组元素。请注意，插值搜索仅在元素以均匀分布的排序顺序排列时有效。

变量**低**和**高**用作功能参数。赋值`low =0, High=n-1`通过调用函数`InterpolationSearch(A,key)`在迭代循环内进行插值搜索，并将函数返回值赋给变量索引。这里，我们使用以下公式计算中间元素 mid:

`mid = low + ((key – A[low]) * (high – low) / (A[high] – A[low]))`

其中 **A【低…高】**是我们的搜索空间，**键**是要搜索的给定元素。

如果搜索元素关键字与中间元素匹配，则返回中间元素索引。否则，检查**键**是否大于中间元素。如果是，则制作`low = mid + 1`。否则分配`high = mid – 1`。如果索引等于-1，则打印元素未找到。否则，打印找到的元素的索引。即:索引+1

下面给出了在执行程序中实现插值搜索的步骤。

## 算法:

**STEP 1** :导入包 fmt
**STEP 2** :打开`main()`启动程序，GO 程序执行从`main()`
**开始 STEP 3** :声明变量 n、x、temp、Low、High、result。
**STEP 4** :将数组的大小读取为 n.
**STEP 5** :定义数组 A[]。
**STEP 6** :循环使用 A 读取 A[]数组元素。
**STEP 7** :读取要搜索的号码作为关键字。
**步骤 8** :将低指定为 0，将高指定为 n-1 项的数量。
**STEP 9** :调用插值搜索(A，key)函数，将返回值赋给索引。
**步骤 10** :使用“如果”条件检查索引是否等于-1。如果是，打印未找到的元素
**步骤 11** :否则，打印找到的元素的位置。即:索引+1
**步骤 12** :退出

### 实现插值搜索功能的步骤

**STEP 1** :将变量**中的**声明为中间元素，**低的**和**高的**作为数组的索引。
**STEP 2** :初始化`low = 0`和`high = n-1`。
**第三步**:打开【for 循环】，检查`A[low] < key`和`A[high] > key`情况。如果条件为真，则执行以下步骤。
**STEP 4** :利用公式计算中间元素**中间**；mid = low+((key-A[low])*(high-low))/(A[high]-A[low])。
**步骤 5** :使用“如果”条件检查搜索元素键是否等于数组中间元素 mid。如果是，返回 mid 的值并退出该函数。
**STEP 6** :使用“如果”条件检查，数组中间元素**中间**小于键。如果是，分配`low = mid + 1`。
**STEP 7** :否则检查数组中间元素**中间**是否大于键如果是`high = mid -1`。
**STEP 8** :使用“if”条件检查搜索元素**键**是否等于数组中间元素**中间**。如果是，返回**中间**的值，退出该功能。
**STEP 9** :检查 **A【低】**是否等于搜索元素**键**，如果是，返回**低**。
**STEP 10** :否则检查 **A【高】**是否等于搜索元素**键**，如果是，返回**高**。否则，返回-1。

下面给出了使用插值搜索算法搜索整数数组中元素的 Go 程序的源代码。输出将显示元素在数组中的位置。

## GO 源代码

```go
package main
import "fmt"

//interpolation search method
func InterpolationSearch(A []int, key int)int{
 var mid int
 var low int
 low = 0
 var high int
 high = len(A) - 1

 for A[low] < key && A[high] > key {
  mid = low + ((key-A[low])*(high-low))/(A[high]-A[low])

  if A[mid] < key {
   low = mid + 1
  } else if A[mid] > key {
   high = mid - 1
  } else {
   return mid
  }
 }

 if A[low] == key {
  return low
 } else if A[high] == key {
  return high
 } else {
  return -1
 }

}

// main method
func main() {
         var key int
        var n int
        fmt.Println("Enter the size of the array")
 fmt.Scan(&n)
 A := make([]int, n, 100)
       fmt.Println("Enter elements of the array in uniform distributed and sorted order: ")
 for i := 0; i < n; i++ {
  fmt.Scan(&A[i])
 }
 fmt.Println("Enter the number to be searched")
 fmt.Scan(&key;)
 var index int
 index = InterpolationSearch(A, key)
 if index == -1 {
  fmt.Println("Element not found !")
 } else {
 fmt.Println("The element found at", index+1)
 }
} 

```

## 输出

```go
Enter the size of the array
5
Enter elements of the array in uniform distributed and sorted order: 
2
4
6
8
10
Enter the number to be searched
8
The element found at 4
```