# Go 程序：实现快速排序

> 原文：<https://learnetutorials.com/golang/programs/implement-quick-sort>

这里我们解释如何编写一个 GO 程序来对数组中的元素列表进行排序。有不同类型的排序算法。在这种情况下，我们使用快速排序对数组元素进行排序。快速排序是生产排序实现中常用的最有效的排序算法之一。顾名思义，我们可以说它是最快的排序算法，但是你应该对排序的实现给予关注和照顾，否则你的速度会下降得很快。所以对于大数据集来说，这不是一个有效的算法。

它基于除法和征服类算法的原理。这里，它将数组分成更小的块，这将有助于您快速轻松地对元素进行排序。

这里我们用一个指定的值叫做枢轴。基于枢轴位置，一个大的未排序数组被分成两个子数组。其中一个数组包含小于透视值的值，根据该值进行分区，另一个数组包含大于透视值的值。然后在枢轴的两侧递归地执行排序操作，直到不再存在子数组。

## 如何实现快速排序

在这个 GO 程序中，我们使用在 fmt 包下定义的“`fmt.scanln()`”和“`fmt.println()`”方法接受用户的值。为了使用这些功能，我们需要导入“ **fmt** 包。要将字符串类型转换为 Int 类型，我们使用 **Atoi()** 函数，该函数相当于 ParseInt(字符串、基 int、bitSize int)。您需要在程序中导入“ **strconv** ”包才能访问 **Atoi()** 功能。

这里变量 **A** 保存数组元素。其他变量 **n** 和 **pivot** 分别用作数组和 pivot 索引元素的大小。用于循环读取数组元素。使用两个变量**低**和**高**来存储除枢轴元素之外的最低和最高索引位置。快速排序算法是使用分治法开发的，它在比较算法类别下工作。

这里我们主要使用两个功能，主要的 **quickSort()** 功能以及 **partition()** 功能。**分区()**功能用于查找枢轴值，并负责将所有内容移动到**枢轴**的正确一侧。 **quickSort()** 函数用于处理算法的递归性质。

##### **时间复杂度:**

*   最佳复杂度:n*log(n)
*   平均复杂度:n*log(n)
*   最复杂的:n^2

下面给出了在 Go 程序中实现快速排序的步骤。

## 算法

**STEP 1:** 导入包“fmt”和“strconv”
**STEP 2:**打开 **main()** 启动程序，GO 程序执行从 **main()**
**开始 STEP 3** :声明变量 **n** 。
**STEP 4:** 读取数组大小为 **n**
**STEP 5:** 定义数组**A[]**
**STEP 6:**使用“for loop”读取**A[**数组元素。
**STEP 7:** 通过调用函数**快速排序(arr，0，len(arr)-1)**
**STEP 8:**用于循环显示排序后的数组。
**步骤 9:** 退出

### 实现快速排序的步骤(arr，0，len(A)–1)

**STEP 1:** 检查是否低<高，然后通过调用**分区(A、低、高)**
**找到数组下界的枢纽索引 STEP 2:** 应用分治策略通过调用**快速排序(A、低、枢纽)**
**通过调用**快速排序(A、枢纽+t)将右侧数组排序到枢纽位置****

### 实现分区的步骤(整数，低整数，高整数)

**步骤 1:** 选择一个最低界限元素作为枢轴值枢轴
**步骤 2:** 声明两个变量**低**和**高**(即指针)来存储除枢轴元素之外的最低和最高索引位置。
**STEP 3:** 赋值 `i=low, j=high.`
**STEP 4:** 使用 for 循环，通过增加“ **i** 的索引值向右移动左侧指针，直到指针**A【I】**的值小于或等于**枢轴**元素。
**STEP 5:** 使用 for 循环，通过递减“ **j** 的索引值向左移动右侧指针，直到指针的值大于**枢轴**元素。
**STEP 6:** 仅当 **i** 小于 **j**
**时，交换数组的索引 **i** 和 **j** 中的当前值 STEP 7:** 将 j <sup>第</sup>个位置中的元素交换到数组的下限，并将 Pivot 元素放置到 j 的位置
**STEP 8:**

## GO 源代码

```go
package main

import (
 "fmt"
 "strconv"
)

func quickSort(A []int, low, high int) {
 if low < high {

        // Find the pivot index of an lower bound of an array
  var pivot = partition(A, low, high)

        // Apply Divide and conquer strategy
        // to sort the left side and right side of an array
        // respective to the pivot position

        // Left hand side array
  quickSort(A, low, pivot)

        // Right hand side array
  quickSort(A, pivot + 1, high)
 }
}

func partition(A []int, low, high int) int {

    // Pick a lowest bound element as an pivot value
 var pivot = A[low]

 var i = low
 var j = high

 for i < j {

        // Increment the index value of "i"
        // till the left most values should be less than or equal to the pivot value
  for A[i] <= pivot && i < high {
   i++;
  }

        // Decrement the index value of "j"
        // till the right most values should be greater than to the pivot value
  for A[j] > pivot && j > low {
   j--
  }

        // Interchange the values of present 
        // in the index i and j of an array only if i is less than j
  if i < j {
   var temp = A[i]
   A[i] = A[j]
   A[j] = temp
  }
 }

    // Interchange the element in j's poisition to the lower bound of an array
    // and place the Pivot element to the j's position
 A[low] = A[j]
 A[j] = pivot

    // Finally return the appropriate index position of the pivot element
 return j
}

func main() {

 fmt.Println("Enter the size of the array")
 var n int
 fmt.Scan(&n)
 A := make([]int, n, 100)
fmt.Println("Enter elements : ")

 for i := 0; i < n; i++ {
  fmt.Scan(&A[i])
 }

 quickSort(A, 0, len(A) - 1)
 fmt.Print("After Sorting: ")
 for i := 0; i < n; i++ {
  fmt.Print(strconv.Itoa(A[i]) + " ")
 }
} 

```

## 输出

```go
Enter the size of the array
5
Enter elements: 
81
60
73
52
95
After Sorting: 52 60 73 81 95 
```