# Go 程序：实现插入排序

> 原文：<https://learnetutorials.com/golang/programs/implement-insertion-sort>

这里我们解释如何编写一个 GO 程序来实现排序。有不同类型的排序方法。在这种情况下，我们使用插入排序对数组中的元素进行排序。插入排序是一种通过使用比较算法开发的简单技术。它的工作原理就像你手中的扑克牌一样。插入排序是一种比归并排序、堆排序或快速排序更有效、更高级的算法。

在这个 Go 程序中，在对东西进行排序之前，我们必须设置一个起点，这有助于在一个方向上保持一致，直到到达数组的末尾。这意味着数组首先被分成两个部分:已排序部分和未排序部分。最初，已排序的部分只包含一个元素，即主数组的第一项，其余项被视为未排序的部分。在未排序的节中取最左边的元素，在排序的节中找到合适的位置。重复这个过程，直到没有元素存在于未排序的子数组中。最后，来自未排序部分的每个值被插入到排序部分的正确位置。

## 如何实现插入排序

在这个 GO 程序中，我们可以使用内置功能`fmt.println()`打印任何东西，使用`fmt.scanln()`读取数值，这些方法在 **fmt** 包中定义。为了使用这些功能，我们需要导入“ **fmt** ”包。
这里变量 A 保存数组元素。其他变量 n 用作数组的大小。用于循环读取数组元素并通过调用函数`insertionSort()`进行排序。

`insertionSort()`从迭代嵌套 for 循环中的整个数组元素开始。也就是说，如你所见，在这个函数中，我们需要 2 个**用于循环**，外环和内环。

外部循环使用循环变量 **j** ，它有助于从左到右迭代数组直到数组结束，并选择一个**键**，它有助于在一个方向上保持一致，直到我们到达数组结束，并在每次迭代中将该键与左侧进行比较。请注意，最初，我们从第二个元素(索引 1)中选择**键**，以保存 1 次迭代，并在左侧比较该键。

在内部循环中，使用变量“ **i** ，这有助于向后迭代左侧的元素。这里如果满足内循环的排序条件，将左侧所有元素移位:`i>-1 && A[i] > key`，其中条件`A[i]>key`为升序。

在外循环的每个键迭代中，我们将所选的键插入其正确的位置，并重复所有这些过程，直到我们在所有键上循环。最后，排序后的数组返回到主函数，主函数将排序后的数组显示为输出。

时间复杂性:

*   最佳复杂度:n
*   平均复杂度:n^2
*   最复杂:n^2

下面给出了执行程序中实现插入排序的步骤。

## 算法

**第一步**:进口包裹 **fmt** 。
**STEP 2** :打开**主()**启动程序，GO 程序执行从**主()开始。**
**STEP 3** :声明变量 **n.**
**STEP 4** :将数组的大小读取为 **n.**
**STEP 5** :定义数组 **A[]。**
**STEP 6** :使用“ **for loop** 读取 **A[]** 数组元素。
**STEP 7** :通过调用函数`insertionSort (A, n)`
**进行选择排序 STEP 8** :用于循环显示排序后的数组。
T41】第 9 步:退出

### 实现插入排序的步骤(A，n)

**STEP 1** :初始设置`j=1`
**STEP 2** :使用 for loop 打开外环，for loop 使用 j loop 变量。
**STEP 3** :如果外循环满足 j
**STEP 4** :通过给 key 赋值 A[j]来选择一个键，在每次迭代中比较左侧？？？？？
**STEP 5** :设置`i := j - 1`
**STEP 6** :打开内部循环，使用‘I’变量。
**STEP 7** :如果内环满足排序条件:`i>-1 && A[i] > key`，那么将左侧元素移动为`A[i+1] = A[i]`。否则，转到步骤 9。
**STEP 8** :重复步骤 7，递减“ **i** 的值，对左侧的元素进行反向迭代，直到所选的键到达左侧的开始处。
**STEP 9** :在外环的每次按键迭代中，通过增加 **j** 的值，我们将所选按键插入其正确的位置作为`A[i+1] = key`。转到步骤 3
**步骤 10** :返回排序数组 **A.**

## GO 源代码

```go
package main

import (
  "fmt"
)

func main() {
  fmt.Println("Enter the size of the array")
 var n int
 fmt.Scan(&n)
 A := make([]int, n, 100)
fmt.Println("Enter elements of the array : ")

 for i := 0; i < n; i++ {
  fmt.Scan(&A[i])
 }
fmt.Println("Sorted array:")
   fmt.Println(insertionSort (A, n))

}

func insertionSort(A []int, n int) []int {
  for j := 1; j < n; j++ {
    key := A[j]
    i := j - 1
    for i > -1 && A[i] > key {
      A[i+1] = A[i]
      i -= 1
    }
    A[i+1] = key
  }
  return A
} 

```

## 输出

```go
Enter the size of the array
5
Enter elements of the array : 
32
24
56
85
63
Sorted array:
[24 32 56 63 85] 
```