# Go 程序：实现希尔排序

> 原文：<https://learnetutorials.com/golang/programs/implement-shell-sort>

这里我们解释如何编写一个 GO 程序来实现一个排序算法。有不同类型的排序方法。在这种情况下，我们使用希尔排序对数组中的元素进行排序。

我们可以说 Shell 排序是插入排序的扩展版本。这两种算法都是基于比较的就地排序算法。Shell 排序是一种高效的中型数据集排序算法。

shell 排序的大部分是基于插入排序的。在插入排序中，每当一个元素必须向前移动很远时，我们只将元素向前移动一个位置，而将一个元素移动到很远的位置需要很多次移动。这会增加算法的执行时间。但是在壳排序的情况下，它可以克服插入排序的这个缺点。因为 shell 排序允许交换更远的项目。这意味着它避免了像插入排序那样的大移位。

## 如何实现希尔排序

在这个 GO 程序中，我们正在导入“fmt”包，以将一些标准库包含到程序中。我们使用 fmt 包中定义的`fmt.scanln()`和 `fmt.println()`方法接受用户的值。为了使用这些功能，我们需要导入“fmt”包。在 main 函数启动之后，在 Main 内部，我们正在执行整个程序。

正如我们所看到的，shell 排序算法首先确实会对彼此相距很远的元素进行排序，然后它会随后缩小它们之间的差距。这个间隙称为**间隔**。这个间隔可以通过使用下面给出的克努特公式来计算，

**克努特公式:**
h = h * 3 + 1
其中“ **h** ”是初始值为 1 的区间

在这个程序中，变量 **A** 保存数组元素。另一个变量 **n** 用作数组的大小。使用**进行**循环读取数组元素。通过调用函数`shellSort(A, n)`执行 shell 排序。在这里，函数`shellSort(A, n)`执行以下操作，如初始化**区间**的值，将数组分成相等区间的较小子数组，使用插入排序对这些子数组进行排序，并重复该过程，直到整个数组被排序。

下面给出了在 Go 程序中实现 Shell 排序的步骤。

## 算法

**第一步**:进口包裹 **fmt** 。
**STEP 2** :打开 **main()** 启动程序，GO 程序执行从**main()**
**STEP 3**开始:声明变量 **n** 。
**STEP 4** :将数组的大小读取为 **n**
**STEP 5** :定义数组**A[]**
**STEP 6**:使用“for loop”读取**A[**数组元素。
**STEP 7** :通过调用函数`shellSort(A, n)`进行 shell 排序。
**STEP 8** :用于循环显示排序后的数组。
**步骤 9** :退出

### 实现壳排序的步骤(A，n)

**STEP 1** :打开第一个循环进行 shell 排序，将 0 索引处的元素与`n/2`索引处的元素进行比较。这里`n/2`索引存储在变量**区间**中。
**步骤 2** :如果循环条件:0 索引处的元素大于间隔处的元素为真，则执行步骤 3，否则执行步骤 8。
**STEP 3** :对循环使用**打开外循环进行插入排序，通过赋值`j=interval`使用循环变量 **j** 。
**STEP 4** :如果外循环满足条件，`j<n,`那么会帮助你从左到右迭代数组区间元素，直到数组结束。否则，转到步骤 7。
**STEP 5** :如果内环满足排序条件:`k >= interval && A[k-interval] > A[k]`，则交换元素的值。否则，增加`j=j+1`并转到步骤 4。
**STEP 6** :重复步骤 5，将 **k** 的值递减为`k=k-interval`。
**STEP7** :设置`interval = interval /2`转到第 2 步
**第 8 步**:返回排序数组 **A****

## GO 源代码

```go
package main
import "fmt"
func main() {
    fmt.Println("Enter the size of the array")
 var n int
 fmt.Scan(&n)
 A := make([]int, n, 100)
fmt.Println("Enter elements of the array : ")

 for i := 0; i < n; i++ {
  fmt.Scan(&A[i])
 }
fmt.Println("Sorted array:")
   fmt.Println(shellSort(A, n))

}

func shellSort(A []int, n int) []int {

    for interval := int(n/2); intervel > 0; interval /= 2 {
     for j := interval; j < n; j++ {
      for k := j; k >= interval && A[k-intervel] > A[k]; k -= interval {
       A[k], A[k-interval] = A[k-interval], A[k]
      }
     }
    }
return A

} 

```

## 输出

```go
Enter the size of the array
5
Enter elements of the array : 
32
24
56
85
13
Sorted array:
[13 24 32 56 85] 
```