# Go 程序：实现归并排序

> 原文：<https://learnetutorials.com/golang/programs/Implement-merge-sort>

实现数据排序的方法有很多。每当我们比较每种排序算法的效率和速度时，其中一些算法或多或少比另一些算法更高效、更快。当我们比较分类工作时，我们可以说没有最好的一体化解决方案对所有情况都最有效。这意味着每种算法都有自己的重要性。在本节中，我们将重点关注归并排序算法。

归并排序是基于分治策略的经典排序算法之一，这意味着我们将问题分成更小的块，这将有助于您更容易地解决问题。
归并排序的基本思想是将输入数组拆分为两个子数组。通过递归过程求解每个单独的子数组，然后在最后，我们将两个排序的数组合并为最终的排序数组。我们可以说归并排序比冒泡排序快得多。请注意，在所有 3 种情况下(最差、平均和最佳)，归并排序的时间复杂度都是θ(nLogn)。

## 如何实现归并排序

让我们了解归并排序的实现。

在这个 GO 程序中，我们正在导入“ **fmt** ”包，以将一些标准库包含到程序中。我们使用 fmt 包中定义的`fmt.scanln()`和`fmt.println()`方法接受用户的值。为了使用这些功能，我们需要导入“ **fmt** ”包。在 main 函数启动之后，在 Main 内部，我们正在执行整个程序。

在这个 Go 程序中，我们主要使用两个函数，递归**归并排序**函数和**合并**函数。
**merge sort**函数是一个递归函数，它调用自己两次，将数组分成两个大致相等的部分，然后调用 **merge()** 将这些子数组重新组合在一起，就像排序后的数组一样。

## 算法:

**STEP 1** :导入包**fmt**
T5】STEP 2:打开 **main()** 启动程序，GO 程序执行从**main()**
**STEP 3**开始:声明变量 **n** 。
**STEP 4** :将数组的大小读取为 **n**
**STEP 5** :定义数组**A[]**
**STEP 6**:使用‘**for loop**读取**A[**数组元素。
**STEP 7** :通过调用函数 **mergeSort(A** )进行归并排序。
**STEP 8** :使用**进行**循环显示排序后的数组。
**步骤 9** :退出

### 实现归并排序的步骤(一)

**步骤 1** :检查未排序数组 **A** 的长度是否小于 2。如果是，返回数组 A.
**STEP 2** :先将`mergeSort(A[:len(items)/2])`的返回值赋给变量**。
**STEP 3** :将`mergeSort(A[len(items)/2:]`的返回值赋给变量**秒**。
**STEP 4** :通过调用函数`merge(first, second`，将两个排序列表合并回一个排序列表。
**STEP 5** :将结果数组返回到**主**功能**

 **### 实现合并的步骤(第一步、第二步)

**STEP1** :将第一个和第二个数组分别赋值给 **a[]** 和 **b[]** 作为函数参数。
**STEP 2** :声明数组最终和循环变量 **i** 和 **j** 。
**第三步**:分配`i=0`和`j=0`。
**STEP 4** :迭代 2 个数组/切片最小长度的次数。
**STEP 5** :在每次迭代中，我们通过使用一个循环，将左边&右边的元素，即**a【I】**和**b【I】**进行比较，并将较小的元素插入到最终的数组**最终的**中，直到迭代结束。
**STEP 6** :插入所有缺失的元素，当我们用完迭代的时候。就像当一个子数组具有较小的元素时，另一个子数组将具有我们没有插入到结果数组中的元素**最终**。
**STEP 7** :返回结果数组**最终**。**  **## GO 源代码

```go
package main
import "fmt"
func main() {

        fmt.Println("Enter the size of the array")
 var n int
 fmt.Scan(&n)
 A := make([]int, n, 100)
fmt.Println("Enter elements of the array : ")

 for i := 0; i < n; i++ {
  fmt.Scan(&A[i])
 }

    fmt.Println("Sorted array:")
   fmt.Println(mergeSort(A))

}

func mergeSort(A []int) []int {
    if len(A) < 2 {
        return A
    }
    first := mergeSort(A[:len(A)/2])
    second := mergeSort(A[len(A)/2:])
    return merge(first, second)
}

func merge(a []int, b []int) []int {
    final := []int{}
    i := 0
    j := 0
    for i < len(a) && j < len(b) {
        if a[i] < b[j] {
            final = append(final, a[i])
            i++
        } else {
            final = append(final, b[j])
            j++
        }
    }
    for ; i < len(a); i++ {
        final = append(final, a[i])
    }
    for ; j < len(b); j++ {
        final = append(final, b[j])
    }
    return final
} 

```

## 输出

```go
Enter the size of the array
5
Enter elements of the array : 
3
8
2
6
1
Sorted array:
[1 2 3 6 8] 
```**