# Go 程序：在给定链表的第`k`个节点后插入一个新节点

> 原文：<https://learnetutorials.com/golang/programs/linked-list-insertion-of-a-new-node-after-the-kth-node>

链表是由一堆节点组成的线性数据结构，每个节点有两个属性:数据和下一个。这里的“下一个”是指向列表中下一个节点的指针。有太多的链表操作允许我们对链表执行不同的操作。例如，插入操作将向链表添加一个新节点。

在这个程序中，我们将创建一个单链表，并在链表的第 Kt 个节点后添加一个新节点。为了完成这个任务，我们将通过遍历列表直到头部变为零来找到第 k <sup>个</sup>节点。如果我们在列表中找到第 k <sup>个</sup>节点，那么通过在第 k <sup>个</sup>节点之后添加一个新节点来更新链表。让我们更详细地看看这个程序。

## 如何在第 K <sup>个</sup>节点后插入新节点

在这个程序中，我们将重点关注如何使用 GO 语言在给定链表中的第 k <sup>个</sup>值节点后添加一个新节点。

有一个 **fmt** 包，用来导入一些标准库到程序中。使用内置功能`fmt.println()`打印屏幕上的任何内容，使用`fmt.scanln()`读取数据。这些功能在 **fmt** 包中定义。所以我们需要导入 **fmt** 包来使用这些功能。之后，打开主功能。我们在主函数里面做整个程序，这是我们程序的起点。

这里我们使用一个结构来定义一个节点。通过调用函数`NewNode`生成链表，该函数通过将数据赋给节点值并将节点的指针更改为下一个节点来创建节点。现在**头**是链表的起始节点。

通过调用函数`TraverseLinkedList(head)`显示链表中的所有节点，该函数遍历一个从**头**开始的列表，直到找到参考值为**零**。

现在你有了一个链表。每当你想在给定链表中的第 k <sup>个</sup>节点后添加一个节点时，使用`fmt.scanln`读取你想添加的数据作为第一个节点，并将其传递给函数`AddAfterKthNode`。这个函数定义了一个接受链表头和输入值的方法。检查**头**是否等于零，表示列表为空。如果头等于零，则返回**头**，不添加任何节点。否则，通过在第 k <sup>个</sup>节点后添加一个新节点来更新链表。为此，遍历新节点所需位置之前的节点。如果找到第 k<sup>个值位置，则为新节点分配内存并存储数据。更改下一个指针，在链表中第 k <sup>个</sup>节点之后包含一个新节点。最后，将链表的头部返回给主函数。您可以通过调用功能`TraverseLinkedList`来显示更新后的链表。</sup>

下面给出了 Go 程序中在给定链表中第 k <sup>个</sup>节点后添加新节点的步骤。

## 算法:

**STEP 1** :开始
**STEP 2** :定义节点的结构
**STEP 3** :通过调用函数`NewNode()`创建链表。这里头是链表的开始节点。
**STEP 4** :调用功能`TraverseLinkedList(head`显示输入链表。
**STEP 5** :读取要作为**项插入到链表中的新数据**
**STEP 6** :通过调用`head = AddAfterKthNode(head, 10, item)`
**在链表的第 kth 个节点后添加新节点 STEP 7** :通过调用函数`TraverseLinkedList(head)`显示更新后的链表。
**步骤 8** :退出

### 实现新节点(值为整数)的步骤:

**步骤 1** :将变量 **n** 声明为节点。
**STEP 2** :创建节点 **n** ，方法是将数据分配到其节点值中，并将该节点的指针更改为下一个节点。
**STEP 3** :返回节点 **n**

### 实现 tratravelinkedlist _ head *节点的步骤):

**STEP 1** :遍历以**开头的列表**显示链表中的所有节点，直到找到参考值为**零**。

### 实现 AddAfterKthNode(head *Node，k，data int)的步骤:

**STEP 1** :定义一个接受链表**头**的方法。
**STEP 2** :检查，表头是否等于空，表示列表为空。如果 head == nil，则返回 **head** ，不添加任何节点。否则执行第 3 步
**第 3 步**:定义一个节点 **temp** ，该节点将首先指向列表的头部。
**第四步**:遍历列表，直到**温度**指向零。
**STEP 5** :在每次迭代中，检查 **temp** 是否会指向 k <sup>第</sup>个值节点。如果是，请执行以下步骤

*   定义新节点 **ptr**
*   新节点 **ptr** 将插入到第 k 个<sup>节点</sup>之后，这样**温度**将指向新节点 **ptr** ，而 **ptr** 将指向**温度**。

**第六步**:返回**头**。

## GO 源代码

```go
package main
import (
   "fmt"
)
type Node struct {
   value int
   next *Node
}
func NewNode(value int, next *Node) *Node{
   var n Node
   n.value = value
   n.next = next
   return &n
}
func TraverseLinkedList(head *Node){
   temp := head
   for temp != nil {
      fmt.Printf("%d ", temp.value)
      temp = temp.next
   }
   fmt.Println()
}
func AddAfterKthNode(head *Node, k , data int) *Node{
  if head == nil{
      return head
   }
   temp := head
   for temp != nil{
      if temp.value == k{
         ptr := NewNode(data, nil)
         ptr.next = temp.next
         temp.next = ptr
         break
      }
      temp = temp.next
   }
   return head
}
func main(){
   head := NewNode(30, NewNode(10, NewNode(80, NewNode(40, nil))))
   fmt.Printf("Input Linked list is: ")
   TraverseLinkedList(head)
   var item int;
   fmt.Printf ("\nEnter the item which you want to insert?\n") 
   fmt.Scan(&item;)

   head = AddAfterKthNode(head, 10, item)
   fmt.Printf("Updated Linked List by Inserting New Node After %dth Value Node:\n", 10)
   TraverseLinkedList(head)
} 

```

## 输出

```go
Input Linked list is: 30 10 80 40 

Enter the item which you want to insert?
75
Updated Linked List by Inserting New Node After 10th Value Node:
 30 10 75 80 40 
```