# Go 程序：从链表中删除第一个节点

> 原文：<https://learnetutorials.com/golang/programs/delete-the-first-node-from-a-linked-list>

在某些情况下，我们希望从链表中取消一些节点。这种情况我们可以通过使用链表的删除操作来处理。删除是链表的重要操作之一，允许从链表中删除节点。

我们可以说链表是一个线性的数据结构，包括一堆节点，每个节点有两个属性，比如数据和下一个指针。这里的“下一个”是指向列表中下一个节点的指针。有太多的链表操作允许我们对链表执行不同的操作。例如，删除操作将从链表中删除一个节点。

在这个程序中，我们将创建一个单链表，并从链表中删除第一个节点。为了完成这个任务，我们将迭代列表，直到头部变为零。如果该节点不是零，则转到标题的下一个节点，并通过将该下一个节点更改为标题来更新链表。让我们更详细地看看这个程序。

## 如何从链表中删除第一个节点

在这个程序中，我们将关注如何使用 GO 语言从给定的链表中删除第一个节点。
有一个 fmt 包，用于将一些标准库导入程序。使用内置功能`fmt.println()`打印屏幕上的任何内容，使用`fmt.scanln()`读取输入数据。我们需要导入“ **fmt** 包来使用这些功能。之后，打开主功能。我们在主函数里面做整个程序，这是我们程序的起点。

这里我们使用一个结构来定义一个节点。函数`NewNode`通过将数据赋给链表的节点值，并将节点的指针更改为下一个节点，从而创建链表的节点。现在**头**是链表的起始节点。

函数`TraverseLinkedList(head)`通过遍历以**头**开始的列表来显示链表中的所有节点，直到找到参考值为**零**。

每当你想从给定的链表中删除第一个节点时，调用函数`DeleteFirstNode(head)`。它定义了一个接受链表头的方法。检查头是否等于零，这意味着列表是空的。如果**头**等于零，则返回该头，不删除任何节点。否则，通过删除第一个节点来更新链接列表。这意味着将头的下一个节点作为新头，并通过为其指针指定 **nil** 值来取消旧头。最后，将新的头部返回到主功能。您可以通过调用功能`TraverseLinkedList`来显示更新后的链表。

下面给出了在 Go 程序中用于从链表中删除第一个节点的步骤。

## 算法:

**STEP 1** :开始
**STEP 2** :定义节点的结构
**STEP 3** :通过调用函数`NewNode()`创建链表。这里头是链表的开始节点。
**STEP 4** :调用功能`TraverseLinkedList(head)`显示输入链表。
**STEP 5** :调用`DeleteFirstNode(head)`
**删除链表中的第一个节点 STEP 6** :调用函数`TraverseLinkedList(head)`显示更新后的链表。
**步骤 7** :退出

### 实现新节点(值)的步骤:

**步骤 1** :将变量 **n** 声明为节点。
**STEP 2** :创建节点 **n** ，方法是将数据分配到其节点值中，并将该节点的指针更改为下一个节点。
**STEP 3** :返回节点 **n**

### 实现 tratravelinkedlist _ head 的步骤):

**STEP 1** :通过遍历以**开头的列表**来显示链表中的所有节点，直到我们发现参考值为**零**。

### 实现删除第一个节点(头)的步骤:

**STEP 1** :定义一个接受链表**头**的方法。
**STEP 2** :检查，头部是否等于零。如果**头**等于值 nil，则返回头，不删除任何节点。否则做第三步
**第三步**:取**头**的下一个节点，通过删除第一个节点将其设置为新头。
**第四步**:退回新头。

## GO 源代码

```go
package main
import "fmt"
type Node struct {
   value int
   next *Node
}
func NewNode(value int, next *Node) *Node{
   var n Node
   n.value = value
   n.next = next
   return &n
}
func TraverseLinkedList(head *Node){
   temp := head
   for temp != nil {
      fmt.Printf("%d ", temp.value)
      temp = temp.next
   }
   fmt.Println()
}
func DeleteFirstNode(head *Node) *Node{
   if head == nil{
      return head
   }
   newHead := head.next
   head.next = nil
   return newHead
}
func main(){
   head := NewNode(30, NewNode(10, NewNode(80, NewNode(70, nil))))
   fmt.Printf("Input Linked list is: ")
   TraverseLinkedList(head)
   head = DeleteFirstNode(head)
   fmt.Printf("Updated linked list after deleting first node: ")
   TraverseLinkedList(head)
} 

```

## 输出

```go
Input Linked list is: 30 10 80 70 
Updated linked list after deleting first node: 10 80 70 
```