# Go 程序：从链表中删除第`k`个节点

> 原文：<https://learnetutorials.com/golang/programs/delete-the-kth-node-from-a-linked-list>

链表是一种基本的数据结构，由一堆节点组成，每个节点有两个属性，如数据和指针 next。这里的“下一个”是指向列表中下一个节点的指针。有太多的链表操作允许我们对链表执行不同的操作。例如，删除操作将从链表中删除一个节点。

在这个程序中，我们将创建一个单链表，并从链表中删除 Kth 节点。为了完成这个任务，我们将通过遍历列表直到头部变为零来找到第 k <sup>个</sup>节点。如果我们在列表中找到了第 k 个<sup>节点，那么通过删除第 k 个<sup>节点来更新链表。让我们更详细地看看这个程序。</sup></sup>

## 如何删除第 K <sup>个</sup>节点

在这个程序中，我们将关注如何使用 GO 语言从给定的链表中删除 kth 节点。
有一个 fmt 包，用于将一些标准库导入程序。使用内置功能`fmt.println()`在屏幕上打印任何东西。我们需要导入“fmt”包来使用这个功能。之后，打开主功能。我们在**主**功能里面做整个程序，这是我们程序的起点。

这里我们使用一个结构来定义一个节点。函数`NewNode`通过将数据分配到其节点值并将节点的指针更改为下一个节点来创建链表的节点。现在头部是链表的开始节点。

函数`TraverseLinkedList(head)`通过遍历从头部开始的列表来显示链表中的所有节点，直到发现参考值为零。

每当你想从给定的链表中删除第 k <sup>个</sup>节点并调用函数`DeleteKthNode(head,k)`。在这个函数中，它定义了一个方法，该方法接受链表的头和您想要删除的输入值。检查头是否等于零，这意味着列表是空的。如果头等于零，返回头，不删除任何节点。否则，通过删除第 k <sup>个</sup>节点来更新链表。为此，遍历链表找到第 k 个<sup>节点的位置。如果它找到第 k <sup>个</sup>节点，那么用它的下一个节点的下一个值覆盖该节点的下一个值。如果没有找到第 k <sup>个</sup>节点的节点值，则返回头，不删除任何节点。</sup>

最后可以通过调用`TraverseLinkedList`函数显示更新后的链表。

下面给出了在 Go 程序中从链表中删除第 k <sup>个</sup>节点的步骤。

## 算法:

**STEP 1** :开始
**STEP 2** :定义节点的结构
**STEP 3** :通过调用函数`NewNode()`创建链表。这里头是链表的开始节点。
**STEP 4** :调用功能`TraverseLinkedList(head)`显示输入链表。
**STEP 5** :调用`DeleteKthNode(head, k)`
**从链表中删除第 kth 个节点 STEP 6** :调用`TraverseLinkedList(head)`函数删除节点后显示链表。
**步骤 7** :退出

### 实现新节点(值)的步骤:

**步骤 1** :将变量 **n** 声明为节点。
**STEP 2** :创建节点 **n** ，方法是将数据分配到其节点值中，并将该节点的指针更改为下一个节点。
**STEP 3** :返回节点 **n**

### 实现 tratravelinkedlist _ head 的步骤):

**STEP 1** :遍历以**开头的列表**显示链表中的所有节点，直到找到参考值为**零**。

### 实现 DeleteKthNode(head，k)的步骤:

**STEP 1** :定义一个接受链表**头**的方法。
**STEP 2** :检查，表头是否等于零，表示列表为空。如果头等于零，则返回**头**，不删除任何节点。否则，执行步骤 3。
**STEP 3** :定义一个节点 **temp** ，该节点将首先指向列表的**头**。
**步骤 4** :遍历列表，直到**温度**指向零。
**STEP 5** :在每次迭代中，检查 **temp** 是否会指向 k <sup>第</sup>个节点。如果是，用下一个节点的下一个值覆盖该节点的下一个值。否则，返回**头**不删除任何节点。

## GO 源代码

```go
package main
import "fmt"
type Node struct {
   value int
   next *Node
}
func NewNode(value int, next *Node) *Node{
   var n Node
   n.value = value
   n.next = next
   return &n
}
func TraverseLinkedList(head *Node){
   temp := head
   for temp != nil {
      fmt.Printf("%d ", temp.value)
      temp = temp.next
   }
   fmt.Println()
}
func DeleteAfterKthNode(head *Node, k int) *Node{
   // Delete after Kth node.
   if head == nil{
      return head
   }
   temp := head
   for temp != nil{
      if temp.value == k{
         temp.next = temp.next.next
      }
      temp = temp.next
   }
   return head
}
func main(){
   head := NewNode(320, NewNode(110, NewNode(402, NewNode(503, nil))))
   fmt.Printf("Input Linked list is: ")
   TraverseLinkedList(head)
   head = DeleteAfterKthNode(head, 402)
   fmt.Printf("Node %d is deleted.\nUpdated Linked List after deletion is:\n", 402)
   TraverseLinkedList(head)
} 

```

## 输出

```go
Input Linked list is: 320 110 402 503 
Node 402 is deleted.
Updated Linked List after deletion is:
320 110 402 
```