# Go 程序：实现从链表中删除最后一个节点

> 原文：<https://learnetutorials.com/golang/programs/deletion-of-the-last-node-from-a-linked-list>

这里我们主要集中在删除链表的最后一个节点。在此之前，我们应该对链表有一个基本的了解。链表是计算机编程中的线性数据结构。链表中的所有元素都是用指针链接的。这意味着它有一个或多个节点，每个节点包含数据和访问下一个节点的指针。删除是重要的链表操作之一，有助于从链表中删除一个节点。因此，要删除链表的最后一个节点，我们应该找到第二个最后一个节点，并使该节点的下一个指针为空。

在这个程序中，我们将创建一个单独的链表，删除给定链表的最后一个节点，并更新链表的头部。为了完成这个任务，我们将通过遍历列表找到倒数第二个节点。如果我们找到了列表中的第二个最后一个节点，那么通过将它的指针设置为 nill 来删除最后一个节点，从而更新链表。让我们更详细地看看这个程序。

## 如何删除链表的最后一个节点

在这个程序中，我们将关注如何使用 GO 语言从给定的链表中删除最后一个节点。

有一个 fmt 包，用于将一些标准库导入程序。使用内置功能`fmt.println()`在屏幕上打印任何东西。我们需要导入“ **fmt** 包才能使用该功能。之后，打开主功能。我们在主函数里面做整个程序，这是我们程序的起点。这里我们使用一个结构来定义一个节点。在这个程序中使用另外三个重要的函数，如 NewNode、TraverseLinkedList 和 DeleteLastNode。我们可以更详细地看到这些功能。

函数`NewNode`通过将数据分配到其节点值并将节点的指针更改为下一个节点来创建链表的节点。现在头部是链表的开始节点。

函数`TraverseLinkedList(head)`通过遍历从头部开始的列表来显示链表中的所有节点，直到发现参考值为零。

每当你想从给定的链表中删除最后一个节点时，调用函数`DeleteLastNode(head)`。这个函数定义了一个接受链表头的方法。检查头是否等于零，这意味着列表是空的。如果头等于零，返回头，不删除任何节点。否则，声明一个临时指针 **temp** ，并将其分配给列表的头部。它可以帮助您遍历链表来找到最后一个节点。这意味着我们可以通过迭代一个循环来找到最后一个节点，直到条件`temp.next.next != ni` l .当“`temp.next.next = nill"`时，我们可以理解`temp.next`成为第二个最后一个节点位置。通过将`temp.next` 的值设置为**零**来删除链表的最后一个节点。最后，这个函数将返回链表的**头**。

通过调用功能`TraverseLinkedList`显示更新后的链表。

下面给出了在 Go 程序中用于从给定的链表中删除最后一个节点的步骤。

## 算法:

第一步:开始
第二步:定义节点的结构
第三步:通过调用函数`NewNode()`创建链表。这里头是链表的开始节点。
第四步:调用`TraverseLinkedList(head)`功能显示输入链表。
步骤 5:通过调用`DeleteLastNode(head)`从链表中删除最后一个节点。
第六步:调用`TraverseLinkedList(head)`功能，删除节点后显示链表。
步骤 7:退出

### 实现新节点(值)的步骤:

第一步:将变量 **n** 声明为节点。
步骤 2:通过将数据分配到节点值并将节点的指针更改为下一个节点来创建节点 **n** 。
步骤 3:返回节点 **n**

### 实现 tratravelinkedlist _ head 的步骤):

第一步:通过遍历以头开始的列表来显示链表中的所有节点，直到我们发现引用值为空。

### 实现删除最后一个节点(头)的步骤。

步骤 1:定义一个接受链表头的方法。
第二步:检查，表头是否等于零，表示列表为空。如果头等于零，则返回头。否则执行第三步
第三步:声明一个临时指针 **temp** 并将其分配给列表的头部。
步骤 4:遍历列表，以便到达链表的倒数第二个节点。即:用条件`temp.next.next != nil`迭代循环。如果循环条件为真，则将`temp.next`值改写为**温度**。
步骤 5:通过将`temp.next`的值设置为**零**来删除链表的最后一个节点。
第六步:返回**头**

## GO 源代码

```go
package main
import (
   "fmt"
)
type Node struct {
   value int
   next *Node
}
func NewNode(value int, next *Node) *Node{
   var n Node
   n.value = value
   n.next = next
   return &n
}
func TraverseLinkedList(head *Node){
   temp := head
   for temp != nil {
      fmt.Printf("%d ", temp.value)
      temp = temp.next
   }
   fmt.Println()
}
func DeleteLastNode(head *Node) *Node{
   if head == nil{
      return head
   }
   temp := head
   for temp.next.next != nil{
      temp = temp.next
   }
   temp.next = nil
   return head
}
func main(){
   head := NewNode(20, NewNode(40, NewNode(80, NewNode(90, nil))))
   fmt.Printf("Input Linked list is: ")
   TraverseLinkedList(head)
   head = DeleteLastNode(head)
   fmt.Printf("Last node id deleted\nUpdated linked list:")
   TraverseLinkedList(head)
}

```

## 输出

```go
Input Linked list is: 20 40 80 90 
Last node id deleted
Updated linked list:20 40 80 
```