# Go 程序：实现结构方法

> 原文：<https://learnetutorials.com/golang/programs/implement-the-structs-method>

在本节中，我们将把注意力集中在 structs 方法上。在那之前，现在你可以理解什么是结构了。Golang 中的结构是用户定义的类型，包含命名字段/属性的集合。这意味着它将可能不同类型的项目组合成单一类型或单一单元。通过使用 struct 关键字，您可以在 Go 上定义一个结构。

**示例:**

键入员工结构{
id int
姓名字符串
职位字符串
工资 int

这里 type 关键字用于引入一种新的类型。后面是雇员类型的名称。关键字 struct 用于指示我们正在定义一个结构类型，并在大括号内列出结构的字段，如 id、姓名、职位和工资。这里每个字段都有一个名称和一个类型。

## 转到结构方法

在 Go 编程中，结构也可以通过使用结构对象来定义方法。当一个方法被附加到结构上时，它就像一个普通的函数一样工作。但是它还需要指定它的类型。

```go
 type type_name struct { }
func (m type_name) function_name() int {
    //code
} 

```

## 如何在 Go 中实现结构方法

在这一节中，我们将把注意力集中在结构上。例如，一个员工记录有一个 id、姓名、职位、一天的工资和休假。将这五个属性组合成一个单一的结构**员工**是有意义的。通过使用结构概念，您可以读取和显示员工记录。

下面给出的程序将解释如何在 Go 编程中创建一个结构，创建一个实例，为结构实例设置值，读取和打印结构实例。

这里我们可以使用内置函数`fmt.scanln()`读取输入值。输出可以使用内置功能`fmt.println()`显示。两种内置功能都在 fmt 包中定义。为了使用这些功能，我们应该将“ **fmt** 包导入到我们的程序中。

下面给出了执行程序中实现结构方法的步骤。

## 算法

第一步:开始
第二步:导入包 **fmt**
第三步:定义一个结构**员工**，包括员工的身份证、姓名、职位、一天的工资和假期。
STEP 4:打开 **main()** 启动程序，GO 程序执行从 **main()**
开始 STEP 5:声明结构变量 **emp1**
STEP 6:使用 **emp1**
读取员工详细信息 STEP 7:使用 struct 方法`show()`显示员工详细信息。
第八步:调用 struct 方法 `totalWorkingDays()`
将员工工作日计算成 **w** 第九步:显示员工工作日
第十步:调用 struct 方法`calculateSalary(w)`
计算显示员工当月工资第十一步:退出

### 实现结构方法`show()`的步骤。

第一步:借助结构对象 **e** 显示学生详细信息

### 实现结构方法的步骤总计工作日()

第一步:返回`30 - e.leave`的值

### 实现结构方法计算工资的步骤(工作日)

第一步:返回`workingDays  X e.daySalary`的值

## GO 源代码

```go
package main                                                                 

import (                                                                     
 "fmt"                                                                     
)                                                                            

//define a struct 'Employee'                                                  
type Employee struct {                                                        
 id int                                                                   
 name string    
    post string  
    daySalary int                                                        
 leave  int

}                                                                            
   func (e Employee) show() {
 // displays student details  
fmt.Println("Employee Details")                                            
 fmt.Println("----------------")                                          
 fmt.Printf("Id: %d\n", e.id)                                      
 fmt.Printf("Name: %s\n", e.name)     
     fmt.Printf("post: %s\n", e.post)
     fmt.Printf("Salary of one day: %d\n", e.daySalary)                 
 fmt.Printf("leave: %d\n", e.leave)                                

}

// Methods to calculate total working days using struct instance
func (e Employee) totalWorkingDays() int {
 return (30-e.leave)
}

// Struct Methods to calculate total Salary of month
func (e Employee)calculateSalary(workingDays int) int {
 return (workingDays * e.daySalary)
}

func main() {                                                                
 var emp1 Employee                                                     

 // setting values                                                        
 emp1.id = 101                                                          
 emp1.name ="Employee 1"
 emp1.post ="Admin"
 emp1.daySalary=500
  emp1.leave=5                              

 // displays Employee details 
    emp1.show()

    // displays Employee Working Days
    var w int
    w = emp1.totalWorkingDays()
 fmt.Printf("Total Working Days: %d\n", w)

 // displays Employee Salary
    fmt.Printf("Total Salary of month: %d\n", emp1\. calculateSalary(w))

} 

```

## 输出

```go
Employee Details
----------------
Id: 101
Name: Employee 1
post: Admin
Salary of one day: 500
leave: 5
Total Working Days: 25
Total Salary of month: 12500
```