# HTML 锚点

> 原文：<https://learnetutorials.com/html/anchor-tags>

在本 HTML 教程中，您将了解到 HTML 中的所有锚点。我们还将讨论锚标签在 HTML 中的不同用途。

## 什么是 HTML 中的锚点标签？

链接，通常称为超链接，是将一个 web 源连接到另一个 web 源的链接。用户可以使用链接在全球任何服务器上从一个网页导航到另一个网页。一个连接有两个端点，称为锚。链接从源锚点开始，到目标锚点结束，目标锚点可以是图像、音频或视频剪辑、PDF 文件、HTML 页面或文档本身中的元素等。

在大多数浏览器中，默认情况下链接显示如下:

*   未访问的链接以蓝色突出显示。
*   已访问的链接以紫色突出显示，并带有下划线。
*   活动链接以红色突出显示。

**语法**

在 HTML 中，使用`<a>`标签指定链接。链接或超链接可以是一个单词、一组单词或一幅图像。用户在浏览器中看到并点击的链接部分总是在开始的`<a>`标签和结束的`</a>`标签之间。

```html
 <a href="url">Link text</a> 

```

### 锚标签示例

```html
 <a href="https://www.google.com/">Google Search</a>
<a href="https://www.learnetutorials.com/"> Learn E Tutorials </a>
<a href="images/smile.jpg">
    <img src="smile.jpg" alt="kites">
</a> 

```

## 如何设置锚标签的目标？

目标属性将浏览器导向引用内容的位置。有四个不同的目标，每个目标都有自己的以下划线(_)字符开头的名称:

*   **_blank** —该命令在新窗口或选项卡中打开被引用的文档。
*   **_ 父级** —该命令在父级窗口中显示链接的文档。
*   **_self** —在与原始文档相同的窗口或选项卡中显示链接的文档。因为这是默认值，所以没有必要明确提及。
*   **_top** —在浏览器窗口中完整显示链接文档。

### 锚标签示例

```html
 <a href="/about-us.php" target="_top">About Us</a>
<a href="https://www.google.com/" target="_blank">Google</a>
<a href="images/sky.jpg" target="_parent">
    <img src="sky-thumb.jpg" alt="Cloudy Sky">
</a> 

```

## 如何创建书签锚点？

您还可以利用书签锚点将人们指引到当前网页的特定区域。如果你有一个冗长的网站，书签是非常有用的。使用锚点标签创建书签只需要两个步骤:将 id 属性添加到您希望跳转的元素中，然后使用`<a>`标签的 href 属性的值。

### 锚标签示例

```html
 <a href="#sectionA">Jump to Section A</a>
<h2 id="sectionA">Section A</h2>
<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit...</p> 

```

### 最常用的锚点标签属性

| 属性 | 价值观念 | 描述 |
| 字符集 | 字符集 | 指定了引用资源的字符编码。 |
| 用灯芯绒做的衣物 | x，y 坐标 | 指定了链接在屏幕上的位置。 |
| 下载 | 文件名 | 当用户单击链接时，此属性指定是否下载关联的资源，而不是转到该资源。 |
| 超链接 | 统一资源定位器 | 指定目标文档或在线资源的位置(如图像、PDF 或任何其他媒体文件)。 |
| 元首万岁 | 语言代码 | 指定了引用文档的语言。该属性只能在给出 href 属性时使用。 |
| 媒体 | 媒体查询 | 指定为其创建链接资源的介质类型。 |
| 名字 | 文本 | 指定了锚点的名称。相反，使用全局属性 id。 |
| 能量损耗率 | 备用作者书签帮助许可证下一个 nofollow noreferrer 预取上一个搜索标记 | 描述超链接文档和引用资源之间的连接。仅当 href 属性存在时才使用此属性。 |
| 发动机的旋转 | 发动机的旋转 | 描述链接文档与原始文档的连接(与 rel 属性相反)。 |
| 形状 | 矩形圆形多边形默认值 | 指定热点区域的形式，即超链接的可选区域。 |
| 目标 | _blank _parent _self _top 框架名称 | 定义将用于打开 href 属性中提供的链接资源的目标。 |
| 类型 | 内容类型 | 指定所连接素材的内容类型(MIME 类型)，如“图像/jpeg”、“文本/html”等。 |