# Java 中的变量

> 原文：<https://learnetutorials.com/java/variables>

java 变量是计算机内存中可以存储数据值的保留空间。您可以为这些内存位置中的每一个分配一个特定的名称，但是应该遵循命名约定。

通常，java 程序以变量声明开始，因为变量存储了 java 程序执行任务所需的信息。信息或数据可以是简单的文本、代码或数字，甚至是简单的预定义计算。因此，存储数据的变量具有特定的数据类型，您将在下一个教程中详细学习 Java 中的数据类型。

### 示例:程序中的变量

```java
 public class Student {

 public static void main(String[] args) {
 String name;
 int age;

 }

} 

```

在上面的代码中，`name`是字符串数据类型的变量，`age`是整数数据类型的另一个变量。

## 如何在 Java 中命名变量

虽然“Java”提供了根据您的意愿和方便使用变量名的自由，但是您必须遵守某些规则。

1.  变量名只能是字母(A，A，B，B)、数字(0，1，2)和下划线(_)的组合。
2.  变量必须以字母开头，或者某些编译器支持下划线(_)或美元符号($)。但不能以数字开头。
3.  因为 Java 是一种区分大小写的语言，所以大写(num)和小写(NUM)字母的处理是不同的。
4.  特殊字符(/，；命名变量时，不允许使用，:)和符号(#，@)。
5.  变量名必须不同于保留关键字。这意味着像 int、float 等保留关键字不能用于命名变量。
6.  不允许有空格。
7.  最后但同样重要的是，使用简短、有意义(不超过 31 个字符)的变量名更安全。

下表给出了有效和无效变量名的概念。

| **有效变量名称** | **无效变量名称** |
| 年龄，_ 年龄，$年龄 | 17 岁 |
| 一，一 | int，float，for，while |
| 螺柱 1、螺柱 2 | 螺柱#、螺柱@2、螺柱 1 |

除此之外，java 几乎没有不需要遵循的命名约定，但是许多 java 开发人员会实践这些约定来保持 Java 代码的熟练程度。遵循这些约定会提高代码的可读性。下面列出了几个命名约定:

1.  始终用小写写变量名，如`age`、`name`等。
2.  如果变量名由多个单词组成，请将每个后续单词的首字母大写，即`studName`、`studAge`、`studFatherName`等。
3.  存储常数值的变量(静态最终字段)总是以大写字母命名，每个单词之间带有下划线。例:`EXCHANGE_RATE`。

## 如何用 Java 声明一个变量

像在其他编程语言中一样，在 java 中，所有将要在程序中使用的变量都必须首先声明。正是因为这两个原因

1.  编译器必须知道要为变量保留多少空间才能正常运行。分配的空间必须足够，并且不能过大，以免造成内存滥用。
2.  编译器必须识别数据，无论它是数字还是字母，这就是为什么必须声明“类型”。除此之外，为了便于操作，应该给它一个有意义的名称(称为标识符)。

变量声明语法涉及两个重要部分，如下所示，一个是数据类型，另一个是变量名。变量声明应该总是以分号结尾，除非编译器会引发终止错误。此外，如果多个变量拥有相同的数据类型，java 提供了在一行中声明它们的自由。

**语法**:

```java
 datatype variable_name; 

```

例如，

```java
 int num1; 
int num 2; 
float f1,f2; 

```

这里，`int`表示整数，`float`表示小数。`int`和`float`是数据类型，`num1`、`num2`、`f1`、`f2`是标识符(变量名)。用特定数据类型声明的变量将只接受该特定数据类型的值。这里`num`只能取整数值，如果我们试图存储任何其他数值，比如字符到数字，那么它会产生一个错误。

## 如何在 Java 中初始化变量

声明完成后，您可以根据需要自由使用分配的空间(即变量)。这个声明的变量最初包含垃圾值，即未定义的值。如果您希望最初分配一些值，您可以在赋值运算符“`=`”的帮助下完成。变量初始化可以在声明时执行，也可以稍后赋值。

**语法**:

```java
 datatype variable_name = value; 

```

变量初始化的一些示例如下所示:

```java
 int num1 = 4; 
float f1 ;
f1 = 2.5; 

```

除非用关键字 final 声明，否则变量总是在其空间中分配最新的值。见下面的例子，

```java
 public class Student {

    public static void main(String[] args) {
        String name = "TOM";
        int age = 17;
        age = 20;

        System.out.println("Name:" + name);
        System.out.println("Age:" + age);

    }

} 

```

**输出:**

```java
 Name:TOM
Age:20 
```

在上面的例子中，最初，变量`age`存储值`17`，但是随着时间的推移，它遇到了`age`被分配了一个新值`20`。所以新的值`20`会覆盖先前的值`17`，因为变量没有用关键字`final`声明。因此它显示年龄为`20`。

如果将变量声明为`final`并尝试为其赋值，结果将是错误的。

## 如何显示变量

现在要用 java 显示变量，我们可以使用`println()`方法。让我们借助一个例子来理解这一点:

```java
 public class Sum {

    public static void main(String[] args) {
        int num1 = 4;
        int num2 = 5;
        System.out.println("First number is : " + num1);
        System.out.println("Second number is : " + num2);

        int sum = num1 + num2;
        System.out.println("Sum is " + sum);
    }

} 

```

这里变量`num1`和`num2`分别存储整数值 4 和 5。变量`sum`包含`num1`和`num2`的附加值。使用`println()`方法，显示变量中存储的值。为了给文本加上变量，我们可以使用`+`字符。

**输出:**

```java
 First number is : 4
Second number is : 5
Sum is 9 
```

## java 中变量的类型

Java 描述了 4 种类型的变量。它们如下所示:

1.  局部变量
2.  实例变量(非静态字段变量)
3.  类变量(静态字段变量)
4.  因素

### 局部变量

局部变量是在方法、构造函数或代码块中定义的变量。变量的范围仅限于该方法或代码块。因此，我们可以说这种类型的变量只有局部作用域，这意味着变量是在进入代码块或被方法调用时创建的，而在退出代码块或返回方法时被销毁。

### 示例:说明局部变量

```java
 void method()
{
      int num = 5;   // Local Variable 
} 

```

这里，变量`num`绑定到函数`method()`。

### 实例变量

实例变量是定义在类内部但在方法、构造函数或代码块外部的变量，并且不以关键字`static`作为前缀。这意味着实例变量是**非静态字段变量**。

实例变量属于一个对象，该对象又是一个类的实例，因此我们可以换句话说“**实例变量是类的实例**”。每当使用关键字`new`创建一个类的对象时，就会创建一个实例变量。这意味着实例变量对于它们的对象是唯一的。

### 示例:如何创建实例变量

```java
 Class Employee{
String employee_Name;
int employee_Id; 

```

在上面的例子中，创建了两个 emp 1 和 emp2 类的实例。

### 静态变量

如果变量以关键字 static 作为前缀，则称其为静态变量。java 中的静态变量是在类内部定义的，但在方法或代码块外部。静态变量也称为类变量，因为它们属于类而不是对象(实例)。因此，静态变量对于类的所有实例都是公共的，而不管实例的数量。换句话说，声明为静态的变量在类的所有对象之间共享。下面的代码片段将说明静态变量的工作原理。

### 示例:静态变量的使用

```java
 Class Employee{
String employee_Name;
int employee_Id;
static String company_Name= “ABC”; //Static 

```

### 因素

参数是与方法相关联的变量。调用方法时，参数用于将信息传递给方法。参数的范围位于声明参数的方法内部。

### 示例:说明参数的使用

```java
 public class ParamEx {

    static void MethodDisp(String fname) {
        System.out.println("Hai " + fname + " Welcome to LearneTutorials!!!");
    }

    public static void main(String[] args) {
        MethodDisp("Tom");
        MethodDisp("Jerry");

    }

} 

```

本例中，`ParamEx`是一个方法名为`MethodDisp()`的类。此方法的目的是显示消息“海(姓名)欢迎学习在线！！!"。在这里，该名称作为字符串参数`fname` 在方法调用中传递给`MethodDisp()`。

现在不要为参数而烦恼。毫无疑问，您将在未来的教程中学习。从现在开始，只要记住变量也可以以参数的形式出现。