# Java 中的循环

> 原文：<https://learnetutorials.com/java/loops>

在本教程中，我们将了解如何在 Java 编程中使用循环语句或迭代语句，根据某些条件多次运行一组指令。众所周知，一台计算机可以进行任意次数的重复运算，不知疲倦地进行 10 次、100 次，甚至 10 万次。所以，每种编程语言都有这样的特性来控制程序在执行次数上的流动。

## 循环的类型

**循环**是控制流语句，通过重复执行同一组语句直到满足终止条件，提供了一种控制程序流向不同部分的方法。计算机编程语言中的循环有助于一组指令/功能重复执行达所需次数，直到某些条件变为真。该代码块可以被执行任意次，从 0 到无穷大。如果一个循环永远持续下去，它被称为**无限循环**

Java 有三种类型的循环，用于多次执行一组指令/函数。这些重复语句循环的基本功能相似，但在语法和工作时间上有所不同。此外，控制结构根据控制语句在循环、入口控制循环或出口控制循环中的位置进行分类。
Java 中的三种循环类型如下:

1.  For 循环
2.  而循环/进入控制循环
3.  边循环边做/退出控制循环

### 让我们看看表格形式中循环的区别:

| 用于循环 | 

*   When you know exactly how many times the loop wants to be executed by a set of statements, it is recommended to use.
*   If the condition is true, the For loop statement will be executed; This means that a set of statements will be repeated zero or more times.
*   If the loop condition is false, the execution of this group of statements is stopped & control will jump to the statement after the loop.

 |
| 当循环 | 

*   You can use it when you are uncertain about the number of iterations. It is recommended to use when the number of iterations is not fixed. .
*   It executes the repetition specified in the text zero or more times, and it allows the code to execute repeatedly according to conditions.
*   If the condition is false, the execution will be stopped.
*   Also known as `Entry Control Loop.`

 |
| 边循环边做 | 

*   Also known as Exit Control Loop, it is a control flow statement that is executed at least on a part of the program, and the next level of execution depends on given conditions.
*   It is similar to a while loop, except that it executes the statement at least once before checking the Boolean condition.
*   If the condition is false, execute step.

 |

现在我们可以详细了解 java 中每个循环语句的工作原理。

## 对于 JAVA 中的循环:

在某些情况下，如果您知道执行一个代码块所需的次数，我们可以使用 For 循环。比如；如果你想检查在公司工作的员工的缺勤记录，你可以使用 for 循环，因为你知道员工在办公室的力量。
For 循环是一种控制流语句，用于多次重复执行一个代码块，直到满足特定条件。
For 循环结构如下:

*   初始化
*   条件/测试语句
*   更新语句/增量或减量表达式

for 循环语法的时间线如下:

```java
 for(initialization; testing_condition; increment/ decrement) 
{ 
// Block of codes 
/ statements …… 
…... 
} 

```

![flowchart ](img/a0189eea77b3b221eb1e2c27a89e6709.png)

### Java 中 for 循环的流程图

for 循环语句的执行如下:

1.  **循环中的初始化**

    在这一部分中，我们用一个起始值初始化控制变量，该值作为 for 循环的开始。for 循环的初始化部分只执行一次，它在测试条件之前的循环开始时执行。另外，请注意，初始化与否是可选的。

    我们来看一个例子；

    ```java
     for(int i=0; i<5; i++)
    {
    System.out.println(i);
    } 

    ```

    `int i=0` 是初始化部分，其中整数变量`i`用值`0`初始化。

2.  **循环测试条件**

    这一部分将为循环的执行提供测试条件。应仔细说明测试条件，以执行所需的执行次数或确定循环何时退出。测试条件在每次迭代中重复，并终止，直到条件得到满足。
    在上例中，测试变量的值，即`i <5`为待测条件；意味着变量 I 应该小于 5，否则，循环终止，控制将转移到循环后的语句。

3.  **更新循环中的语句**

    通常称为增量/减量表达式。它通常用于在每次迭代后更新控制变量，每次迭代完语句部分后执行。for 循环也允许负增量。
    `i++` 是上例中的更新语句。当条件为真时，控制进入执行语句/代码块的循环，一旦迭代全部完成，变量值增加`1, i=i+1`。对照条件测试控制变量的新值。

现在让我们看一个例子来理解 for 循环中的迭代。

```java
 class ForLoopEx {
    public static void main(String[] args) {
      for( int i=0; i<=10; i++)
         {
        System.out.println(i*i);
        }
    }
} 

```

该 for 循环执行 11 次，并在一行中打印数字 0 到 10 的平方。

**输出:**

```java
 0
1
4
9
16
25
36
49
64 
```

### For-Loop 的其他特性:

for 循环还有其他几项功能。

1.  #### 一次可以初始化多个变量。

    语句 n = 1；for(I = 0；i < = 10i++)可以写成

    ```java
     for(n=1; i=0; i<=10; i++) 

    ```

2.  #### The incremental part also has multiple parts.

    ```java
     for(n=1; i=10; n<=i; n++,i--)
    {
      ……
      ……
    } 

    ```

3.  #### The test conditions have any compound relationship, and the test need not be limited to loop control variables.

    ```java
     sum=0;
    for(i=1, i<10 && sum<50; i++)
    {
      ……
      ……
    } 

    ```

## Java 中循环的嵌套

在 Java 中，一个 for 循环中的另一个 for 循环称为循环嵌套。每条语句都应该被正确地表述，以便容易地确定哪些语句属于每个 for 循环。

```java
for (i=1; i<10; i++)
 {
    ……
    ……
    for (j=1; j<=5; j++)
    {
       …..
       …..
    }
    ……
    …..
 }
 …….
 …… 
```

例如，

```java
 public class NestedLoopEx {
    public static void main(String args[]) {
        int i, j, row = 10;

        for (i = 0; i & lt; row; i++) // loop 1 returns the number of rows
        {
            for (j = 0; j & lt; = i; j++) // loop 2 returns the number of columns
            {
                System.out.print( & quot;* & quot;); // prints *
            }
            System.out.println(); // next line
        }
    }
} 
```

**输出:**

```java
 * 
* * 
* * * 
* * * * 
* * * * * 
* * * * * * 
* * * * * * * 
* * * * * * * * 
```

### 增强的 for 循环

也为每个循环调用，用于检索元质数组，而不是使用数组索引。这个特性有助于遍历元质数组，这使得代码可读。for-each 循环中需要注意的一点是，它不允许以相反的顺序遍历元素。增强型 for 循环允许消除 for 循环中的迭代器，并从集合中检索元素。

语法:

```java
 for (Type Identifier : Expression)
 {  
  //statements;
 } 

```

在这里，

*   类型表示使用的数据类型或对象
*   标识符是指变量的名称
*   表达式是 java 的一个实例。朗。可迭代接口或数组

## 当循环

While 循环也称为**入口控制循环**。这是 Java 中最简单的循环结构，它检查为 while 循环指定的条件。While 循环是 Java 的基本循环语句，当特定的测试条件为真时，它会持续执行一个代码块。

while 循环计算必须返回布尔值的条件，如果条件为真，while 循环将执行 While 循环中的代码块。这将继续测试表达式，直到条件评估为 false，并且迭代的控制转移到循环之外。如果测试条件为假，它将不会执行，循环后的代码将立即执行。

在 java 程序中定义 While 循环语句的基本格式是:

```java
 Initialization:
While (test condition)
{
 Body of the loop
} 

```

While 迭代语句如下:

![while](img/2f8bd6b69e0e43cee56255bafab23dbc.png)

使用边循环边编程

```java
 class HelloWorld {
    public static void main(String[] args) {
    int i;
    i=0;
    while (i<=10)
       {
          System.out.println(i*i);
          i=i+1;
      }
    }
} 

```

**输出:**

```java
 0
1
4
9
16
25
36
49
64 
```

注意我们已经给了 `i`一个初始值`0`。在第一个循环中，while 检查它是否小于或等于 10。作为`0<10`，代码执行并将 0 的平方打印为 `0`。语句`'i=i+1'`将`'i`的值从`0`增加到`1.`现在再次`while'`检查并找到 1 < 10，因此打印 1 的平方为 1。类似地，2，3，4，....直到 10 点被打印出来。但是在最后一个循环的最后一条语句中`'i'`变成`11'.`所以“while”发现 11 既不小于也不等于`10`，循环终止。

## JAVA 中的嵌套 WHILE 循环

Java 允许在另一个 while 中包含嵌套的 while 循环。您可以在嵌套概念中包含任意数量的 while。

语法:

```java
 While(<condition>)
{
While(<condition>)
{
…..
…..
}
….
}</condition></condition> 

```

请参见下面的示例，使用嵌套 while 循环打印乘法表。

```java
 class NestedWhileLoopEx {
    public static void main(String[] args) {
     int i=1;
     while(i<2)
     {
        int j =1;
         while(j<=10)
        {
        System.out.printf("%d * %d = %d \n", i, j, i * j);
        j=j + 1;
        }
     i=i + 1;

    }
}
} 

```

**输出:**

```java
 1 x 1 = 1
1 x 2 = 2
1 x 3 = 3
1 x 4 = 4
1 x 5 = 5
1 x 6 = 6
1 x 7 = 7
1 x 8 = 8
1 x 9 = 9
1 x 10 = 10 
```

## Java 中的边做边语句

在 While 循环中，它在执行循环之前测试条件。因此，如果不满足条件，循环的主体可能不会被执行。在某些程序中，有必要在执行测试之前先执行主体。在这种情况下，可以使用 do-while 循环。与 For 循环和 While 循环不同，do-while 循环在测试条件之前至少执行一次循环体。do-while 循环保证在第一次尝试时执行循环一次。

java 编程语言中的 do-while 循环可以表达如下:

```java
 Initialization:
do
{
 Body of the loop
}
While (test condition); 

```

do-while 循环是一个控制流语句，它在执行底部的测试条件之前首先评估循环的主体。从语法中可以看出，while 语句中的测试条件是在循环结束时测试的；它提供了一个出口控制回路。因此，边做边循环也称为**出口控制**循环。

如果满足布尔条件，程序的控件将再次计算循环体。这种情况一直持续到条件成立。一旦条件变为 false，控制将立即转移到 while 语句之后的语句。

### 使用边做边循环编程:

```java
 public class DoWhileEx {    
public static void main(String[] args) {    
    int i=0;    
    do{    
        System.out.println(i*i);    
    i++;    
    }while(i<=10);    
}    
} 

```

**输出:**

```java
 0
1
4
9
16
25
36
49 
```

## 当 Vs 做-当

| **而** | **边做边做** |
| 这是一个入口控制的循环 | 这是一个出口控制 |
| 只有当测试条件为真时，它才会执行 | 即使测试条件为假，它也将至少执行一次 |
| 首先测试测试条件 | 在执行测试条件之前，首先执行循环的主体 |
| while 语句的末尾没有分号 | while 语句末尾的分号 |
| 计算顶部的表达式 | 计算底部的表达式 |