# PHP 常量

> 原文：<https://learnetutorials.com/php/constants>

在本 PHP 教程中，您将学习 PHP 中所有关于常量的知识。我们将详细讨论什么是常数、常数数组、const 关键字、常数的命名约定、常数和变量之间的区别、神奇常数和数学常数。

## 什么是 PHP 常量？

常量与变量非常相似，但是常量的值不能修改或未定义。常量是存储简单值的名称或标识符，这些值不会被更改。常量的值一旦在程序中定义就不能修改。默认情况下，常量是全局的，因此在整个脚本中，我们可以在任何需要的地方使用它们。与变量不同，常数不使用“$”作为前缀。常数有两种定义方式:

1.  通过使用`define()`函数
2.  通过使用 const 关键字

句法

```php
 define(name, value, case-insensitive);  // using the define() function
const name = value;   // using the const keyword 

```

## 如何使用`define()`函数定义常量？

我们使用`define()`函数在 PHP 中定义一个常数。通过使用`define()`函数，它在运行时定义了一个常数。在`define()`函数中，我们传递参数“**名称**”、“**值**”和“不区分大小写”。参数“**不区分大小写**”是可选的，默认情况下，它将为 false，如果我们想将常量名称定义为不区分大小写，我们应该将该参数作为 true 传递。按照惯例，我们用大写字母来命名常量标识符，这样可以很容易地识别常量和变量。像变量一样，我们只使用字母数字字符和下划线来命名常量，而不使用特殊字符和空格。所有常量名称都以字母或下划线开头。

```php
 define(“WELCOME”, “Welcome to learnetutorials.com”);  
echo WELCOME; 

```

**输出:**

```php
 Welcome to learnetutorials.com 
```

不区分大小写的值为 true 的示例

```php
 define(“WELCOME”, “Welcome to learnetutorials.com”, true);  
echo welcome; 

```

**输出:**

```php
 Welcome to learnetutorials.com 
```

## 如何用 const 关键字定义常量？

和`define()`函数一样，我们也用 const 关键字在 PHP 中定义一个常量。通过使用 const 关键字，它在编译时定义常量。const 关键字是一种语言构造，而不是像`define()`那样的函数。默认情况下，使用 const 关键字定义的常量区分大小写。按照惯例，我们用大写字母来命名常量标识符，这样可以很容易地识别常量和变量。像变量一样，我们只使用字母数字字符和下划线来命名常量，而不使用特殊字符和空格。所有常量名称都以字母或下划线开头。

```php
 const WELCOME =  “Welcome to learnetutorials.com”;  
echo WELCOME; 

```

**输出:**

```php
 Welcome to learnetutorials.com 
```

不区分大小写的值为 true 的示例

```php
 const WELCOME =  “Welcome to learnetutorials.com”;  
echo welcome; 

```

**输出:**

```php
 error 
```

## 什么是 PHP 中的常量数组？

我们也可以在 PHP 中定义一个常量数组。要定义常数数组，我们使用`define()`函数。我们使用常量数组来定义在整个脚本中不应该修改的数组。定义常数数组类似于定义常数。我们使用带有参数“name”、“array”和“不区分大小写”的`define()`函数。

句法

```php
 define(name, array, case-insensitive); 

```

示例:

```php
 define(“LANGUAGES”,[
   “PHP”,
   “Python”,
   “Java”
] );  
echo LANGUAGES[0]; 

```

**输出:**

```php
 PHP 
```

不区分大小写的值为 true 的示例

```php
 define(“LANGUAGES”,[
   “PHP”,
   “Python”,
   “Java”
], true);  
echo languages[0]; 

```

**输出:**

```php
 PHP 
```

## 常量()函数在 PHP 中有什么用？

函数常量()用于返回常量的值。当您想要访问常量的值但不知道它的名称时，这是非常有用的，例如，如果它存储在变量中或由函数返回。

例子

```php
 define(“AGE”,50);  // define a constant with name AGE
$AGE = 18;    // define a variable with name AGE
echo $AGE;  // print the value of the variable
echo constant(“AGE”); // print the value of the constant 

```

**输出:**

```php
 18
50 
```

## PHP 常量的命名约定是什么？

*   命名约定大多类似于变量命名约定。主要区别在于常量命名中没有使用“$”符号。
*   按照惯例，常量最好用大写字母命名。
*   PHP 中的常量名称将只包含字母数字(a-z、A-Z、0-9)字符和下划线(_)。
*   每个常量名称必须以字母(a-z、A-Z)或下划线(_)开头。另一方面，不能使用数字(0-9)或特殊字符。
*   常量名称不应包含空格
*   如果我们使用`define()`函数定义一个常量，我们可以将它设置为不区分大小写，或者如果我们使用 const 关键字定义一个常量，那么它将始终区分大小写。

## 如何检查脚本中是否定义了 PHP 常量？

为了检查脚本中是否定义了常数，我们使用`defined()`函数。在`defined()`函数中，我们将常量名称作为参数传递，如果在脚本中定义了常量，它将返回 **1** (真)，否则将返回 **0** (假)。

句法

```php
 define(name, array, case-insensitive); 

```

示例:

```php
 define(“NAME”, “Jhon Doe”);
if(defined(NAME)){
    echo “The constant is defined”;
} else {
    echo “The constant is not defined”;
} 

```

**输出:**

```php
 The constant is defined 
```

不区分大小写的值为 true 的示例

```php
 define(“FULL_NAME”, “Jhon Doe”);
if(defined(NAME)){
    echo “The constant is defined”;
} else {
    echo “The constant is not defined”;
} 

```

**输出:**

```php
 The constant is not defined 
```

## 如何使用变量作为常量名？

并不总是需要将程序中的常量名称复杂化到您想要访问它的程度。例如，如果您可能有一个通用程序，希望在任意数量的不同常量上运行，而不仅仅是在名称中输入的常量。解决这个问题最简单的方法是将常量的名称保存在变量中。为此，我们必须将常量名称赋给变量，然后在需要时，我们必须使用常量()函数，变量名称作为参数。

示例:

```php
 define(“FULL_NAME”, “Jhon Doe”);
$name = “FULL_NAME”;
echo constant($name); 

```

**输出:**

```php
 Jhon Doe 
```

## 常量和变量有什么区别？

| 常数 | 变量 |
| 一旦定义了常数，它就永远不能被修改或未定义 | 只要需要，变量可以修改或不定义 |
| 默认情况下，常数是全局的 | 变量可以是局部的、静态的或全局的 |
| 常量是使用`define()`函数或 const 关键字定义的 | 定义一个变量不需要什么，只需要使用赋值操作符(=)赋值即可 |
| 常量可以在任何地方声明和检索，不管变量范围规则如何 | 变量也可以在任何地方声明，但是变量范围规则是流动的 |
| 常量不使用“$”符号 | 变量使用“$”符号作为前缀来表示变量 |

## 什么是 PHP 脚本和环境相关常量/ PHP 魔法常量？

魔法常数是 PHP 中预先定义的常数，根据它们的使用会有很大的变化。它们以双下划线(__)开头，以另一个双下划线结尾。它们与其他预定义的常数非常相似，但是因为它们的值根据情况而变化，所以它们被称为神奇常数。

PHP 中有 9 个魔法常数:

1.  **__Line__**

    它给出调用常量的当前行号。

    ```php
        <?php
            echo "Using  __LINE__ \n ";
            echo __LINE__;
        ?> 

    ```

    **输出:**

    ```php
      Using  __LINE__
      3 
    ```

2.  **__FILE__**

    它用于返回存储文件的路径。

    ```php
        <?php
            echo "Using  __FILE__ \n ";
            echo __FILE__;
         ?>

    ```

    **输出:**

    ```php
      Using  __FILE__
      C:\ xampp\htdocs\php\magic_constant.php 
    ```

3.  **__DIR__**

    它用于返回被执行文件的目录路径。

    ```php
        <?php
            echo "Using  __DIR__ \n ";
            echo __DIR__;
        ?>

    ```

    **输出:**

    ```php
      Using  __DIR__
      C:\ xampp\htdocs\php 
    ```

4.  **__FUNCTION__**

    它用于返回使用 __FUNCTION__ 常量的函数的函数名。

    ```php
        <?php
           echo "Using  __FUNCTION__ \n";
           function a(){
               echo __FUNCTION__;
           }
           a();
       ?>

    ```

    **输出:**

    ```php
      Using  __FUNCTION__
      a 
    ```

5.  **__CLASS__**

    它用于返回使用 _ _ CLASS _ _ 常量的类的类名。

    ```php
        <?php
           echo "Using  __CLASS__ \n";
           class a{
               function ab(){
                   ;
               }
           }
           class b{
               function ab(){
                   echo __CLASS__;
               }
           }
        $a = new a;
        $a -> ab();
        $b = new b;
        $b -> ab();

       ?>
    ```

    **输出:**

    ```php
      Using  __CLASS__
      a 
    ```

6.  **__TRAIT__**

    它用于返回使用 __TRAIT__ 常量的性状的性状名称。

    ```php
       <?php   
           echo "Using __TRAIT__ \n";    
           trait ab {    
               function abc(){    
                   echo __TRAIT__;  
               }    
           }    
           class xyz {    
               use ab;    
               }    
           $a = new xyz;    
           $a->abc();    
       ?> 

    ```

    **输出:**

    ```php
      Using  __TRAIT__
      a 
    ```

7.  ** __METHOD__**

    它用于返回使用 __METHOD__ 常量的类方法的类方法名。

    ```php
        <?php   
           echo "Using __METHOD__\n";  
           class a {    
               function b() {    
                       echo __METHOD__ . "\n";   
                   }    
               function c(){    
                       echo __METHOD__;   
               }    
           }    
           $a = new a;    
           $a->b();
           $a->c();
       ?> 
    ```

    **输出:**

    ```php
      Using __METHOD__
      a::b
      a::c 
    ```

8.  **__NAMESPACE__**

    它将返回使用它的当前命名空间。

    ```php
      <?php   
           echo "Using __NAMESPACE__\n";  
           class a {    
               function __construct() {    
                   echo 'This will be printed on calling namespace.';     
               }     
           }    
           $ab = __NAMESPACE__ . '\a';    
           $a = new $ab;   
       ?> 
    ```

    **输出:**

    ```php
      Using __NAMESPACE__
            This will be printed on calling namespace. 
    ```

9.  **ClassName::class**

    像另一个神奇的常数一样，它不以双下划线(__)开始和结束。它用于返回类名的完全限定名。PHP 5.5.0 引入了 ClassName::class 常量。当使用命名空间类时，它很有用。

    ```php
     <?php   
           namespace abc;  
           echo "Using ClassName::class \n";  
           class xyz {    
           }  
           echo xyz::class;    //ClassName::class   
       ?>
    ```

    **输出:**

    ```php
      Using ClassName::class 
      abc\xyz 
    ```

## PHP 中的数学常数都有哪些？

| 常数 | 价值 | 描述 |
| 中程核力量 | 中程核力量 | 它用于返回无穷大 |
| M_E | 2.7182818284590452354 | 它用于返回 e |
| 穆勒 mueller | 0.57721566490153286061 | 它用于返回欧拉常数 |
| M_LNPI(消歧义) | 1.14472988584940017414 | 用于返回圆周率的自然对数:log_e(圆周率) |
| M_LN2(消歧义) | 0.69314718055994530942 | 它用于返回 2 的自然对数:log _ e 2 |
| M_LN10 突击步枪 | 2.30258509299404568402 | 它用于返回 10 的自然对数:log_e 10 |
| M_LOG2E | 1.4426950408889634074 | 它用于返回 E 的以 2 为底的对数:log_2 e |
| M_LOG10E | 0.43429448190325182765 | 它用于返回 E 的以 10 为底的对数:log_10 e |
| M_PI | 3.14159265358979323846 | 它用于返回圆周率的值 |
| M_PI_2 | 1.57079632679489661923 | 它用于返回π/2 的值 |
| M_PI_4 | 0.78539816339744830962 | 它用于返回π/4 的值 |
| M_1_PI | 0.31830988618379067154 | 它用于返回 1/π的值 |
| m2 PI |           0.63661977236758134308 | 它用于返回 2/π的值 |
| M_SQRTPI | 1.77245385090551602729 | 它用于返回圆周率的平方根 |
| M_2_SQRTPI | 1.12837916709551257390 | 它用于返回π的 2/平方根:2/sqrt(π) |
| M_SQRT1_2 | 0.70710678118654752440 | 它用于返回 1/2: 1/sqrt(2)的平方根 |
| M_SQRT2 | 1.41421356237309504880 | 它用于返回 2 的平方根:sqrt(2) |
| M_SQRT3 | 1.73205080756887729352 | 它用于返回 3 的平方根:sqrt(3) |
| 圆盘烤饼 | 圆盘烤饼 | 它用于返回“不是数字” |
| PHP_ROUND_HALF_UP | one | 它被用来返回四舍五入的一半 |
| PHP_ROUND_HALF_DOWN | Two | 它用于向下倒回一半 |
| PHP_ROUND_HALF_EVEN | three | 它用于返回偶数的一半 |
| PHP_ROUND_HALF_ODD | four | 它用于返回奇数的一半 |