# PHP 函数

> 原文：<https://learnetutorials.com/php/functions-tutorial>

在本 PHP 教程中，您将学习 PHP 中条件语句的所有知识。我们将详细讨论用户定义函数、参数化函数、按值调用、按引用调用、默认参数、变量参数、返回类型声明、递归函数。

PHP 函数与其他编程语言相同。函数是用于执行某些任务并返回输出的代码。函数以函数参数的形式获取输入。

## 在 PHP 中使用函数有什么好处？

*   **代码可重用性**:一旦定义了一个 PHP 函数，就可以根据需要多次调用该函数。
*   **通俗易懂**:用 PHP 函数隔离编程逻辑。因为每个逻辑都被分成函数，所以人们更容易理解应用程序的流程。
*   **少代码**:因为不用反复写逻辑，所以节省了很多代码。函数的使用允许你只写一次逻辑并重用它。

在 PHP 中，有许多用于各种目的的内置函数，同样，用户也可以声明用户定义的函数。

## PHP 中什么是用户定义的？

用户为满足其需求而声明的功能称为用户定义功能。函数不会在程序执行时自动执行，而是只能通过调用函数来执行。

## 如何在 PHP 中创建一个用户定义函数？

为了创建一个用户定义的函数，我们使用关键字 function，后跟函数名和圆括号，圆括号包含我们编写函数代码的参数和大括号。

**语法**

```php
 function functionName() {
  code to be executed;
} 

```

### 示例:PHP 中的函数

```php
 function welcome () {
    echo "Welcome to learnetutorials.com";
}
welcome (); 

```

**输出:**

```php
 Welcome to learnetutorials.com 
```

在上面的例子中，我们创建了一个用户定义的函数“welcome”来打印字符串“Welcome to learnetutorials.com”。为此，我们使用关键字 function 后跟函数名“welcome”创建了函数，并使用 echo 语句打印了所需的。在函数之外，我们称函数为“welcome”，后跟圆括号，以确定它是函数。

## PHP 中的值调用是什么意思？

PHP 允许通过值和引用来调用函数。在通过值进行 PHP 调用的情况下，实际值不会改变，相反，函数中的值只会改变。

### 示例:在 PHP 中按值调用

```php
 function countNum ($num) {
    $num += 1; 
}
$num = 1; 
countNum ($num);
echo $num; 

```

**输出:**

```php
 1 
```

在上面的例子中，我们可以看到我们作为参数传递的值是变量，在函数的参数中创建的变量将不同于函数外部的变量。我们已经在变量一章中讨论过了。正如我们所知，在函数块中所做的更改不会影响函数外部的变量。

## PHP 中引用调用是什么意思？

在通过引用进行的 PHP 调用中，即使在函数内部发生了变化，实际值也会发生变化。在这里，&符号必须与参数一起使用。&符号表示变量的引用。

### 示例:PHP 中的引用调用

```php
 function countNum(&$num){
    $num += 1; 
}
$num = 1; 
countNum($num);
echo $num; 

```

**输出:**

```php
 2 
```

在上面的例子中，我们可以看到我们作为参数传递的值是变量的引用，在函数的参数中创建的变量将是原始变量的引用，如果我们改变变量的值，即使在函数内部，函数外部的变量的值也将改变。

## PHP 中的默认参数值函数

在 PHP 中，我们使用默认的参数值，如果我们不传递任何参数，那么将使用在函数参数中指定的默认值。

### 示例:PHP 中的默认参数值函数

```php
 function welcome ($name = "Guest") {
    echo "Hai $name, welcome to learnetutorials.com \n";
}
welcome ("John");
welcome (); 

```

**输出:**

```php
 Hai John, welcome to learnetutorials.com 
Hai Guest, welcome to learnetutorials.com 
```

在上面的例子中，我们可以看到我们在函数本身的参数中赋值的值。当我们在调用函数时通过参数传递值时，传递的值将被打印，如果我们在没有参数的情况下调用函数，那么将使用默认值。

## PHP 中的可变参数函数

PHP 有一个可变长度的参数函数。这表明您可以向函数发送任意数量的参数。为此，我们只需在参数名称前放置三个省略号(点)。

### 示例:PHP 中的变量参数函数

```php
 function welcome (...$names) {
    foreach ($names as $name) {
        echo "Hai $name, welcome to learnetutorials.com \n";
    }
}
welcome ("Jhon", "Roy", "Justin"); 

```

**输出:**

```php
 Hai Jhon, welcome to learnetutorials.com 
Hai Roy, welcome to learnetutorials.com 
Hai Justin, welcome to learnetutorials.com 
```

在上面的例子中，我们可以看到我们发送了三个值作为参数，在函数的参数中，我们没有声明三个变量，而是创建了一个变量参数。在函数块中，我们使用 foreach 循环打印了变量参数的值。

## 如何在 PHP 函数中返回值？

要从函数中返回中的值，我们使用 return 语句。

### 示例:PHP 函数中的返回值

```php
 function welcome($name) {
    return "Hai $name, welcome to learnetutorials.com";
}
echo welcome ("Roy"); 

```

**输出:**

```php
 Hai Roy, welcome to learnetutorials.com 
```

在上面的示例中，我们可以看到，我们没有在函数中打印字符串，而是从字符串中返回了值，并且使用 echo 语句打印了函数的返回值。

## PHP 中的返回类型声明是什么意思？

由于 PHP 是一种松散类型的脚本语言，返回类型可能与预期的不同。为了避免这种情况，我们使用了返回类型声明，通过这种声明，我们可以指定要从函数返回的值的类型。为了声明函数的返回类型，我们在开始的大括号({)前添加一个冒号(:)，并指定要返回的值的类型。

### 不带返回类型声明的示例

```php
 function AddNum ($n1, $n2) {
    return $n1 + $n2;
}
$num1 = 10.6;
$num2 = 11;
echo AddNum ($num1, $num2); 

```

**输出:**

```php
 21.6 
```

在上面的例子中，我们可以看到我们传递了一个整数和一个浮点数作为参数，并且函数自动返回了一个浮点数，假设我们需要返回一个整数值，在这种情况下，我们使用了返回类型声明。

### 不带返回类型声明的示例

```php
 function AddNum ($n1, $n2): int {
    return $n1 + $n2;
}
$num1 = 10.6;
$num2 = 11;
echo AddNum ($num1, $num2); 

```

**输出:**

```php
 21 
```

在上面的例子中，我们可以看到它使用了相同的程序，但是只是添加了函数的返回类型声明。通过这样做，我们得到了整数值形式的函数返回值。

## PHP 中的递归

递归函数是那些在函数本身中调用相同函数的函数。这也叫做递归。

### PHP 中的递归

```php
 function countNum ($n) {
    if ($n <= 10) {
        echo "$n ";
        $n++;
        countNum ($n);
    }
}
$num = 1;
echo countNum ($num); 

```

**输出:**

```php
 1 2 3 4 5 6 7 8 9 10 
```

在上面的例子中，我们可以看到，我们只在函数外部调用了函数一次，函数的所有其他调用都是在函数本身内部完成的。