# PHP 数组

> 原文：<https://learnetutorials.com/php/arrays>

在本 PHP 教程中，您将了解到 PHP 中数组的所有知识。我们将详细讨论各种类型的数组，如索引数组、关联数组、多维数组，我们还将讨论数组函数。

## PHP 中数组是什么意思？

数组是 PHP 中的数据结构之一。数组用于将相同类型的数据存储在连续的内存位置。我们可以在数组中存储任意数量的数据。函数的作用是:在 PHP 中创建一个数组。数组主要有三种类型，即索引数组、关联数组、多维数组

![Array](img/61465106eccc4d790740c1c630c56f19.png)

## 数组的优势是什么？

*   **更少的代码**:通过使用数组，有助于避免多个变量的使用，并将同一类型的数据存储在单个数组变量中。
*   **易于遍历**:我们只需要使用一个循环就可以遍历整个。
*   **排序**:对数组中的元素进行排序更方便

## PHP 中不同类型的数组

1.  索引数组
2.  关联数组
3.  多维数组

## 1.PHP 中的索引数组

索引数组是那些每个元素都有以 0 开头的索引值的数组。默认情况下，PHP 中的每个数组都是索引数组。PHP 中的索引数组可以用来存储整数、字符串或任何对象。PHP 中的索引数组也称为数值数组。

## 如何在 PHP 中创建索引数组？

在 PHP 中创建索引数组主要有两种方法

1.  We can create an array by using the “array ()” function

    ```php
     $languages = array ("PHP", "Python", "GO", "JavaScript");
    foreach ($languages as $language) {
        echo "$language \n";
    } 

    ```

    **输出:**

    ```php
     PHP 
    Python 
    GO 
    JavaScript 
    ```

    在上面的例子中，我们可以看到我们已经使用函数“`array()`”创建了数组。通过使用`array()`函数，我们可以通过传递所需的元素作为参数来创建一个数组，并且它将在每个位置被自动索引。我们还使用 foreach 循环打印了数组的每个元素。

2.  We can create an array by assigning values into each index of the array

    ```php
     $languages[0] = "PHP";
    $languages[1] = "Python";
    $languages[2] = "GO";
    $languages[3] = "JavaScript";

    foreach ($languages as $language) {
        echo "$language \n";
    } 

    ```

    **输出:**

    ```php
     PHP 
    Python 
    GO 
    JavaScript 
    ```

    在上面的示例中，我们可以看到，我们已经通过手动将元素分配给数组的适当索引来创建数组。不建议这样做，因为这样做比较耗时，而且还会增加代码。我们还使用 **foreach** 循环打印了数组的每个元素。

## PHP 中的关联数组

索引数组是这样的数组，其中数组中的每个元素都用名称或键而不是索引来存储。在 PHP 中，键值对是通过使用“ **= >** ”符号创建的。在 PHP 中，因为每个元素由一个标签而不是一个递增的数字来表示，所以您可以很容易地记住它。

## 如何在 PHP 中创建一个关联数组？

1.  We can create an array by using the “array ()” function

    ```php
     $ages = array ("Jhon" => 23, "Roy" => 15, "Justin" => 20, "Bob" =>27);
    foreach ($ages as $name=>$age) {
        echo "$name is $age years old \n";
    }

    ```

    **输出:**

    ```php
     Jhon is 23 years old 
    Roy is 15 years old 
    Justin is 20 years old 
    Bob is 27 years old

    ```

    在上面的例子中，我们可以看到我们已经使用函数“ **array()** 创建了数组。通过使用**数组()**函数，我们可以创建一个绕过所需元素的数组，并以相应的键作为参数。我们还使用 **foreach** 循环打印了数组的每个元素。

2.  We can create an array by assigning values in to each index of the array

    ```php
     $ages["Jhon"] = 23;
    $ages["Roy"] = 15;
    $ages["Justin"] = 20;
    $ages["Bob"] = 27;

    foreach ($ages as $name=>$age) {
        echo "$name is $age years old \n";
    }

    ```

    **输出:**

    ```php
     Jhon is 23 years old 
    Roy is 15 years old 
    Justin is 20 years old 
    Bob is 27 years old

    ```

    在上面的示例中，我们可以看到，我们已经通过手动将元素分配给数组的适当键来创建数组。不建议这样做，因为这样做比较耗时，而且还会增加代码。我们还使用 **foreach** 循环打印了数组的每个元素。

## PHP 中的多维数组

在 PHP 中，多维数组用于存储数组本身中的数组。它有助于以表格格式存储数据。PHP 多维数组可以表示为矩阵，矩阵表示为行*列。

## 如何用 PHP 创建多维数组？

```php
 $students = array  
  (  
  array(1,"Bob",20),  
  array(2,"John",21),  
  array(3,"Roy",20)  
  );  
for ($row = 0; $row < 3; $row++) {  
  for ($col = 0; $col < 3; $col++) {  
    echo $students[$row] [$col]."  ";  
  }  
  echo "\n";  
} 

```

**输出:**

```php
 1  Bob  20  
2  John  21  
3  Roy  20 

```

在上面的例子中，我们可以看到，要创建多维数组，我们必须在一个数组中创建多个数组。这样，我们就能以矩阵形式存储元素。我们还打印了数组的每个元素。

## PHP 中使用的数组函数

PHP 有许多数组方法来访问和操作数组中的元素。最常用的数组函数如下。

1.  **array()** function: PHP `array()` function is used to create and return an array. It is used to create indexed, associative, and multidimensional arrays. **Syntax :**

    ```php
     array(value1, value2, value3, ...); 

    ```

    ```php
     $languages = array ("PHP", "Python", "GO", "JavaScript");
    echo $languages[2]; 

    ```

    **输出:**

    ```php
     GO 
    ```

2.  **array_change_key_case()** function: PHP `array_change_key_case()` function is used to change the case of the key of the element in the array. **Syntax :**

    ```php
     array_change_key_case(array, case); 

    ```

    ```php
     $ages = array ("Jhon" => 23, "Roy" => 15, "Justin" => 20, "Bob" =>27);
    print_r(array_change_key_case($ages,CASE_UPPER)); 

    ```

    **输出:**

    ```php
     Array
    (
        [JHON] => 23
        [ROY] => 15
        [JUSTIN] => 20
        [BOB] => 27
    ) 
    ```

3.  **array_chunk()** function: PHP `array_chunk()` function is used to split the array into several parts. **Syntax :**

    ```php
     array_chunk(array, size, preserve_key); 

    ```

    ```php
     $ages = array ("Jhon" => 23, "Roy" => 15, "Justin" => 20, "Bob" =>27);
    print_r(array_chunk($ages,2)); 

    ```

    **输出:**

    ```php
     Array
    Array
    (
        [0] => Array
            (
                [0] => 23
                [1] => 15
            )

        [1] => Array
            (
                [0] => 20
                [1] => 27
            )

    ) 
    ```

4.  **count()** function: PHP `count()` function is used to return the number of elements in the array. **Syntax :**

    ```php
     count(array, mode(optional)); 

    ```

    ```php
     $languages = array ("PHP", "Python", "GO", "JavaScript");
    echo count($languages); 

    ```

    **输出:**

    ```php
     4 
    ```

5.  **list()** function: The PHP `list()` function is used to assign the elements in the array to the variables in a single operation. **Syntax :**

    ```php
     list(var1, var2, ...) 

    ```

    ```php
     $languages = array ("PHP", "Python", "GO", "JavaScript");
    list($a, $b, $c, $d) = $languages;
    echo $a. "\n";
    echo $b. "\n";
    echo $c. "\n";
    echo $d. "\n"; 

    ```

    **输出:**

    ```php
     PHP
    Python
    GO
    JavaScript 
    ```

6.  **sort()** function: PHP `sort()` function is used to sort the array in order  **Syntax :**

    ```php
     sort(array, sorttype (optional)); 

    ```

    ```php
     $languages = array ("PHP", "Python", "GO", "JavaScript");
    sort($languages);
    print_r($languages); 

    ```

    **输出:**

    ```php
     Array
    (
        [0] => GO
        [1] => JavaScript
        [2] => PHP
        [3] => Python
    ) 
    ```

7.  **array_reverse ()** function: PHP `array_reverse ()` function is used to arrange the array in reverse order. **Syntax :**

    ```php
     array_reverse(array, preserve); 

    ```

    ```php
     $languages = array ("PHP", "Python", "GO", "JavaScript");
    print_r(array_reverse($languages)); 

    ```

    **输出:**

    ```php
     Array
    (
        [0] => JavaScript
        [1] => GO
        [2] => Python
        [3] => PHP
    ) 
    ```

8.  **array_search()** function: PHP `array_search()` function is used to search the element in the array and return its index or key if the value exists in the array. **Syntax :**

    ```php
     array_search(value, array, strict(optional)); 

    ```

    ```php
     $languages = array ("PHP", "Python", "GO", "JavaScript");
    echo array_search("GO", $languages); 

    ```

    **输出:**

    ```php
     2 
    ```

9.  **array_merge()** function: PHP `array_merge()` function is used to merge two or more arrays together. **Syntax :**

    ```php
     array_merge(array1, array2, array3, ...); 

    ```

    ```php
     $languages1 = array ("GO", "JavaScript");
    $languages2 = array ("PHP", "Python");
    print_r(array_merge($languages1, $languages2)); 

    ```

    **输出:**

    ```php
     Array
    (
        [0] => GO
        [1] => JavaScript
        [2] => PHP
        [3] => Python
    ) 
    ```

10.  **array_intersect ()** function: PHP `array_intersect ()` function is used to compare two or more array and return the common elements. **Syntax :**

    ```php
     array_intersect(array1, array2, array3, ...); 

    ```

    ```php
     $languages1 = array ("GO", "JavaScript", "R");
    $languages2 = array ("PHP", "Python", "GO", "R");
    print_r(array_intersect($languages1, $languages2)); 

    ```

    **输出:**

    ```php
     Array
    (
        [0] => GO
        [2] => R
    ) 
    ```