# php 字符串

> 原文：<https://learnetutorials.com/php/strings>

在本 PHP 教程中，您将了解 PHP 中的所有字符串。我们将详细讨论字符串和各种类型的字符串函数。

## PHP 中的字符串是什么意思？

字符串数据类型是字母数字字符序列。基本上有一个非数字数据类型。字符串可以是字母、单词、数字和特殊字符。将字符串赋给变量时，它们被认为是相同的，但在某些情况下是不同的。主要有四种方法来指定字符串，即单引号、双引号、heredoc 语法和 newdoc 语法

## PHP 中不同类型的字符串

1.  单引号
2.  双重引用
3.  Heredoc 语法
4.  Newdoc 语法

## 什么是 PHP 中的单引号字符串？

在 PHP 中，我们可以通过用单引号将字符串括起来来生成一个字符串。这是在 PHP 中定义字符串最方便的方法。我们可以将字符串值赋给一个变量并打印该字符串，也可以使用打印函数直接打印该字符串。

```php
 echo 'Hello world! ';
$str = 'learnetutorials.com';
echo $str; 

```

**输出:**

```php
 Hello world! learnetutorials.com 
```

在上面的例子中，我们可以看到我们通过用单引号将字符串括起来来创建字符串。单引号中的字符串将被直接打印。我们不能在单引号内使用变量或任何其他转义序列。如果我们想在字符串中使用单引号，我们必须在引号前使用反斜杠(\)，否则会引发错误。

### 字符串中使用单引号的示例

```php
 $str = 'Welcome to \'learnetutorials.com\' ';
echo $str; 

```

**输出:**

```php
 Welcome to 'learnetutorials.com' 
```

## 什么是 PHP 中的双引号字符串？

在 PHP 中，我们也可以通过用双引号将字符串括起来来生成一个字符串。与单引号字符串类似，我们可以将字符串值赋给一个变量并打印该字符串，也可以使用打印函数直接打印该字符串。在双引号字符串中，我们还可以使用变量或其他转义序列。

```php
 $str = 'learnetutorials.com';
echo "Welcome to $str"; 

```

**输出:**

```php
 Welcome to learnetutorials.com 
```

在上面的例子中，我们可以看到我们通过用双引号将字符串括起来来创建字符串。我们还在双引号字符串中使用了变量。

**双引号字符串中使用的转义序列是:**

*   “\n”被新的一行代替
*   “\t”被制表符替换
*   “\$”被美元符号替换
*   " \r "被回车替换
*   “\\”被反斜杠替换
*   “\”被双引号替换
*   “\”被单引号替换

```php
 // using \n
echo "Hello \nWorld! \n";

// using \t
echo "Hello\tWorld! \n";

// using \$
echo "Hello World! \$ \n";

// using \r
echo "Hello \r World! \n";

// using \\
echo "Hello \\ World! \n";

// using \"
echo "Hello  \"World!\" \n";

// using \'
echo 'Hello  \'World!\' '; 

```

**输出:**

```php
 Hello 
World! 
Hello World! 
Hello World! $ 
Hello 
 World! 
Hello \ World! 
Hello  "World!" 
Hello  'World!' 
```

## PHP 中的 Heredoc 语法字符串是什么？

PHP 中分隔字符串的第三种方法是 Heredoc 语法(< < <

### 命名规则

heredoc 标识符应遵循命名约定，即它必须只包含字母数字字符或下划线，并且必须以下划线或非数字字符开头。

```php
 $str = <<< welcome
Hai All Welcome to learnetutorials.com
welcome;
echo $str; 

```

**输出:**

```php
 Hai All Welcome to learnetutorials.com 
```

在上面的例子中，我们可以看到我们使用 heredoc 语法创建了字符串。它主要类似于双引号字符串。

## 什么是 PHP 中的 Newdoc 语法字符串？

Newdoc 大部分类似于 heredoc，但是，解析不是在 newdoc 中执行的。也是通过三个小于符号<<< followed by an identifier. However, in this case, the identifier is wrapped in a single quote. The same rules apply to newdoc as they do to heredocs.
来识别的，newdoc 和 heredoc 的主要区别是 Newdoc 类似于单引号字符串，而 heredoc 类似于双引号字符串。

```php
 $str = <<< 'welcome'
Hai All Welcome to learnetutorials.com
welcome;
echo $str; 

```

**输出:**

```php
 Hai All Welcome to learnetutorials.com 
```

在上面的例子中，我们可以看到我们使用 newdoc 语法创建了字符串。它主要类似于单引号字符串。

## PHP 字符串函数

PHP 有各种各样的字符串函数来访问和操作字符串。最常用的字符串函数如下。

1.  **strlen()** function: PHP `strlen()` function is used to return the length of the string.

    ```php
     strlen(string); 

    ```

    ```php
     $str = 'Welcome to learnetutorials.com ';
    echo strlen($str);

    ```

    **输出:**

    ```php
    31
    ```

2.  **str_replace()** function: PHP `str_replace ()` function is used to find and replace the specified word or character from the string**.**

    ```php
     str_replace(find,replace,string,count); 

    ```

    ```php
     $str = 'Welcome to learnetutorials.com ';
    echo $str; //before the function str_replace()
    echo "\n";
    echo str_replace("to", "by", $str); //on using the srt_replace()

    ```

    **输出:**

    ```php
     Welcome to learnetutorials.com 
    Welcome by learnetubyrials.com

    ```

3.  **str_split()** function: PHP `str_split()` function is used to split the characters in the string into array**.**

    ```php
     str_split(string,length); 

    ```

    ```php
     $str = 'learnetutorials.com';
    print_r(str_split($str));

    ```

    **输出:**

    ```php
     Array
    (
        [0] => l
        [1] => e
        [2] => a
        [3] => r
        [4] => n
        [5] => e
        [6] => t
        [7] => u
        [8] => t
        [9] => o
        [10] => r
        [11] => i
        [12] => a
        [13] => l
        [14] => s
        [15] => .
        [16] => c
        [17] => o
        [18] => m
    )
    ```

4.  **strcmp()** function: PHP `strcmp()` function is used to compare two strings and return the difference. 

    ```php
     strcmp(string1,string2); 

    ```

    ```php
     $str1 = 'Welcome to learnetutorials.com';
    $str2 = 'Welcome by learnetutorials.com';
    echo strcmp($str1, $str2);

    ```

    **输出:**

    ```php
     18 
    ```

5.  **strtolower()** function: PHP strtolower() function is used to convert the string in to lowercase.

    ```php
     strtolower(string); 

    ```

    ```php
     $str = 'Welcome TO learnEtutorials.com';
    echo strtolower($str);

    ```

    **输出:**

    ```php
     welcome to learnetutorials.com 
    ```

6.  **strtoupper()** function: The PHP `strtoupper ()` function is used to convert the string into uppercase.

    ```php
     strtoupper(string); 

    ```

    ```php
     $str = 'Welcome to learnetutorials.com';
    echo strtoupper($str);

    ```

    **输出:**

    ```php
     WELCOME TO LEARNETUTORIALS.COM 
    ```

7.  **ucfirst()** function: PHP `ucfirst()` function is used to convert the first letter of the string into uppercase**.**

    ```php
     ucfirst(string); 

    ```

    ```php
     $str = 'welcome to learnetutorials.com';
    echo ucfirst($str);

    ```

    **输出:**

    ```php
     Welcome to learnetutorials.com 
    ```

8.  **lcfirst()** function: PHP `lcfirst()` function is used to convert the first letter of the string into lowercase**.**

    ```php
     lcfirst(string); 

    ```

    ```php
     $str = 'WELCOME TO LEARNETUTORIALS.COM';
    echo lcfirst($str);

    ```

    **输出:**

    ```php
     wELCOME TO LEARNETUTORIALS.COM 
    ```

9.  **str_word_count()** function: PHP `str_word_count()` function is used to count the number of words in the string.

    ```php
     str_word_count(string,return(optional),char(optional)) 

    ```

    ```php
     $str = 'welcome to learnetutorials.com';
    echo str_word_count($str);

    ```

    **输出:**

    ```php
     4 
    ```

10.  <**str_repeat()** function: PHP `str_repeat()` function is used to repeat the string for a specified number of times.

    ```php
     str_repeat(string,repeat) 

    ```

    ```php
     $str = "welcome to learnetutorials.com \n";
    echo str_repeat($str, 5);

    ```

    **输出:**

    ```php
     welcome to learnetutorials.com 
    welcome to learnetutorials.com 
    welcome to learnetutorials.com 
    welcome to learnetutorials.com 
    welcome to learnetutorials.com

    ```