# PHP 日期和时间

> 原文：<https://learnetutorials.com/php/date-and-time>

在本 PHP 教程中，您将了解 PHP 中使用的所有日期和时间函数。我们将详细讨论日期和时间函数及其用途和格式。

## 日期()函数在 PHP 中有什么用？

PHP `date()`函数是一个内置函数，用于处理日期数据类型。PHP `date()`函数有助于将日期或时间转换为人类可读的格式。`date()`函数的强制格式参数定义了如何格式化日期(或时间)。
以下是一些常用于日期的字符示例:

*   **d** -代表一个月中的某一天(01 到 31)
*   **m** -表示一个月(01 到 12)
*   **Y** -表示年份(四位数)
*   **l** ('L '小写)-表示一周中的某一天

其他字符，如"/"，"、或“-”可以放在字符之间以提供格式。
PHP 中的`date()`函数只会返回截止到服务器的当前日期/时间。

句法

```php
date (format, timestamp(optional)); 

```

例子

```php
echo "Today is " . date("Y/m/d") . "\n";
echo "Today is " . date("Y.m.d") . "\n";
echo "Today is " . date("Y-m-d") . "\n";
echo "Today is " . date("l"); 
```

**输出:**

```php
Today is 2021/11/27
Today is 2021.11.27
Today is 2021-11-27
Today is Saturday 

```

## 什么是 PHP 中的时间戳？

`date()`方法生成一个表示日期的格式化字符串。使用您必须提供的字符串参数`date()`，您可以对它返回的格式施加很大的控制。`date()`函数接受时间戳作为可选参数；如果未指定，则使用当前日期和时间。给定日期()格式字符串中的任何附加数据都将包含在返回值中。在 PHP 中，时间戳是当前时间和格林威治标准时间 1970 年 1 月 1 日 00:00:00 时的值之间的数字(以秒为单位)。`date()`函数返回一个基于默认时区的值。php.ini 文件指定了默认时区。date_default_timezone_set 方法也可以用来以编程方式设置它。

句法

```php
time(); 

```

例子

```php
echo time (); 

```

**输出:**

```php
1637997813 

```

## 提取当前可访问的时区标识符列表

我们使用方法“日期时区::列表标识符()”来提取可用的时区。
示例

```php
 $timezones &equals; DateTimeZone::listIdentifiers();
foreach($timezones as $key => $zones){
    echo "$key $zones \n";
} 

```

**输出:**

有 424 个时区可用，在上面的例子中，我们可以看到我们已经访问了时区，并使用 for-each 循环打印了值。

## 如何在 PHP 中编程设置时区？

为了设置我们当前的日期和时间，我们必须在其参数中使用方法`date_default_timezone_set()`，我们传递所需的时区。
示例

```php
// to know the default timezone
echo "The time in " . date_default_timezone_get() . " is " . date("H:i:s");
echo "\n";
// to set the timezone
date_default_timezone_set("Asia/Calcutta");
echo "The time in " . date_default_timezone_get() . " is " . date("h:i:s a"); 

```

**输出:**

```php
The time in UTC is 07:53:01
The time in Asia/Calcutta is 01:23:01 pm 
```

以下是一些常用于日期时间格式的字符示例:

| 特性 | 描述 |
| **一** | 它用于以小写字母表示“am”或“pm” |
| **A** | 它用于以大写字母表示“上午”或“下午” |
| **d** | 它用于以前导 0 表示一个月中的某一天 |
| **D** | 它用三个字母来表示一周中的一天(周一) |
| **F** | 它用来表示月份 |
| **h** | 它用于以 12 小时格式表示时间，以 0 为前导 |
| **H** | 它用于以 24 小时格式表示时间，以 0 为前导 |
| **g** | 它用于以 12 小时的格式表示时间，不引入 0 |
| **G** | 它用于以 24 小时格式表示时间，不引入 0 |
| **i** | 它用于表示分钟(0-59) |
| **j** | 它用于表示一个月中的某一天，不带前导 0 |
| **l** | 它用来表示一周中的某一天 |
| **L** | 它用于表示闰年(如果为真，则返回 1，如果为假，则返回 0) |
| **米** | 它用于以带前导 0 的数字表示月份 |
| **M** | 它用三个字母来表示月份(二月) |
| **n** | 它用于以数字表示月份，不带前导 0 |
| **s** | 它用来表示一小时中的秒数 |
| **U** | 它用于表示时间戳 |
| **y** | 用两位数表示年份 |
| **Y** | 它用于以四位数表示年份 |
| **z** | 它用来表示一年中的某一天 |
| **Z** | 它用于表示距格林尼治标准时间的偏移量(以秒为单位) |

## PHP 中最常用的日期和时间函数

1.  **date_add()** function: PHP date_add() function is used to return the date from the given date and the given interval.

    句法

    ```php
    date_add(object, interval); 

    ```

    例子

    ```php
    $date=date_create("2021-11-27");
    date_add($date,date_interval_create_from_date_string("20 days"));
    echo date_format($date,"Y-m-d"); 

    ```

    **输出:**

    ```php
    2021-12-17 
    ```

2.  **date_format()** function: PHP date_format() function is used to return a date formatted in the format given.

    句法

    ```php
    date_format(object, format); 

    ```

    例子

    ```php
    $date=date_create("2021-11-27");
    echo date_format($date,"Y/m/d"); 

    ```

    **输出:**

    ```php
    2021/11/27 
    ```

3.  **checkdate()** function: PHP checkdate() function is used to return that the entered date is a valid date or not.

    句法

    ```php
    checkdate(month, day, year); 

    ```

    例子

    ```php
    var_dump(checkdate(11,27,2021));
    var_dump(checkdate(2,29,2021)); 

    ```

    **输出:**

    ```php
    bool(true)
    bool(false) 
    ```

4.  **date_diff()** function: PHP date_diff() function is used to return the difference between two dates.

    句法

    ```php
    date_diff(datetime1, datetime2, absolute(optional)); 

    ```

    例子

    ```php
    $date1=date_create("2021-01-26");
    $date2=date_create("2021-09-10");
    $diff=date_diff($date1,$date2);
    echo $diff->format("%R%a days"); 

    ```

    **输出:**

    ```php
    +227 days 
    ```

5.  **mktime()** function: PHP mktime() function is used to return the unix timestamp for a date.

    句法

    ```php
    mktime(hour, minute, second, month, day, year, is_dst); 

    ```

    例子

    ```php
    echo date("M-d-Y h:m:s", mktime(10,11,35,11,27,2021)); 

    ```

    **输出:**

    ```php
    Nov-27-2021 10:11:35 
    ```