# PHP JSON

> 原文：<https://learnetutorials.com/php/json>

在本 PHP 教程中，您将学习到 PHP 中所有关于 JSON 的知识。我们将详细讨论 PHP 中 JSON 的编码和解码。

## JSON 是什么意思？

JSON 是 JavaScript 对象符号的缩写。JSON 是一种轻量级的数据传输格式，易于理解和创建。JSON 和 XML 一样，是一种基于文本的格式，对于人类和计算机来说，编写和解释都很简单；但是，与 XML 不同的是，JSON 数据结构比 XML 数据结构消耗更少的带宽。

### JSON 可以用以下结构表示:

*   **对象:**JSON 中的对象定义为键/值对的集合(即键:值)。每个对象由左花括号“{”和右花括号“}”分隔。逗号“，”用于分隔几个键/值对。
*   **数组:**JSON 中的数组定义为按顺序排列的值列表。数组用左括号“[”表示，用右括号“]”结束。逗号“”用于分隔这些值。

JSON 中的键总是字符串，然而，值可以是字符串、整数、真或假、空，甚至是对象或数组。字符串必须用双引号括起来。
一个 JSON 数据结构看起来很像一个 PHP 数组。PHP 内置了对 JSON 数据进行编码和解码的功能。这些函数`json_encode()`分别用于将数据编码成 json 和`json_encode()`用于解码来自 JSON 的数据。

## PHP 中如何将数据编码成 JSON？

在 PHP 中，`json_encode()`函数用于将数据编码到 json 中。如果成功，此方法将生成值的 JSON 表示；否则，它返回 FALSE。
语法

```php
 json_encode ( value, options ) 

```

例子

```php
 $details = array("first_name" => "John", "last_name" => "Doe", "age" => 23);
echo json_encode($details); 

```

**输出:**

```php
 {"first_name":"John","last_name":"Doe","age":23} 
```

例如:如果它不在键/值对中，并且我们希望使用相应的索引作为键，那么在这种情况下，我们使用 JSON_FORCE_OBJECT 作为选项参数。

```php
 $languages = array("PHP", "Python", "Java", "Go", "JavaScript");
echo json_encode($languages, JSON_FORCE_OBJECT); 

```

**输出:**

```php
 {"0":"PHP","1":"Python","2":"Java","3":"Go","4":"JavaScript"} 
```

## PHP 中如何解码来自 JSON 的数据？

JSON 数据解码和编码一样简单明了。要将 JSON 编码的文本解码成合适的 PHP 数据类型，请使用 PHP `json_decode()`函数。

句法

```php
 json_decode ($json, assoc, depth, options); 

```

例子

```php
 $details = array("first_name" => "John", "last_name" => "Doe", "age" => 23);
echo json_encode($details); 

```

**输出:**

```php
 object(stdClass)#1 (3) {
  ["first_name"]=>      
  string(4) "John"      
  ["last_name"]=>       
  string(3) "Doe"       
  ["age"]=>
  int(23)
} 
```

默认情况下，`json_decode()`方法返回一个对象。但是，您可以给出第二个参数 assoc，它接受一个布尔值，当设置为 true 时，将 JSON 对象转换为关联数组。默认情况下，它设置为 false。
示例

```php
 $json &equals; '{"first_name":"John","last_name":"Doe","age":23}';
var_dump(json_decode($json, TRUE)); 

```

**输出:**

```php
 array(3) {        
  ["first_name"]=>
  string(4) "John"
  ["last_name"]=> 
  string(3) "Doe" 
  ["age"]=>       
  int(23)
} 
```

### 单独访问解码元素的示例

```php
 $json &equals; '{"first_name":"John","last_name":"Doe","age":23}';
$data = json_decode($json, TRUE);
echo "First Name is " . $data['first_name'] . "\n";
echo "Last Name is " . $data['last_name'] . "\n";
echo "Age is " . $data['age']; 

```

**输出:**

```php
 First Name is John
Last Name is Doe
Age is 23 
```

### 例 2

```php
 $json &equals; '{"first_name":"John","last_name":"Doe","age":23}';
$data = json_decode($json);
echo "First Name is " . $data->first_name . "\n";
echo "Last Name is " . $data->last_name . "\n";
echo "Age is " . $data->age; 

```

**输出:**

```php
 First Name is John
Last Name is Doe  
Age is 23 
```