# PHP OOP

> 原文：<https://learnetutorials.com/php/oops>

在本 PHP 教程中，您将了解到 PHP 中面向对象编程的所有知识。我们将详细讨论类、对象、构造函数、析构函数、访问修饰符、继承、抽象类、接口、特性、静态方法、静态属性等等。

## PHP 中的面向对象编程是什么意思？

面向对象编程是一种基于类和对象概念的编程技术。面向对象意味着我们把我们的程序构造成各种对象的集合，这些对象既有数据又有行为。过程编程侧重于开发对数据执行操作的过程或函数，而面向对象编程则侧重于构建既包含数据又包含函数的对象。在面向对象编程中，主要关注的是数据安全。

## PHP 中面向对象编程有什么优势？

*   面向对象编程有助于为程序提供清晰的模块化结构。
*   面向对象编程有助于遵循“不要重复自己”(DRY)的理念，使您的代码更容易维护、更改和调试。
*   面向对象编程有助于更快地执行脚本
*   面向对象编程有助于用更少的脚本、更快的开发时间和高度的可重用性来创建更复杂的行为程序。

### 在我们讨论面向对象编程之前需要了解的术语

*   **       Class –** 

    类是程序员指定的数据类型，包括本地函数和本地数据。一个类可以被认为是一个模板，用于创建几个同类(或类)对象的实例。

*   ** Object –** 

    对象是由类描述的数据结构的单个实例。我们可以一次创建一个类，然后创建多个属于它的对象。对象也被称为实例。

*   **Member Variable –** 

    成员变量是在类中声明的变量。这些数据对当前类的外部是隐藏的，只能通过成员函数访问。当构造一个对象时，这些变量被称为对象的属性。

*   **Member function** – 

    成员函数是在类中指定的函数，用于检索对象。成员函数也称为方法。

*   **Inheritance –** 

    当一个类是通过从父类继承一个现有的行为来定义的时候，它被称为继承。在这种情况下，子类将继承父类的所有成员函数和变量。

*   **Parent class – **

    父类是由另一个类继承的类。父类也称为基类或超类。

*   **Child Class –** 

    子类是从另一个类继承而来的类。子类也称为子类或派生类。

*   **Polymorphism –** 

    多态性是一种面向对象的思想，在这种思想中，同一个函数可能有几个角色。例如，函数名将保持不变，但它将接受不同数量的参数并执行新任务。

*   **Overloading –** 

    重载是一种多态性，在这种多态性中，一些或所有运算符根据它们接收的参数类型有不同的实现。类似地，具有不同实现的函数可能会过载。

*   **Data Abstraction –** 

    数据抽象是实现细节被隐藏(抽象)的任何数据格式。

*   **Encapsulation –** 

    封装是指我们将所有数据和成员函数封装到一个对象中的概念。

*   **Constructor –** 

    构造函数指的是一种特定的函数，每当一个对象由一个类构成时，该函数就会被自动调用。

*   **Destructor –** 

    析构函数被称为一种函数，当一个项目被移除或退出作用域时，它会被自动调用

## PHP 中的类和对象是什么意思？

面向对象编程的两个基本组成部分是类和对象。一个类是一个独立的变量和函数的集合，它们共同完成一个或多个定义的任务，而对象是一个类的单个实例。一个类充当一个模板或蓝图，从中可以构建许多不同类型的对象。单个对象在形成时会继承相同的基本属性和行为，但每个对象的特定属性可能有不同的值。

### 如何在 PHP 中定义一个类和对象

要在 PHP 中定义一个类，我们使用 class 关键字，后跟类名和一对花括号“{ }”
语法

```php
 <?php
class classname {
  // code goes here...
}
?> 

```

例子

```php
 <?php
class Students
{
    public $name;
    public $age;
    function set_detail($name, $age)
    {
        $this->name = $name;
        $this->age = $age;
    }
    function get_details()
    {
        return "Name is " . $this->name . " and Age is " . $this->age;
    }
}
?> 

```

学生类中的变量名称和年龄是成员变量。学生类中的`set_detail()`和`set_detail()`方法是成员函数。

没有对象，类就无足轻重。一个类可以用来产生许多对象。每个对象都有类中声明的所有属性和方法，但是它们的属性值会有所不同。
定义一个类的对象是用 new 关键字后跟类名创建的。

### 例如:我们用的是同一个例子

```php
 <?php
class Students
{
    public $name;
    public $age;
    function set_detail($name, $age)
    {
        $this->name = $name;
        $this->age = $age;
    }
    function get_details()
    {
        return "Name is " . $this->name . " and Age is " . $this->age;
    }
}
$student1 = new Students();
$student2 = new Students();
$student1->set_detail('John', 19);
$student2->set_detail('Roy', 18);
echo $student1->get_details();
echo "\n";
echo $student2->get_details();
?> 

```

**输出:**

```php
 Name is John and Age is 19
Name is Roy and Age is 18 
```

$this 关键字用于表示当前对象。它只能在方法内部使用。

### instanceof 关键字有什么用？

instanceof 关键字用于检查对象是否属于该类。
示例

```php
<?php
class Students
{
    public $name;
    public $age;
    function set_detail($name, $age)
    {
        $this->name = $name;
        $this->age = $age;
    }
    function get_details()
    {
        return "Name is " . $this->name . " and Age is " . $this->age;
    }
}
$student = new Students();
var_dump($student1 instanceof Students);
?> 

```

**输出:**

```php
 bool(true) 
```

## 构造函数是什么意思？

构造函数是一种在创建对象时调用的函数。因此，我们通过使用构造函数初始化许多项来充分利用这种行为。
在 PHP 中定义一个构造函数，我们使用`__construct()`函数。
示例

```php
<?php
class Students
{
    public $name;
    public $age;
    function __construct($name, $age)
    {
        $this->name = $name;
        $this->age = $age;
    }
    function get_details()
    {
        return "Name is " . $this->name . " and Age is " . $this->age;
    }
}
$student1 = new Students("John", 18);
echo $student1->get_details();
?> 

```

**输出:**

```php
 Name is John and Age is 18 
```

## 析构函数是什么意思？

当对象被销毁或脚本结束或终止时，将调用析构函数。如果你定义了一个析构函数，PHP 会在脚本结束时自动调用它。
在 PHP 中定义一个析构函数，我们使用 _ _ `destruct()`函数。
示例

```php
<?php
class Students
{
    public $name;
    public $age;
    function __construct($name, $age)
    {
        $this->name = $name;
        $this->age = $age;
    }
    function __destruct()
    {
        echo "Name is " . $this->name . " and Age is " . $this->age;
    }
}
$student1 = new Students("John", 18);
?> 

```

**输出:**

```php
 Name is John and Age is 18 
```

## 什么是继承？

扩展关键字允许类继承另一个类的属性和方法。这种可扩展性方法被称为继承。这很可能是使用面向对象编程方法的令人信服的理由。
要继承一个类，我们使用 extends 关键字，后跟父类名。
示例

```php
 <?php
class Students
{
    public $name;
    public $age;
    function __construct($name, $age)
    {
        $this->name = $name;
        $this->age = $age;
    }
}
class DisplayStudents extends Students
{
    function get_details()
    {
        return "Name is " . $this->name . " and Age is " . $this->age;
    }
}
$student1 = new DisplayStudents('John', 19);
echo $student1->get_details();
?> 

```

**输出:**

```php
 Name is John and Age is 19 
```

## 访问修饰符是什么意思？

在处理类时，您甚至可以使用访问关键字来限制对其属性和方法的访问，以便进行更多的控制。有三个可见性关键字(从最可见到最不可见)定义了如何以及从哪里可以查看和修改属性和方法，它们是公共的、受保护的和私有的。

*   **公共**属性或方法可以从类内外的任何地方访问。在 PHP 中，这是所有类成员的默认可见性。
*   **受保护的**属性或方法只能从类本身内部或从子类或继承类(即扩展该类的类)访问。
*   **私有**属性或方法只能从定义它的类中获得。子类或继承类不能访问私有属性或方法。

例子

```php
 <?php
class Students
{
    public $roll_no;
    public $name;
    public $age;
    function __construct($roll_no, $name, $age)
    {
        $this->roll_no = $roll_no;
        $this->name = $name;
        $this->age = $age;
    }
}
class DisplayStudents extends Students
{
public function get_name()
    {
        echo "\nName is " . $this->name;
    }
    protected function get_age()
    {
        echo "\nAge is " . $this->age;
    }
    private function get_roll_no()
    {
        echo "RollName is " . $this->roll_no;
    }
}
$student1 = new DisplayStudents(101, 'John', 19);
$student1->get_name();
$student1->get_roll_no(); // it will throw an error since it is protected
$student1->get_age(); // it will throw an error since it is private
?> 

```

## 抽象类是什么意思？

当一个父类有一个命名的方法，但是需要它的子类来完成职责时，这被称为抽象类和方法。至少有一个抽象方法的类称为抽象类。抽象方法是已经声明但尚未在代码中实现的方法。从抽象类继承时，子类方法必须与抽象类方法具有相同的名称和相同或较少限制的访问修饰符。因此，如果抽象方法受到保护，子类方法也必须受到保护或公开，但不能是私有的。此外，所需参数的类型和数量必须相同。但是，子类可能包含额外的可选参数。
定义一个抽象类，我们使用抽象关键字。
示例

```php
 <?php
abstract class Languages
{
    public $name;
    public function __construct($name)
    {
        $this->name = $name;
    }
    abstract public function intro(): string;
}
class Python extends Languages
{
    public function intro(): string
    {
        return "$this->name uses Python for Programming...";
    }
}
class PHP extends Languages
{
    public function intro(): string
    {
        return "$this->name uses PHP for Programming...";
    }
}
$John = new Python("John");
echo $John->intro();
echo "\n";
$Roy = new PHP("Roy");
echo $Roy->intro();
echo "\n";
?> 

```

**输出:**

```php
 John uses Python for Programming...
Roy uses PHP for Programming... 
```

## 接口是什么意思？

定义接口是为了给实现者提供通用的函数名。这些接口可以由不同的实现者根据他们的需要以不同的方式实现。接口类似于类，只是它不能包含代码。方法的名称和参数可以由接口定义，但不能由它们的内容定义。
定义一个接口类，我们使用 interface 关键字。
示例

```php
 <?php
interface Greeting
{
    function sayHai();
}
class Welcome implements Greeting
{
    function sayHai()
    {
        echo "Hai! All Welcome to learnetutorials.com";
    }
}
$welcome = new Welcome();
$welcome->sayhai();
?> 

```

**输出:**

```php
 Hai! All Welcome to learnetutorials.com 
```

## 特质是什么意思？

PHP 只允许单一继承，这意味着一个子类只能从一个父类继承。那么，如果一个类需要继承许多行为呢？这个问题用面向对象的特性来解决。可以在各种类中使用的方法是使用特性声明的。可以在各种类中使用的方法和抽象方法可以添加到特征中，并且这些方法可以有任何访问修饰符(公共的、私有的或受保护的)。
要定义一个 Traits 类，我们使用 trait 关键字。
示例

```php
 <?php
trait sayHai
{
    public function sayHai()
    {
        echo "Hai! All Welcome to learnetutorials.com... ";
    }
}
trait intro
{
    public function intro()
    {
        echo "We learn to code...";
    }
}
class Welcome
{
    use sayHai, intro;
}
$welcome = new Welcome();
$welcome->sayhai();
$welcome->intro();
?> 

```

**输出:**

```php
 Hai! All Welcome to learnetutorials.comHai! All Welcome to learnetutorials.com... We learn to code...
```

## 静态属性和方法是什么意思？

除了可见性之外，属性和方法可以被标记为静态的，这使得它们可以在不需要类实例化的情况下使用。作用域解析运算符(::)可用于访问静态属性和方法，如下所示:类名::$property 和类名::`method()`。
示例

```php
 <?php
class Welcome
{
    public static $sayHai = "Hai! all Welcome to learnetutorials.com...  ";
    public static function sayHello()
    {
        echo self::$sayHai;
    }
}
echo Welcome::$sayHai;
Welcome::sayHello();
?> 

```

**输出:**

```php
 Hai! all Welcome to learnetutorials.com...  Hai! all Welcome to learnetutorials.com... 
```