# PHP MySQL 数据库

> 原文：<https://learnetutorials.com/php/mysql-database>

在本 PHP 教程中，您将了解到 PHP 中所有的 MySQL 数据库连接。我们还将讨论如何连接数据库、创建数据库、创建表、插入表、从数据库中获取数据、更新数据、删除数据以及关闭连接。

## 什么是 MySQL？

MySQL 是一个关系数据库管理系统。它是使用最广泛的 PHP 数据库系统。甲骨文公司创建、分发和支持 MySQL。MySQL 是网络上使用最广泛的关系数据库系统之一。它可以免费下载，并且设置简单。
MySQL 和其他关系数据库一样，都是以表的形式存储数据。表是按行和列组织的相关数据的集合。表中的每一行都代表一个固有的相互链接的数据记录，例如一个人的信息，每一列都代表一个特定的字段，例如 id、名字、姓氏、电子邮件等等。

## MySQL 有什么优势？

*   MySQL 使用简单，但功能强大、快速、安全且可扩展。
*   MySQL 兼容多种操作系统，包括 UNIX 或 Linux、微软 Windows、苹果 Mac OS X 等。
*   MySQL 支持传统的 SQL(结构化查询语言)。
*   MySQL 是一个优秀的数据库管理系统，适用于小型和大型应用程序。
*   MySQL 有适当的数据安全层来保证敏感数据的安全。

## PHP 和 MySQL 怎么连接？

要在 MySQL 数据库中存储或访问数据，必须首先连接到 MySQL 数据库服务器。PHP 提供了两种连接到 MySQL 服务器的方法:MySQL(改进的 MySQL)和 PDO (PHP 数据对象)。虽然 PDO 扩展更具可移植性，并支持十几个其他数据库，但 MySQL 扩展，顾名思义，只支持 MySQL 数据库。另一方面，MySQL 扩展使连接到 MySQL 数据库服务器并在其上运行查询变得容易。PDO 和 MySQL 都提供了一个面向对象的 API，但是 MySQL 也提供了一个程序 API，对于新手来说非常容易理解。

## MySQLi 和 PDO 有什么区别？

*   PDO 支持其他 12 个数据库系统，而 MySQL 只支持 MySQL 数据库。
*   PDO 和 MySQL 都是面向对象的数据库，但是 MySQL 另外还有一个过程 API。
*   如果在开发期间，用户或开发团队想要更改数据库，使用 PDO 比在 MySQLi 中更容易做到，因为 PDO 支持 12 个不同的数据库系统。

## 连接到 MySQL 数据库服务器

PHP 中的 mysqli _ `connect()`函数使这变得简单。这个连接用于 PHP 和 MySQL 数据库服务器之间的所有通信。以下是通过 MySQL 和 PDO 扩展连接到 MySQL 的基本语法:

语法:使用 MySQLi 过程化

```php
 $c = mysqli_connect("hostname", "username", "password", "database"); 

```

语法:使用 MySQLi 面向对象

```php
 $mysqli = new mysqli("hostname", "username", "password", "database"); 

```

语法:使用 PDO

```php
 $c = new PDO("mysql:host=hostname; dbname=database", "username", "password"); 

```

在上面的语法中，hostname 参数指定了 MySQL 服务器的主机名(例如 localhost)或 IP 地址，而 username 和 password 参数指定了访问 MySQL 服务器的凭据，而 database 参数(如果提供的话)指定了执行查询时要使用的默认 MySQL 数据库。

### 示例:使用 MySQLi 过程化

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $c = mysqli_connect($host, $username, $password);             
    if (!$c) {
        die("Connection failed: " . mysqli_connect_error());
    }
    echo "Connected successfully";
    ?> 

```

### 示例:使用 MySQLi 面向对象

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $mysqli = new mysqli($host, $username, $password);
    if ($mysqli === false) {
        die("ERROR: Could not connect. " . $mysqli->connect_error);
    }
    echo "Connect Successfully. Host info: " . $mysqli->host_info;
    ?> 

```

### 例如:使用 PDO

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    try {  
        $c = new PDO("mysql:host=$host", $username, $password);                     
        $c->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        echo "Connected successfully";
    } catch (PDOException $e) {
        echo "Connection failed: " . $e->getMessage();
    }
    ?> 

```

### PHP MySQL 中如何关闭数据库连接？

在我们从一个 PHP 脚本连接到一个 MySQL 数据库之后，当我们的工作完成时，我们也应该分离或关闭连接。下面提到了在所有三种方法中关闭 MySQL 连接的语法。

语法:使用 MySQLi 过程化

```php
 mysqli_close($c); 

```

语法:使用 MySQLi 面向对象

```php
 $c->close(); 

```

语法:使用 PDO

```php
 $c = null; 

```

## 如何在 PHP MySQL 中创建数据库？

既然您已经学习了如何连接到 MySQL 数据库服务器。现在我们将运行一个 SQL 查询来构建一个数据库。我们必须先建立一个数据库，然后才能保存或访问数据。在 MySQL 中，建立数据库命令用于创建新的数据库。让我们使用 CREATE DATABASE 语句创建一个 SQL 查询，然后通过将其发送到 PHP mysqli _ `query()`函数来运行它，最终创建我们的数据库。

### 例如:使用 MySQLi 程序，我们创建了一个名为 db_pro 的数据库

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = ""; 
    $c = mysqli_connect($host, $username, $password);         
    if (!$c) {
        die("Connection failed: " . mysqli_connect_error());
    }
    $sql_query = "CREATE DATABASE db_pro";
    if (mysqli_query($c, $sql_query)) {
        echo "Database created successfully";
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . mysqli_error($c);
    }
    ?> 

```

### 示例:使用 MySQLi 面向对象，我们创建了一个名为 db_obj 的数据库

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";   
    $c = new mysqli($host, $username, $password);             
    if ($c === false) {
        die("ERROR: Could not connect. " . $c->connect_error);
    }
    $sql_query = "CREATE DATABASE db_obj";
    if ($c->query($sql_query) === true) {
        echo "Database created successfully";
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . $c->error;
    }
    ?> 

```

### 例如:使用 PDO，我们正在创建一个名为 db_pdo 的数据库

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    try {   
        $c = new PDO("mysql:host=$host", $username, $password);               
        $c->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    } catch (PDOException $e) {
        echo "Connection failed: " . $e->getMessage();
    }
    try {
        $sql_query = "CREATE DATABASE de_pdo";
        $c->exec($sql_query);
        echo "Database created successfully";
    } catch (PDOException $e) {
        die("ERROR: Could not able to execute $sql_query. " . $e->getMessage());
    }
    ?> 

```

## 如何在 PHP MySQL 中创建表？

我们学习了如何在 MySQL 服务器上构建数据库。现在是在数据库中创建表的时候了，我们将在其中真正存储数据。表格将数据排列成行和列。要在数据库中构建表，请使用 SQL CREATE TABLE 命令。让我们使用 CREATE TABLE 语句编写一个 SQL 查询，然后通过将其传递给 PHP mysqli _ `query()`函数来运行它，最终创建我们的表。

### 示例:使用 MySQLi 程序，我们正在数据库 db_pro 中创建学生表

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_pro";
    $c = mysqli_connect($host, $username, $password, $database);          
    if (!$c) {
        die("Connection failed: " . mysqli_connect_error());
    }
    $sql_query = "CREATE TABLE student(
        id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
        first_name VARCHAR(30) NOT NULL,
        last_name VARCHAR(30) NOT NULL,
        email VARCHAR(70) NOT NULL UNIQUE
    )";
    if (mysqli_query($c, $sql_query)) {
        echo "Table created successfully.";
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . mysqli_error($c);
    }
    ?> 

```

### 示例:使用 MySQLi 面向对象，我们正在数据库 db_obj 中创建学生表

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $c = new mysqli($host, $username, $password, $database);     
        if ($c === false) {
        die("ERROR: Could not connect. " . $c->connect_error);
    }
    $sql_query = "CREATE TABLE student(
        id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
        first_name VARCHAR(30) NOT NULL,
        last_name VARCHAR(30) NOT NULL,
        email VARCHAR(70) NOT NULL UNIQUE
    )";
    if ($c->query($sql_query) === true) {
        echo "Table created successfully.";
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . $c->error;
    }
    ?> 

```

### 示例:使用 PDO，我们正在数据库 db_pdo 中创建学生表

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_pdo";
    try {  
        $c = new PDO("mysql:host=$host;dbname=$database", $username, $password);               
        $c->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    } catch (PDOException $e) {
        echo "Connection failed: " . $e->getMessage();
    }
    try {
        $sql_query = "CREATE TABLE student(
            id INT NOT NULL PRIMARY KEY AUTO_INCREMENT,
            first_name VARCHAR(30) NOT NULL,
            last_name VARCHAR(30) NOT NULL,
            email VARCHAR(70) NOT NULL UNIQUE
        )";
        $c->exec($sql_query);
        echo "Table created successfully.";
    } catch (PDOException $e) {
        die("ERROR: Could not able to execute $sql_query. " . $e->getMessage());
    }
    ?> 

```

## PHP MySQL 中如何在表中插入值？

现在，您已经了解了如何在 MySQL 中创建数据库和表。现在我们将看到如何运行一个 SQL 查询来将记录放入一个表中。要在数据库表中插入新条目，请使用“插入”命令。让我们使用 INSERT INTO 语句创建一个具有可接受值的 SQL 查询，然后通过将其发送到 PHP `mysqli_query()`函数将数据插入表中来运行它。这里有一个例子，通过为名字、姓氏和电子邮件字段提供值，向个人数据库中插入一个新条目。

### 例如:使用 MySQLi 过程，我们将值插入学生表

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_pro";          
    $c = mysqli_connect($host, $username, $password, $database);
    if (!$c) {
        die("Connection failed: " . mysqli_connect_error());
    }
    $sql_query = "INSERT INTO student (first_name, last_name, email) VALUES ('John', 'Doe', 'johndoe@mail.com')";
    if (mysqli_query($c, $sql_query)) {
        echo "Records inserted successfully.";
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . mysqli_error($c);
    }
    ?> 

```

### 例如:使用 MySQLi 面向对象，我们将值插入学生表

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_obj";  
    $c = new mysqli($host, $username, $password, $database);      
       if ($c === false) {
        die("ERROR: Could not connect. " . $c->connect_error);
    }
    $sql_query = "INSERT INTO student (first_name, last_name, email) VALUES ('John', 'Doe', 'johndoe@mail.com')";
    if ($c->query($sql_query) === true) {
        echo "Records inserted successfully.";
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . $c->error;
    }
    ?> 

```

### 例如:使用 PDO，我们将值插入到学生表中

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_pdo";
    try { 
        $c = new PDO("mysql:host=$host;dbname=$database", $username, $password);             
        $c->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    } catch (PDOException $e) {
        echo "Connection failed: " . $e->getMessage();
    }
    try {
        $sql_query = "INSERT INTO student (first_name, last_name, email) VALUES ('John', 'Doe', 'johndoe@mail.com')";
        $c->exec($sql_query);
        echo "Records inserted successfully.";
    } catch (PDOException $e) {
        die("ERROR: Could not able to execute $sql_query. " . $e->getMessage());
    }
    ?> 

```

## PHP MySQL 中如何更新表中的值？

UPDATE 语句用于更改数据库表中的现有记录。此语句通常与 WHERE 子句结合使用，以限制对满足特定条件的记录的修改。让我们用 UPDATE 语句和 WHERE 子句创建一个 SQL 查询，然后通过将其提供给 PHP mysqli _ `query()`函数来更新表的条目来执行它。

### 示例:使用 MySQLi 程序，我们将值更新到学生表中

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_pro";
    $c = mysqli_connect($host, $username, $password, $database);          
    if (!$c) {
        die("Connection failed: " . mysqli_connect_error());
    }
    $sql_query = "UPDATE student SET email='jd@mail.com' WHERE id=1";
    if (mysqli_query($c, $sql_query)) {
        echo "Records were updated successfully.";
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . mysqli_error($c);
    }
    ?> 

```

### 示例:使用 MySQLi 面向对象，我们将值更新到学生表中

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_obj";   
    $c = new mysqli($host, $username, $password, $database);   
        if ($c === false) {
        die("ERROR: Could not connect. " . $c--->connect_error);
    }
    $sql_query = "UPDATE student SET email='jd@mail.com' WHERE id=1";
    if ($c->query($sql_query) === true) {
        echo "Records were updated successfully.";
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . $c->error;
    }
    ?> 

```

### 例如:使用 PDO，我们将值更新到学生表中

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_pdo";
    try {    
        $c = new PDO("mysql:host=$host;dbname=$database", $username, $password);             
        $c->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    } catch (PDOException $e) {
        echo "Connection failed: " . $e->getMessage();
    }
    try {
        $sql_query = "UPDATE student SET email='jd@mail.com' WHERE id=1";
        $c->exec($sql_query);
        echo "Records were updated successfully.";
    } catch (PDOException $e) {
        die("ERROR: Could not able to execute $sql_query. " . $e->getMessage());
    }
    ?> 

```

## PHP MySQL 中如何删除表中的值？

SQL DELETE 命令用于从表中删除记录，就像它用于将记录插入表一样。它通常与 WHERE 子句一起使用，只删除符合指定条件的条目。让我们用 DELETE 语句和 WHERE 子句创建一个 SQL 查询，然后通过将其提供给 PHP mysqli _ `query()`函数来删除表的记录来执行它。

### 例如:使用 MySQLi 程序，我们从学生表中删除值

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_pro"; 
    $c = mysqli_connect($host, $username, $password, $database);     
    if (!$c) {
        die("Connection failed: " . mysqli_connect_error());
    }
    $sql_query = "DELETE FROM student WHERE first_name='Roy'";
    if (mysqli_query($c, $sql_query)) {
        echo "Records were deleted successfully.";
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . mysqli_error($c);
    }
    ?> 

```

### 例如:使用 MySQLi 面向对象，我们从学生表中删除值

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_obj";     $c mysqli($host, $username, $password, $database);          
    if ($c ===  false) {
        die("ERROR: Could not connect. " . $c->connect_error);
    }
    $sql_query = "DELETE FROM student WHERE first_name='Roy'";
    if ($c->query($sql_query) === true) {
        echo "Records were deleted successfully.";
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . $c->error;
    }
    ?> 

```

### 例如:使用 PDO，我们从学生表中删除值

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_pdo";
    try {  
        $c = new PDO("mysql:host=$host;dbname=$database", $username, $password);                
        $c->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    } catch (PDOException $e) {
        echo "Connection failed: " . $e->getMessage();
    }
    try {
        $sql_query = "DELETE FROM student WHERE first_name='Roy'";
        $c->exec($sql_query);
        echo "Records were deleted successfully.";
    } catch (PDOException $e) {
        die("ERROR: Could not able to execute $sql_query. " . $e->getMessage());
    }
    ?> 

```

## 如何在 PHP MySQL 中选择表中的值？

到目前为止，您已经学习了如何构建数据库和表，以及如何输入数据。现在是时候恢复在上一个教程中插入到表中的数据了。要从数据库表中获取记录，请使用 SQL SELECT 命令。让我们使用 SELECT 语句创建一个 SQL 查询，然后通过将其提供给 PHP `mysqli_query()`函数来获取表数据来执行它。

### 例如:使用 MySQLi 过程，我们从学生表中获取值

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_pro"; 
    $c = mysqli_connect($host, $username, $password, $database);         
    if (!$c) {
        die("Connection failed: " . mysqli_connect_error());
    }
    $sql_query = "SELECT * FROM student";
    if ($result = mysqli_query($c, $sql_query)) {
        if (mysqli_num_rows($result) > 0) {
            echo "<table>";
            echo "<tr>";
            echo "<th>id</th>";
            echo "<th>First Name</th>";
            echo "<th>Last Name</th>";
            echo "<th>Email</th>";
            echo "</tr>";
            while ($row = mysqli_fetch_array($result)) {
                echo "<tr>";
                echo "<td>" . $row['id'] . "</td>";
                echo "<td>" . $row['first_name'] . "</td>";
                echo "<td>" . $row['last_name'] . "</td>";
                echo "<td>" . $row['email'] . "</td>";
                echo "</tr>";
            }
            echo "</table>";
            mysqli_free_result($result);
        } else {
            echo "No records matching your query were found.";
        }
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . mysqli_error($c);
    }
    ?> 
```

### 例如:使用 MySQLi 面向对象，我们从学生表中获取值

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_obj";  
    $c = new mysqli($host, $username, $password, $database);    
        if ($c === false) {
        die("ERROR: Could not connect. " . $c->connect_error);
    }
    $sql_query = "SELECT * FROM student";
    if ($result = $c->query($sql_query)) {
        if ($result->num_rows > 0) {
            echo "<table>";
            echo "<tr>";
            echo "<th>id</th>";
            echo "<th>First Name</th>";
            echo "<th>Last Name</th>";
            echo "<th>Email</th>";
            echo "</tr>";
            while ($row = $result->fetch_array()) {
                echo "<tr>";
                echo "<td>" . $row['id'] . "</td>";
                echo "<td>" . $row['first_name'] . "</td>";
                echo "<td>" . $row['last_name'] . "</td>";
                echo "<td>" . $row['email'] . "</td>";
                echo "</tr>";
            }
            echo "</table>";
            $result->free();
        } else {
            echo "No records matching your query were found.";
        }
    } else {
        echo "ERROR: Could not able to execute $sql_query. " . $c->error;
    }
    ?> 

```

### 例如:使用 PDO，我们从学生表中获取值

```php
 <?php
    $host = "localhost";
    $username = "root";
    $password = "";
    $database = "db_pdo";
    try {  
        $c = new PDO("mysql:host=$host;dbname=$database", $username, $password);                
        $c->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    } catch (PDOException $e) {
        echo "Connection failed: " . $e->getMessage();
    }
    try {
        $sql_query = "SELECT * FROM student";
        $result = $c->query($sql_query);
        if ($result->rowCount() > 0) {
            echo "<table>";
            echo "<tr>";
            echo "<th>id</th>";
            echo "<th>First Name</th>";
            echo "<th>Last Name</th>";
            echo "<th>Email</th>";
            echo "</tr>";
            while ($row = $result->fetch()) {
                echo "<tr>";
                echo "<td>" . $row['id'] . "</td>";
                echo "<td>" . $row['first_name'] . "</td>";
                echo "<td>" . $row['last_name'] . "</td>";
                echo "<td>" . $row['email'] . "</td>";
                echo "</tr>";
            }
            echo "</table>";
            unset($result);
        } else {
            echo "No records matching your query were found.";
        }
    } catch (PDOException $e) {
        die("ERROR: Could not able to execute $sql_query. " . $e->getMessage());
    }
    ?> 

```