# PHP AJAX

> 原文：<https://learnetutorials.com/php/ajax>

在这篇 PHP 教程中，您将了解到 PHP 中所有的 AJAX。我们将详细讨论 AJAX 的类型、PHP AJAX 连接、使用 AJAX 呈现页面等等。

## 什么是 AJAX？

AJAX 是异步 JavaScript 和 XML 的缩写。AJAX 是一种使用 XML、HTML、CSS 和 Javascript 开发更好、更快、更具交互性的在线应用程序的新技术。传统的 web 应用程序使用同步请求从服务器发送和接收数据。这意味着您填写一个表单，按下 submit，然后被发送到一个新页面，其中包含来自服务器的更新信息。当您触摸 AJAX 中的提交按钮时，JavaScript 将向服务器发送请求，分析结果，并更新当前屏幕。在其最纯粹的形式中，用户不会知道任何东西正在被传输到服务器。

## PHP 中如何使用 AJAX？

为了说明使用 AJAX 的 PHP，我们正在创建一个具有预定义名称的脚本，并且我们正在尝试在输入字段时显示来自指定名称的建议，而无需重新加载当前页面。

### 文件“Index.html”

```php
 <html>
 <head>
  <script>
   function showSuggestion(str) {
    if (str.length == 0) {
     document.getElementById('txt')[removed] = '';
     return;
    } else {      var xmlhttp = new XMLHttpRequest(); xmlhttp. ()  {
      if (this.readyState == 4 && this.status == 200) {
       document.getElementById('txt')[removed] = this.responseText;
      }
     };
     xmlhttp.open('GET', 'getnames.php?q=' + str, true);
     xmlhttp.send();
    }
   }
  </script>
 </head>
 <body>   <p><b>Enter the name in the input field below:</b></p>   <form acti >
   <label for="fname">First name:</label>
   <input
    type="text"
    id="fname"
    name="fname"          
   />
  </form>
  <p>Suggestions: <span id="txt"></span></p>
 </body>
</html> 
```

### "获取名称.php"

```php
 <?php
$a[] = "Anna";
$a[] = "Brittany";
$a[] = "Cinderella";
$a[] = "Diana";
$a[] = "Eva";
$a[] = "Fiona";
$a[] = "Gunda";
$a[] = "Hege";
$a[] = "Inga";
$a[] = "Johanna";
$a[] = "Kitty";
$a[] = "Linda";
$a[] = "Nina";
$a[] = "Ophelia";
$a[] = "Petunia";
$a[] = "Amanda";
$a[] = "Raquel";
$a[] = "Cindy";
$a[] = "Doris";
$a[] = "Eve";
$a[] = "Evita";
$a[] = "Sunniva";
$a[] = "Tove";
$a[] = "Unni";
$a[] = "Violet";
$a[] = "Liza";
$a[] = "Elizabeth";
$a[] = "Ellen";
$a[] = "Wenche";
$a[] = "Vicky";
$q = $_REQUEST["q"];
$hint = "";
if ($q !== "") {
    $q = strtolower($q);
    $len = strlen($q);
    foreach ($a as $name) {
        if (stristr($q, substr($name, 0, $len))) {
            if ($hint === "") {
                $hint = $name;
            } else {
                $hint .= ", $name";
            }
        }
    }
}
echo $hint === "" ? "no suggestion" : $hint;
?> 

```

**输出:**

```php
 ![PHP - session](img/d59af38374f5cfa13b739ab213ff3246.png) 
```

在上面的例子中，我们可以看到建议是在没有重新加载当前网页的情况下发生的，并且是在 AJAX 的帮助下完成的。我们在一个数组中定义了一些名称，在 AJAX 脚本中，我们将输入的字符与数组中的字符进行比较。

## PHP 中如何使用带有 XML 的 AJAX？

AJAX 能够完整地处理 XML 文件。我们可以用例子演示 AJAX 和 XML 的交互。

### 示例:文件“index.html”

```php
 <html>
 <head>
  <script>
   function showCD(str) {
    if (str == '') {
     document.getElementById('txtHint')[removed] = '';
     return;
    }
    if (window.XMLHttpRequest) {
     xmlhttp = new XMLHttpRequest();
    } else {
     xmlhttp = new ActiveXObject('Microsoft.XMLHTTP');
    }     xmlhttp. () {
     if (xmlhttp.readyState == 4 && xmlhttp.status == 200) {
      document.getElementById('txtHint')[removed] = xmlhttp.responseText;
     }
    };
    xmlhttp.open('GET', 'getcourse.php?q=' + str, true);
    xmlhttp.send();
   }
  </script>
 </head>
 <body>
  <form>
Select a Course:    <select name="cds" >
    <option value="">Select a course:</option>
    <option value="Python">Python</option>
    <option value="PHP">PHP</option>
    <option value="JavaScript">JavaScript</option>
    <option value="GO">GO</option>
   </select>
  </form>
  <div id="txtHint"><b>Course info will be listed here...</b></div>
 </body>
</html> 

```

### 文件“getcourse.php”

```php
 <?php
   $q = $_GET["q"];
   $xmlDoc = new DOMDocument();
   $xmlDoc->load("catalog.xml");
   $x = $xmlDoc->getElementsByTagName('COURSE');
   for ($i = 0; $i<=$x->length-1; $i++) {
      if ($x->item($i)->nodeType == 1) {
         if ($x->item($i)->childNodes->item(0)->nodeValue == $q) {
            $y = ($x->item($i)->parentNode);
         }
      }
   }
   $cd = ($y->childNodes);
   for ($i = 0;$i<$cd->length;$i++) {
      if ($cd->item($i)->nodeType == 1) {
         echo("**" . $cd->item($i)->nodeName . ":** ");
         echo($cd->item($i)->childNodes->item(0)->nodeValue);
         echo("
");
      }
   } 

```

### 文件“catalog.xml”

```php
 <CATALOG>
   <SUBJECT>
      <COURSE>Python</COURSE>
      <COUNTRY>India</COUNTRY>
      <COMPANY>learnetutorials.com</COMPANY>
   </SUBJECT>

   <SUBJECT>
      <COURSE>PHP</COURSE>
      <COUNTRY>India</COUNTRY>
      <COMPANY>learnetutorials.com</COMPANY>
   </SUBJECT>

   <SUBJECT>
      <COURSE>JavaScript</COURSE>
      <COUNTRY>India</COUNTRY>
      <COMPANY>learnetutorials.com</COMPANY>
   </SUBJECT>

   <SUBJECT>
      <COURSE>GO</COURSE>
      <COUNTRY>India</COUNTRY>
      <COMPANY>learnetutorials.com</COMPANY>
   </SUBJECT>
</CATALOG> 

```

**输出:**

```php
 ![PHP - session](img/f8f1edf84d1729cc54b3cddb6e53335b.png) 
```

```php
 ![PHP - session](img/292fee04036264f6b700c0bd98b8ec80.png) 
```