# PHP 程序：检查数字数据类型

> 原文：<https://learnetutorials.com/php/programs/check-data-type-of-numbers>

PHP 提供自动数据类型转换。所以，如果你给一个变量分配一个整数值，这个变量的类型将自动是一个整数。然后，如果将一个字符串分配给同一个变量，类型将变为字符串。

这种自动转换有时会破坏您的代码。

### **PHP 整数**

整数是没有小数部分的数字。

整数数据类型是在 32 位系统中介于-2147483648 和 2147483647 之间的非十进制数，在 64 位系统中介于-9223372036854775808 和 9223372036854775807 之间。大于(或小于)此值的值将存储为浮点数，因为它超过了整数的限制。

以下是整数的一些规则:

*   整数必须至少有一个数字
*   整数不能有小数点
*   整数可以是正数，也可以是负数
*   整数可以用三种格式指定:十进制(从 10 开始)、十六进制(从 16 开始，以 0x 为前缀)或八进制(从 8 开始，以 0 为前缀)

PHP 有以下预定义的整数常量:

*   PHP_INT_MAX -支持的最大整数
*   ### Minimum integer supported

*   整数的大小，以字节为单位

PHP 有以下函数来检查变量的类型是否是整数:

*   is_int()
*   is _ integer()-is _ `int()`的别名
*   is _ long()-is _ `int()`的别名

### **PHP 浮动**

浮点数是具有小数点的数字或指数形式的数字。

2.0、256.4、10.358、7.64E+5、5.56E-5 都是浮点数。

浮点数据类型通常可以存储高达 1.7976931348623E+308(取决于平台)的值，最大精度为 14 位。

PHP 有以下预定义的浮点常量(来自 PHP 7.2):

*   最大可表示的浮点数
*   最小的可表示的正浮点数
*   - PHP_FLOAT_MAX -最小的可表示的负浮点数
*   可以舍入到浮点数并返回而不损失精度的小数位数
*   PHP_FLOAT_EPSILON -最小的可表示正数 x，这样 x + 1.0！= 1.0

PHP 有以下功能来检查变量的类型是否为浮点型:

*   is_float()
*   is _ double()-is _ `float()`的别名

### **PHP 无穷大**

大于 PHP_FLOAT_MAX 的数值被认为是无限的。

PHP 具有以下功能来检查数值是有限的还是无限的:

*   is _ 有限()
*   is _ 无穷大()

### **PHP NaN**

NaN 代表“不是数字”。它用于不可能的数学运算。

PHP 有以下功能来检查一个值是否不是数字:

*   is_nan()

### **PHP 数值字符串**

PHP `is_numeric()`函数可用于查找变量是否为数字。如果变量是数字或数字字符串，函数返回 true，否则返回 false。

### **PHP 将字符串和浮点数转换为整数**

有时我们需要将一个数值转换成另一种数据类型。

`(int)`、`(integer)`或`intval()`函数通常用于将值转换为整数。

## 算法

**步骤 1:** 读取数值

**步骤 2:** 检查该值是否为整数类型

**步骤 3:** 检查数值是否为浮点型

**步骤 4:** 检查该值是否为无穷大

**步骤 5:** 检查给定值是否不是数字

**步骤 6:** 检查给定值是否为数字

**步骤 7:** 将给定的浮点数转换为整数并显示该值

## PHP 源代码

```php
<?php
$x = 9988;
var_dump($x);
echo "\n";

$x = 12.368;
var_dump($x);
echo "\n";

$x = 2.8e411;
var_dump($x);
echo "\n";

$x = acos(2);
var_dump($x);
echo "\n";

$x = "3589";
var_dump(is_numeric($x));
echo "\n";

// Cast float to int
$x = 58963.768;
$int_cast = (int)$x;
echo $int_cast; 

```

## 输出

```php
int(9988)

float(12.368)

float(INF)

float(NAN)

bool(true)

58963
```