# Python 基础——关键字

> 原文：<https://learnetutorials.com/python/keywords>

在本教程中，您将探索关于所有关键字的基本介绍，这些关键字是 python 编程语言的基本构造块。你将学习什么是关键字，如何从其他单词中识别关键字以及它们的用途。

Python 关键字是 python 语言中保留的特殊单词，用于某些独特的编程目的。关键字不能用作变量名、函数名、类名或任何其他标识符，但可以用于特定目的。例如，python 关键字–“break”用于中断 Python 代码流。因此，“break”不能用于命名变量或函数或任何其他实体。

python 的新版本有 35 个关键字(保留字)，为 python 语言提供了很好的词汇。

## 如何在列表中列出关键字？

按照下面提到的简单步骤访问操作系统中的 python 关键字列表。

1.  打开 python 外壳或命令提示符
2.  键入“Python”，然后按回车键。
3.  键入“`help()`”函数，然后按 enter 键。
4.  现在只需在帮助实用程序中键入“关键字”。
5.  您将获得适用于您安装的 python 版本的 python 关键字列表。

下面是 Python 关键字的列表。输入任何关键字以获得更多帮助。

| 错误的 | 等待 | 其他 | 进口 | 及格 |
| 没有人 | 破裂 | 除...之外 | 在 | 上升 |
| 真实的 | 班级 | 最后 | 存在 | 返回 |
| 和 | 继续 | 为 | 希腊字母的第 11 个 | 尝试 |
| 如同 | 极好的 | 从 | 非局部的 | 正在… |
| 维护 | 是吗 | 全球的 | 不 | 随着 |
| 异步ˌ非同步(asynchronous) | 艾列弗 | 如果 | 或者 | 产量 |

## Python 中的关键字如何识别？

Python 提供了许多方法来找出或检查哪些单词是为关键字保留的。它们如下所示:

1.  **使用`help()`实用程序**:最简单的方法是在`help()`实用程序中传递特定的关键字，它会给你关于那个关键字的信息。下面是你理解的例子。
2.  **关键字模块处理关键字**:python 中识别关键字的另一种方法是利用包含两个实体的关键字模块来处理关键字。它们是:
    *   **kwlist** :提供您正在执行的 python 版本中所有关键字的列表。
    *   **iskeyword()** :如果提供的词是关键字，则返回 true。
3.  **检查语法错误**:这不是识别关键字的简便方法，尽管如此，如果在试图用关键字赋值以将其用作函数名或变量名时出现任何语法错误，我们可以将其视为一个选项。
4.  将 IDE 与语法荧光笔一起使用:许多 IDE 都可以与 python 一起使用，python 使用荧光笔来区分关键字和其他单词，这是一种在编码时快速识别关键字的简便方法。

## Python 关键字及其用法

根据用法，关键字可以分为以下几类。

1.  **Value Keywords: True, False, None** 

    这些关键字是基于值的关键字，因为它们可以反复使用。这些单例值总是引用相同的对象。

    *   **真**:布尔真；-如果语句为真，则输出真
    *   **假**:布尔假；-如果语句为假，则输出假
    *   **无**:表示无值。
2.  **Operator Keywords: and, or, not, in, is:**

    这些关键字用于计算算术和逻辑运算。

    *   **和**:表示逻辑运算符“与”的功能，当且仅当所有操作数都为真时返回真，否则返回假
    *   **或**:表示逻辑运算符“或”的功能，当且仅当所有操作数都为假时返回假，否则返回真
    *   **not** :表示逻辑运算符“not”的功能:返回给定语句或操作数的反方。
    *   中的**:是执行类似数学术语包含的，∑的隶属算子。此关键字检查列表或集合中是否存在或包含值。**
    *   **为**:用于检查两个对象的身份
3.  **Control flow Keywords: if, elif, else**

    这些关键字通过允许用户使用条件逻辑和执行有利于条件的代码块来控制代码流。

    *   **if** :条件正确时返回真结果的条件语句。
    *   **elif** : CanThis 可以看作 python 中的 switch 语句，其中多个 if 条件被一个接一个地求值。
    *   **否则**:当条件语句(if 或 elif)中的条件为假时，执行代码块
4.  **Iteration Keywords: for, while break, continue**

    这些关键字用于创建和处理迭代。

    *   **代表**:用于创建迭代。
    *   **而**:用于表示循环的关键字。
    *   **break** :中断或终止循环，转到下一条语句。
    *   **继续**触发条件时跳过当前迭代，但在 for 循环或 while 循环中继续剩余迭代。
5.  **结构关键字:def、class、with、pass、lambda**

    *   **def** :用于定义函数或类
    *   **类**:定义一个类
    *   **with:** 由上下文管理器探索，通过正确退出来控制资源，如文件或子进程或锁，无论是否引发异常
    *   **pass:** 一个空语句，用作占位符来防止缩进错误
    *   **lamda:** 定义 python 中的匿名或无名函数
6.  **退货关键字:退货，产量**

    *   **返回**:一旦终止函数调用的执行，将结果返回给调用者。
    *   **产量**:作为结果返回一个发电机。
    *   **导入关键字**:导入，自，作为
    *   **导入**:用于将特定模块导入到 python 程序中。
    *   **从**开始:用于包含导入模块的特定部分或功能。总是伴随着进口。
    *   **为**:为导入的模块提供一个新名称。将计算器作为 calc 导入
7.  **异常处理关键字:尝试、除、引发、最后断言**

    *   **尝试**:尝试捕捉程序中的异常错误
    *   **除外:**与“try”一起工作，用于错误和异常处理
    *   **引发**:引发用户定义的异常错误。
    *   **最后**:用于保证代码的顺利执行，不管一次尝试中发生了什么，除了 or else 块。
    *   **断言**:作为调试工具测试一个条件:如果返回 false，将会出现异常错误，如果返回 true，则空闲
8.  **异步编程关键字:异步，等待**
    *   **异步**:用于定义异步函数或协同程序。
    *   **等待**:用于指定异步函数中的一个点。
9.  **范围关键字:全局、非局部**
    *   **全局**:表示一个变量在整个程序中的作用域，即使该变量是在函数内部声明的
    *   **非局部**:表示变量的范围既不是局部声明的，也不是全局声明的。通常与嵌套函数相关联。
10.  **删除关键字:del**
    *   **del**:delete 的缩写。它有助于移除 python 脚本中存在的对象。

下面以表格形式描述 Python 关键字及其对应的活动，以便于访问。为了更好地理解和可读性，以大写字符开头的关键字会出现在最上面的行中，然后是小写关键字。由此，我们可以认识到 Python 关键字是区分大小写的。

| Sl No | Python 关键字 | 描述 |
| --- | --- | --- |
| one | 真实的 | 布尔真；如果语句为真，则输出真 |
| Two | 错误的 | 布尔假；如果语句为假，则输出假 |
| three | 没有人 | 指示无效或空值。 |
| four | 和 | 指示逻辑运算符“与”的功能:只有当所有操作数都为真时才返回真，否则返回假 |
| five | 或者 | 指示逻辑运算符“或”的功能:只有当所有操作数都为假时才返回假，否则返回真 |
| six | 不 | 指示逻辑运算符“非”的功能:返回给定语句或操作数的反义词。 |
| seven | 存在 | 用于检查两个对象是否位于同一内存位置，从而测试对象的身份。 |
| eight | 如果 | 当正确遇到条件时返回真结果的条件语句。 |
| nine | 其他 | 确定条件语句(如果)中的条件为假时执行的下一步 |
| Ten | 艾列弗 | else-if 的简写形式:参考 if 和 else |
| Eleven | 为 | 用于在 python 语言中表示循环。 |
| Twelve | 正在… | 用于在 python 语言中表示循环。 |
| Thirteen | 破裂 | 中断或终止循环并移动到下一条语句 |
| Fourteen | 继续 | 触发条件时跳过当前迭代，但在 for 循环或 while 循环中继续剩余迭代。 |
| Fifteen | 及格 | 用作占位符以防止缩进错误的 null 语句。 |
| Sixteen | 返回 | 一旦调用方终止函数调用的执行，就将结果返回给调用方。 |
| Seventeen | 产量 | 在生成器函数中用于返回结果。 |
| Eighteen | 尝试 | 试图捕捉程序中的异常错误 |
| Nineteen | 除...之外 | 与“try”一起用于错误和异常处理 |
| Twenty | 上升 | 引发用户定义的异常错误。 |
| Twenty-one | 最后 | 用于确保代码的顺利执行，即使“try”是否引发错误 |
| Twenty-two | 维护 | 用作测试条件的调试工具:它返回 false，将引发异常错误，如果返回 true，则处于空闲状态 |
| Twenty-three | 进口 | 用于将特定模块导入 python 程序。 |
| Twenty-four | 从 | 用于包含导入模块中的特定部分或功能。总是伴随着进口。 |
| Twenty-five | 如同 | 为导入的模块提供新名称。
Eg:将计算器导入为 calc |
| Twenty-six | 极好的 | 用 python 定义一个普通函数 |
| Twenty-seven | 希腊字母的第 11 个 | 在 python 中定义一个匿名函数 |
| Twenty-eight | 班级 | 用 python 定义一个类 |
| Twenty-nine | 全球的 | 指示变量在整个程序中的范围，即使该变量是在函数中声明的 |
| Thirty | 非本地 | 这表明变量的范围既不是局部声明的，也不是全局声明的。通常，与嵌套函数相关联。 |
| Thirty-one | 随着 | 内容经理探索通过正确退出来控制资源，如文件或子进程或锁，无论是否引发异常 |
| Thirty-two | 在 | 用于检查列表或集合中是否存在值。也用于 for 循环。 |
| Thirty-three | 是吗 | delete 的缩写。它有助于移除 python 脚本中存在的对象。 |