# Python 字符串

> 原文：<https://learnetutorials.com/python/python-string>

在本教程中，您将了解什么是顺序数据类型及其分类，以及 python 编程语言中的各种操作。

## 什么是顺序数据类型？

在 Python 编程语言中，顺序数据类型是除数值、映射、实例和异常之外的基本内置数据类型之一。

序列可以被定义为以特定顺序排列的对象的集合，使得它们中的每一个都跟随另一个。

## 序列数据类型的分类

Python 有六种连续的数据类型——字符串、列表、元组、范围、字节、字节射线。其中，最重要的顺序数据类型是字符串、列表和元组。

![Command Prompt](img/43919258470d9707d68d86dc5d6e0006.png)

## Python 中的字符串数据类型

在编程中，字符序列被称为**字符串**。

**字符**可以是字母、数字、符号、空格或标点符号。任何可以在计算机上输入的东西(可见或不可见)都被认为是字符。例如，`Python`是一个包含六个字符的字符串，其中所有字符都是字母。

作为机器的计算机总是理解二进制语言`0`或`1`，不像人类。更具体地说，用户可读的字符必须转换成机器语言。在计算机中，屏幕上出现的每个字符都被隐式转换为 0 和 1 的二进制组合。这种转换被称为*编码*，二进制到字符的转换被称为*解码*。两个普遍接受的编码标准是 **ASCII** 和 **Unicode** 。

在 Python 编程语言中，字符串是 Unicode 字符的有序序列。字符串的一个重要特征是其**不变性**，这意味着字符串在创建后不可能改变其状态。

## 如何在 python 中定义字符串

Python 字符串由双引号(“…”)或单引号(“…”)中的边界文本或字符定义)引号。

### 示例:使用单引号和双引号定义字符串

```py
Str1 = 'Hello'
Str2 = "Welcome"

print(Str1)
print(Str2) 

```

**输出:**

```py
Hello
Welcome 
```

## Python 字符串中的三重引号

在 python 字符串中，三重引号用于表示多行字符串。我们可以使用三个连续的单引号(' ' '……')')或三个连续的双引号(" " "……" " ")来遍历多行。

### 示例:在多行中定义字符串

```py
Str3 =  '''...
Python programming Language
multiline in three single quotes
... '''

Str4 =""".....
Multiline string example 
in three double quotes
....."""
print(Str3)
print(Str4) 

```

**输出:**

```py
...
Python programming Language
multiline in three single quotes
...
.....
Multiline string example
in three double quotes
..... 
```

## 索引和切片以访问字符串

与其他编程语言类似，Python 也将字符串视为 Unicode 字符的数组。我们可以使用*索引或切片*单独或共同访问字符。

## 什么是 python 字符串中的索引？

**索引**是对字符在序列中的位置进行编号的过程，以便于轻松查找字符。索引必须始终是整数。

由于字符串是一系列 Unicode 字符，每个字符位置都用数组中相应的数字进行索引。python 中有两种类型的索引:

*   **正向步进**–步进从 0 开始，从头到尾向前移动。
*   **负步进**–步进从-1 开始，从尾部到头部向后移动。

例如，

`PYTHON `是由 P、Y、T、H、O、n 等字符组成的字符串数组，字符串长度为`6`。字符串`PYTHON `的正负索引如下表所示。

![Command Prompt](img/bbef99e9ec30daa5ca760b47660cba20.png)

### 通过正索引获取字符

参考索引号，我们可以通过使用索引操作符`[ ]`轻松地单独访问字符。以下示例显示了通过正索引提取单个字符。

### 示例:通过正索引访问字符

```py
S = 'PYTHON'
print('S[0] = ',S[0])
print('S[4] = ',S[4]) 

```

**输出:**

```py
S[0] =  P
S[4] =  O 
```

### 通过负索引获取字符

假设我们有一个长字符串，并希望在末尾找到一个字符。Python 支持从尾部到头部的倒计数。负索引总是以`-1`开始。

### 示例:通过负索引访问字符

```py
S = 'PYTHON'
print('S[-1] = ',S[-1])
print('S[-5] = ',S[-5]) 

```

**输出:**

```py
S[-1] =  N
S[-5] =  Y 
```

### 索引时字符串出错

使用索引时，在 python 中发现的两种常见错误类型是

*   **类型错误**:使用整数以外的数字进行索引时会出现类型错误。具体来说，python 在用 float 或 complex 或其他类型进行索引时会引发`TypeError`。
*   **索引错误** : `IndexError`在试图访问超出其范围的值时发生。

### 示例:索引时出错

```py
S = 'PYTHON'
print('s[4.5] = ',s[4.5])   #Exibits typeerror as index is a float value
print('s[41] = ',s[41])  #Exibits Indexerror is out of length 

```

**输出:**

```py
 print('s[4.5] = ',s[4.5])
TypeError: string indices must be integers

 print('s[41] = ',s[41])
IndexError: string index out of range 
```

## python 字符串中什么是切片？

到目前为止，我们已经讨论了如何使用索引操作符`[]`从字符串中访问单个字符。我们还可以使用范围切片操作符`[:]`从字符串中集体提取字符。

**切片**顾名思义，将序列切片为一段序列。在 Python 字符串中，索引或切片运算符`[ ]`用于访问长度为 1 的子字符串，而范围切片运算符`[:]`用于访问字符块或任意长度的子字符串。

范围切片的语法可以表示为

```py
`S[m : n]` 

```

哪里，

**S** :弦

**m** :起始指数

**n** :结束索引

S[m:n]返回从索引 m 到 n 的子串，但不包括索引 n。

为了更好地理解，请在下面找到范围切片的可视化。每个字符都放在索引之间。例如，字符 P 位于 0 和 1 之间，“PY”位于 0 和 2 之间。

![Command Prompt](img/adb06317f5b32315bbeaab3ba74d296e.png)

### 正索引切片

下表更清楚地给出了在 python 中使用正索引进行切片的想法

| 切片表达式 | 子串长度 | 输出 | 评论 |
| **S[0:5]** | five | 大蟒 | 返回从索引 0 到 4 的字符；不包括位置 5 |
| **S[0:6]** | six | 大蟒 | 返回索引 0 到 5 和 6 之间的字符(不包括在内) |
| **S[7:11]** | four | 单词 | 返回 |
| **S[6:12]** | six | w、o、r、l、d | 省略索引 12 |
| **S[: 8]** | eight | 大蟒 | 默认情况下，从开头开始，省略索引 8 |
| **S[8:]** | four | 奥尔德 | 默认情况下，计数到尾部 |

### 示例:使用正索引从字符串“python 世界”中切分子字符串

```py
S ="python world"
print("S[0:5] = ",S[0:5])
print("S[0:6] = ",S[0:6])
print("S[7:11] = ",S[7:11])
print("S[6:12] = ",S[6:12])  
print("S[:8] = ",S[:8])
print("S[8:] = ",S[8:]) 

```

**输出:**

```py
S[0:5] =  pytho
S[0:6] =  python
S[7:11] =  worl
S[6:12] =   world
S[:8] =  python w
S[8:] =  orld 
```

## 使用负索引进行切片

下表更清楚地给出了在 python 中使用负索引进行切片的想法

| 切片表达式 | 子串长度 | 输出 | 评论 |
| S[-12:-7] | five | 大蟒 | 返回从位置-8 到-12 的字符，省略位置-7 |
| S[-7:-3] | four | wo | 返回从位置-4 到-7 的字符，而省略位置-3 |
| S[-12:] | Twelve | python 单词 | 默认情况下，从尾部到尾部计数 |
| S[:-7] | five | 大蟒 | 默认情况下，从位置-8 开始计数 |

### 示例:使用负索引从字符串“python 世界”中切分子字符串

```py
S ="python world"
print("S[-12:-7] = ",S[-12:-7])
print("S[-7:-3] = ",S[-7:-3])
print("S[-12:] = ",S[-12:])
print("S[:-7] = ",S[:-7]) 

```

**输出:**

```py
S[-12:-7] =  pytho
S[-7:-3] =   wo
S[-12:] =  python world
S[:-7] =  pytho 
```

## 如何修改字符串？

字符串的一个特殊特征是它的不变性。一旦字符串被赋值给变量，我们就不能修改它。但是，我们可以通过用另一个字符串重新分配变量来更新一个字符串。

### 示例:重新分配字符串变量

```py
V = 'Python World'
print('Initially Variable V is assigned to :',V)
V = ' Python programming'
print("Variable V is reassigned to :",V) 

```

**输出:**

```py
Initially Variable V is assigned to : Python World
Variable V is reassigned to :  Python programming 
```

同样，我们可以使用关键字“del”删除整个字符串，但是在 python 编程语言中，从字符串中删除字符是无效的。删除字符串的语法如下:

`del variablename`

### 示例:删除字符串

```py
V = 'Python World'
del V
print (V) 

```

**输出:错误**

```py
print('V =',V)
NameError: name 'V' is not defined 
```

## Python 字符串函数

Python 有几个内置函数，可以用字符串执行特定的任务。最常用的字符串函数是`len()`。除了`len()`，`enumerate()`这个函数也被广泛使用，我们将在后面的教程中讨论。

`len()`函数通过计算字符串中出现的字符数给出字符串的长度。

### 示例:字符串函数

```py
#String Function
str ='Python World'
print('Length of the string is',len(str)) 

```

**输出:**

```py
Length of the string is 12 
```

## Python 字符串运算符和操作

Python 允许字符串执行各种操作。由于每个操作都是独一无二的，因此他们设计了独特的操作器。本节将解释字符串中最重要和最常见的运算符。

## 检查子字符串–成员运算符

成员运算符用于验证字符串中子字符串的存在。结果不是真就是假。如果子串存在，则返回真值，否则返回假值。python 中有两种类型的成员运算符。他们是

*   中的**:如果字符串中存在子字符串，则返回真**
*   **不在**中:如果字符串中不存在子字符串，则返回真

### 示例:成员资格验证

```py
#Membership operator
str = 'Python Member'

A ='M' in str
B='Me' not in str

print(A)
print(B) 

```

**输出:**

```py
True
False 
```

## 字符串的连接和重复

字符串的基本操作之一是串联。串联是指将两个或多个字符串粘合在一起形成一个新字符串。python 中的串联运算符是“+”加符号。请注意，在数字的情况下，加号用于加法，而在字符串中，它充当字符串连接符。

### 示例:使用+运算符的字符串串联

```py
#String Concatenation using +
s1 = 'Python'
s2 = 'World'
print('String after concatenation :',s1+s2) 

```

**输出:**

```py
String after concatenation : PythonWorld 
```

同样，使用*符号，我们可以多次重复连接一个字符串。

### 示例:使用*运算符的字符串重复

```py
#String Concatenation using *
s1 = 'Python'
print('s1*3 =',s1*3) 

```

**输出:**

```py
s1*3 = PythonPythonPython 
```

注意:由于字符串是不可变的，串联后形成的新字符串需要分配给一个新变量来存储它。

下一个需要注意的事实是，隐式字符串转换在 python 编程语言中是不可能的。因此，将一个字符串与一个非字符串类型(如数字、布尔值等)连接起来将产生一个`TypeError`。

### 示例:字符串串联:类型错误

```py
s1 = 'Python'
print( s1+3) 

```

**输出:**

```py
print( s1+3)
TypeError: can only concatenate str (not "int") to str 
```

注意:Python 只能将字符串连接成一个字符串

## Python 中的字符串格式

### 什么是字符串中的转义字符

让我们回想一下，在 python 中，字符串是用单引号或双引号分隔的。当我们试图像打印一个已经有双引号的“ **python 程序**”一样打印纯文本时会发生什么？当文本被解释时，会出现说明语法无效的语法错误。

解决这个问题的一种方法是使用三重引号——要么是 3 个连续的单引号，要么是 3 个连续的双引号。另一种选择是使用转义字符。

顾名思义，转义字符转义字符串中的特殊字符，如单引号或双引号。**反斜杠(\ )** 被认为是 python 字符串中的转义字符。换句话说，转义字符允许您将特殊字符转换为普通字符。

例如，
**这是一个“python 程序”**与**相同，这是一个 python 中的“python 程序”**。在本例中，每个特殊字符都以反斜杠作为前缀，以避开语法错误，从而允许在文本中打印特殊字符。

### 示例:字符串格式:转义字符

```py
 #String formatting
print('''it's a "python program"!!!''')       #Triple Quotes
print('it\'s a \"python program\"!!!')     #Escape Character 

```

**输出:**

```py
 #String formatting
print('''it's a "python program"!!!''')       #Triple Quotes
print('it\'s a \"python program\"!!!')     #Escape Character 
```

反斜杠也用来表示一些空白字符，如制表符、换行符、空格、回车等。

### 示例:字符串格式:转义字符

```py
 print('Straw\tBerry')
print("Mul\nBerry") 

```

**输出:**

```py
 Straw   Berry
Mul
Berry 
```

下面列出了 python 中的附加转义字符。

| 转义格式 | 规格 |
| \' | 单引号 |
| \" | 双引号 |
| \n | 换行或换行符 |
| \t | 横表 |
| \v | 垂直标签 |
| \r | 回车 |
| \b | 退格 |
| \a | 铃 |
| \f | 换页 |
| \\ | 反斜线符号 |
| \ooo | ASCII 八进制值 ooo |
| \xhh | ascii 十六进制值 hh |

## 什么是 python 中的原始字符串

python 的另一个独特特性是能够通过原始字符串的表示将转义字符视为普通字符。原始字符串只是以标题“R”或“R”开头的普通字符串。与转义序列不同，反斜杠在原始字符串中没有特殊含义。

### 示例:原始字符串

```py
 #Raw StringExample
print("Hi\tWelcome To \n PYTHON \x48 WORLD! ")
print(R"Hi\tWelcome To \n PYTHON \xWORLD! ") 

```

**输出:**

```py
 Hi      Welcome To
PYTHON H WORLD!
Hi\tWelcome To \n PYTHON \xWORLD! 
```

为了清楚地认识原始字符串，让我们仔细查看上面的示例。在上面的示例中，第一个字符串由 3 个转义字符组成-t，\n 和\x48，表示制表符、新行和十六进制表示。你可以相应地看到结果。第二个字符串被标记为原始字符串，还包含 3 个转义字符- \t，\n 和\x。这里\x 没有特定的表示或含义。即使这样，程序也能成功地打印字符串，而不会产生任何错误。这是因为原始字符串忽略了字符串文字中的所有转义字符。但是如果字符串没有被标记为原始字符串，情况就不同了。它将引发如下所示的错误。

```py
 print("Hi\tWelcome To \n PYTHON \x WORLD! ")
          ^
SyntaxError: (unicode error) 'unicodeescape' codec can't decode bytes in position 25-26: truncated \xXX escape 

```

## Python 中的字符串方法

为了有效地操作字符串，python 有一系列内置方法，如下表所示

| 不，先生。 | 方法 | 描述 |
| one | 大写() | 将字符串的第一个字母大写 |
| Two | 中心(宽度，填充字符) | 返回原始字符串居中的空格填充字符串。 |
| three | 计数(字符串、请求、结束) | 如果给定了起始索引 beg 和结束索引 end，则统计字符串或字符串的子字符串中出现的字符串。 |
| four | 解码(编码、错误) | 使用注册用于编码的编解码器对字符串进行解码。 |
| five | 编码(编码，错误) | 返回字符串的编码字符串版本；遇到错误时引发的值错误。 |
| six | endswith(后缀，beg，end) | 如果字符串或字符串的子字符串(如果给定了起始索引 beg 和结束索引 end)以后缀结尾，则确定并返回 True 否则为假 |
| seven | “制表符”(tabsize) | 将字符串中的制表符扩展到多个空格；默认情况下，tabsize 扩展到 8 个空格。 |
| eight | 查找(字符串、请求、结束) | 如果字符串或其子字符串中存在字符串的索引，则返回字符串的索引，否则返回-1。 |
| nine | 索引(字符串、beg、结束) | 返回与`find()`相同的索引，但如果未找到 str，将引发异常。 |
| Ten | isalnum（） | 如果字符串至少包含 1 个字母数字字符，则返回 true，否则返回 false。 |
| Eleven | 异相（） | 如果字符串至少有 1 个字母字符，则返回 true，否则返回 false。 |
| Twelve | isdigit（） | 当且仅当字符串包含数字时返回 true，否则返回 false。 |
| Thirteen | islower() | 如果字符串至少有一个小写字母，则返回 true，否则返回 false。 |
| Fourteen | isnumeric() | 如果 unicode 字符串只有数字字符，则返回 true，否则返回 false。 |
| Fifteen | isspace() | 如果字符串包含空白字符，则返回 true，否则返回 false。 |
| Sixteen | istitle() | 如果字符串的“标题大小写”正确，则返回 true，否则返回 false。 |
| Seventeen | isupper() | 如果字符串至少有一个大写字符，则返回 true，否则返回 false。 |
| Eighteen | 加入() | 连接多个字符串。 |
| Nineteen | 透镜(线) | 返回字符串中字符的长度或数量 |
| Twenty | 光源(宽度[，file char]) | 返回原始字符串左对齐的空格填充字符串。 |
| Twenty-one | 下部() | 将字符串中的所有大写字母转换为小写字母。 |
| Twenty-two | lstrip（） | 删除字符串中的所有前导空格。 |
| Twenty-three | maketrans() | 返回要在翻译函数中使用的翻译表。 |
| Twenty-four | 最大值(字符串) | 从字符串中返回最大字母字符数。 |
| Twenty-five | 最小值(字符串) | 从字符串中返回最小字母字符。 |
| Twenty-six | 替换(旧的、新的[，最大值]) | 将字符串中所有旧的出现替换为新的出现，或者如果给定了最大值，则最多替换为最大值。 |
| Twenty-seven | rfind(str，beg，end) | 与`find()`相同，但搜索字符串的顺序相反。 |
| Twenty-eight | rinex(str、beg、end) | 与`index()`相同，但搜索字符串的顺序相反。 |
| Twenty-nine | rjust(宽度，[，fillchar]) | 返回原始字符串右对齐的空格填充字符串。 |
| Thirty | rstrip() | 删除字符串的所有尾随空格。 |
| Thirty-one | 分割(str num) | 将字符串拆分为传递的参数，并尽可能多地返回列表。 |
| Thirty-two | 分隔线(num=string.count('\n ')) | 在所有(或数个)换行符处拆分字符串，并返回移除换行符的每行的列表。 |
| Thirty-three | start with(str，beg，end) | 如果字符串或子字符串以字符串开头(如果提供了 beg 和 end)，则返回 True。 |
| Thirty-four | 剥离([字符]) | 对字符串执行`lstrip()`和`lstrip()`。 |
| Thirty-five | swapcase() | 反转字符串中所有字母的大小写。 |
| Thirty-six | 标题() | 返回字符串的“titlecased”格式，表示所有单词都以大写字母开头，其余都是小写字母。 |
| Thirty-seven | translate(table，deletechars= ") | 根据转换表字符串(256 个字符)转换字符串，删除 del 字符串中的字符。 |
| Thirty-eight | 上() | 将字符串中的所有小写字母转换为大写字母。 |
| Thirty-nine | zfill(宽度) | 返回用零填充的原始字符串，总宽度为个字符；`zfill()`用于数字，保留任何给定的符号(小于零)。 |
| Forty | 十进制格式() | 当且仅当 unicode 字符串包含十进制字符时返回 true，否则返回 false。 |

最常用方法的示例，如`lower()`、`upper()`、`upper()`、`upper()`、`upper()`、replace 等。都给了。

### lower()–返回小写字符串

```py
 S = 'Python world'
print(S.lower()) 

```

```py
 python world 
```

### upper()–返回大写字符串

```py
 S = 'Python world'
print(S.upper()) 

```

```py
 PYTHON WORLD 
```

### replace()–用于将现有字符串替换为其他字符串

```py
 S = 'Python world'
print(S.replace('world','program')) 

```

```py
 Python program 
```