# Python 字典

> 原文：<https://learnetutorials.com/python/python-dictionaries>

在本 python 教程中，您将通过示例掌握 Python 字典的所有知识；如何创建字典，如何修改 python 字典，如何删除字典以及对字典的标准操作。除此之外，我们将学习操纵字典的方法。

字典是无序和可变的项目的集合。字典项目通常表示为用花括号{}括起来的键:值对。每个键:值对用逗号分隔。简而言之，字典是一个键值映射，如下图所示。

![Mapping](img/7866206949a3a54c37b323fe2754b044.png)

## Python 字典的主要特性

*   字典是可变的。
*   字典本质上是动态的。
*   字典可以像列表一样嵌套
*   键是唯一且不可变的，而值是可变的

## 如何用 Python 创建字典

python 中的字典可以通过在花括号{}中包含逗号分隔的键值对来定义。创建字典的另一种方法是通过内置的`dict()`功能。

### 字典的句法

```py
<dict_name> = {
      <key>:<value>,
      <key>:<value>,
      .
      .
      <key>:<value>
} 

```

**空字典:**零项 Python 字典。

### 示例:如何定义空字典

```py
emp_dict ={}
print(type(emp_dict)) 
```

**输出:**

```py
 <class 'dict'> 
```

**同质字典:**具有相同不可变数据类型的关键字的字典。

### 示例:如何创建同构字典

```py
int_dict={1:'Odd',2:'Even'}
print(int_dict) 
```

**输出:**

```py
 {1: 'Odd', 2: 'Even'} 
```

**混合字典:**具有不同不可变数据类型的键的字典。

### 示例:混合字典

```py
mix_dict={1:'Student','name':'Tom','Marks':[45,46,47,48,50 ]}
print(mix_dict) 
```

**输出:**

```py
 {1: 'Student', 'name': 'Tom', 'Marks': [45, 46, 47, 48, 50]} 
```

到目前为止，我们已经讨论了各种类型的字典及其创作。创建字典的另一种可能方法是使用名为`dict()`的函数。

### 示例:`dict()`函数

```py
fn_dict = dict({'Name':'John','Age':30})
print(fn_dict) 
```

**输出:**

```py
 {'Name': 'John', 'Age': 30} 
```

## 字典中键和值的属性

python 字典中的两个重要因素是键和值。它们的属性如下所示。

1.  The key must be unique means there should be no duplication. If a dictionary contains duplicate keys then the last assignment will be considered.

    ### 示例:说明密钥不包含重复项

    ```py
     fn_dict = dict({'Name':'John','Age':30 ,'Name':'Charles'})
    print(fn_dict) 

    ```

    **输出:**

    ```py
     {'Name': 'Charles', 'Age': 30} 
    ```

2.  Keys are immutable means they are unchangeable over the lifetime after creation. Keys can be integer, string, tuples but never be a list.

    示例:当键是列表时显示错误

    ```py
     D = {['odd']:(1,3,5,7,9)}
    print(D) 

    ```

    **输出:**

    ```py
     D = {['odd']:[1,3,5,7,9]}
    TypeError: unhashable type: 'list' 
    ```

3.  Values are free of restrictions and they can be any data type and can be of any length.

    ### 示例:显示值可以是任何类型和任何长度

    ```py
     D = {'odd':[1,3,5,7,9]}
    print(D) 

    ```

    **输出:**

    ```py
    {'odd': [1, 3, 5, 7, 9]} 
    ```

## 什么是 Python 中的嵌套字典？

在 Python 中，包含另一个字典的字典称为嵌套字典。嵌套可以在任何级别进行，没有任何限制。这可以可视化，以便更好地理解。

![Nested Dictionary](img/361fa6f5d8a36aa0560c505280e86627.png)

### 嵌套字典

```py
University= {
 'UN_Name':'Oxford',
 'Stud':{   'St1_Name':'Tom','St2_Name':'Becky' }
}
print(University) 

```

**输出:**

```py
{'UN_Name': 'Oxford', 'Stud': {'St1_Name': 'Tom', 'St2_Name': 'Becky'}} 
```

## Python 中如何访问字典值？

我们知道字典是一个无序的`key: value`对的集合。即使它们看起来像它们是如何定义的，当涉及到访问时，数字索引不起作用。这是因为 python 将数值解释为键而不是索引。那么我们如何从字典中获取值呢？

字典使用键从字典中检索值。为了访问值，我们使用相同的方括号，里面是键，而不是索引。我们也可以使用`get()`方法来实现同样的目的。

为了理解，让我们检查下面的例子。

### 从字典中访问值

```py
mix_dict={1:'Student','name':'Tom','Marks':[45,46,47,48,50 ]}
print('mix_dict[1] = ',mix_dict[1])
print("mix_dict['name'] = ",mix_dict['name'])
print("mix_dict['Marks'] = ", mix_dict.get('Marks') 

```

**输出:**

```py
mix_dict[1] =  Student
mix_dict['name'] =  Tom
mix_dict['Marks'] =  [45, 46, 47, 48, 50] 
```

## 访问未定义的值

现在，假设您试图使用字典中没有定义的键来访问一个值。会发生什么？

显然，结果会是一个例外。如果我们引用了字典中没有的键，解释器会发出`KeyError`。只有当我们使用方括号[]来访问值时，才会出现这种情况。`get()`方法返回`None` 作为输出。

### 访问未定义的键时出现键错误

```py
 D= { 'A':'Apple','B':'Banana'}
print(D.get('C'))
print(D['C']) 

```

**输出:**

```py
 None
print(D['C'])
KeyError: 'C'

```

## 如何从嵌套字典中访问值

### 示例:从嵌套字典中访问值

```py
 D={ 
   'D1':{2:4,3:9},
   'D2':{4:64,5:125} 
}
print(D['D1'])
print(D['D2'])
print(D['D1'][3])
print(D['D2'][5]) 

```

**输出:**

```py
 {2: 4, 3: 9}
{4: 64, 5: 125}
9
125

```

## 如何修改 Python 集

字典的可变行为使得通过添加单个或一组条目或替换现有值来修改字典成为可能。向字典添加条目的三种方法如下。

1.  向空字典添加单个条目

    ### 示例:如何向空集合添加元素

    ```py
    Student ={}
    Student[' First_Name']='Charles'
    Student['Last_Name'] = 'Smith'
    print("\n Dictionary after adding two entries one at a time :",Student) 

    ```

    **输出:**

    ```py
     Dictionary after adding two entries one at a time :
    {' First_Name': 'Charles', 'Last_Name': 'Smith'} 
    ```

2.  **update()** function : to add multiple entries to dictionary in one shot

    ### 示例:如何在一个镜头中添加多个元素

    ```py
     Student = {' First_Name': 'Charles', 'Last_Name': 'Smith'}
    Student.update({'ID':10001, 'Department':'Science'})
    print("\n Dictionary after adding multiple entries in one shot :", Student) 

    ```

    **输出:**

    ```py
     Dictionary after adding multiple entries in one shot :
    {' First_Name': 'Charles', 'Last_Name': 'Smith', 'ID': 10001, 'Department': 'Science'} 
    ```

3.  Nesting a dictionary by adding another dictionary

    ### 示例:向现有字典添加字典

    ```py
    Student = {' First_Name': 'Charles', 'Last_Name': 'Smith', 'ID': 10001, 'Department': 'Science'}
    Student['Marks'] ={'Physics':100 ,'Chemistry':98}
    print("\n Dictionary after nesting : \n ",Student) 

    ```

    **输出:**

    ```py
    Dictionary after nesting :
    {' First_Name': 'Charles', 'Last_Name': 'Smith', 'ID': 10001, 'Department': 'Science', 'Marks': {'Physics': 100, 'Chemistry': 98}} 
    ```

我们还可以通过更改或替换现有值来修改字典。这可以通过引用它的键来完成。在下面的示例中，通过引用其键 Last_Name，将现有值 Smith 更改为 David。

我们还可以通过更改或替换现有值来修改字典。这可以通过引用它的键来完成。在下面的示例中，通过引用其键 Last_Name，将现有值 Smith 更改为 David。

### 示例:更改字典中的值

```py
 Student = {' First_Name': 'Charles', 'Last_Name': 'Smith'}
Student['Last_Name']='David'
print(Student) 

```

**输出:**

```py
{' First_Name': 'Charles', 'Last_Name': 'David'}
```

## 如何在 Python 中从字典中移除元素

修改字典的另一种方法是移除其中的元素。有各种方法可以删除字典中的元素。它们列在下面。

1.  **pop()** Method: is a built-in function in a dictionary. It is used to remove a distinct item from a dictionary by referring to its key and this method returns the removed value.

    ### 示例:使用`pop()`方法从字典中移除元素

    ```py
     Student = {' First_Name': 'Charles', 'Last_Name': 'Smith'}
    print(Student.pop('Last_Name'))
    print("Dictionary after removal is:",Student) 

    ```

    **输出:**

    ```py
     Smith
    Dictionary after removal is: {' First_Name': 'Charles'} 
    ```

2.  **popitem()** Method: is a built-in function used to remove the last inserted key-value pair from the dictionary and will return the key-value pairs.

    ### 示例:使用`popitem()`方法从字典中移除元素

    ```py
     Student = {' First_Name': 'Charles', 'Last_Name': 'Smith','Age':27}
    print(Student.popitem())
    print("Dictionary after removal is:",Student) 

    ```

    **输出:**

    ```py
     ('Age', 27) 
    ```

3.  **clear()** Method: is a built-in function used to remove or clear all the elements in a dictionary.

    ### 示例:使用`clear()`方法移除元素

    ```py
     Student = {' First_Name': 'Charles', 'Last_Name': 'Smith','Age':27}
    print(Student.clear())
    print("Dictionary after removal is:",Student) 

    ```

    **输出:**

    ```py
    None 
    ```

4.  **del keyword:** can be used to remove either individual elements or the entire dictionary itself.

    ### 示例:使用 del 关键字移除元素

    ```py
     Student = {' First_Name': 'Charles', 'Last_Name': 'Smith','Age':27}
    del Student['Age']
    print("Dictionary after removal is:",Student)
    del Student
    print("Dictionary after removal is:",Student) 

    ```

    **输出:**

    ```py
    Dictionary after removal is: {' First_Name': 'Charles', 'Last_Name': 'Smith'}
        print("Dictionary after removal is:",Student)
    NameError: name 'Student' is not defined 
    ```

## 如何在 Python 字典中执行成员资格验证

与其他数据类型一样，我们可以使用成员操作符来验证字典中键的存在。这两个成员操作符是:

*   中的**:只有当关键字出现在字典中时才返回真。**
*   **不在**中:字典中没有关键字时返回 false。

### 示例:成员资格验证

```py
 D ={
   0:'Red',
   2:'Green',
   4:'Blue'
   }
print(0 in D)
print(3 not in D) 

```

**输出:**

```py
True
True 
```

## Python 字典内置函数

为了完成一些特定的任务，python 有一些内置的字典功能。它们列在下表中。

| 功能 | 描述 |
| 全部() | 如果字典中的所有键都为真，则返回真 |
| 任何() | 如果字典中的任何键为真，则返回真 |
| len() | 返回字典中键值对的数量 |
| 已排序() | 返回已排序的键列表 |

## Python 字典方法

像函数一样，Python 字典也有执行特殊任务和返回特定值的方法。它们在下表中列出。

| 方法 | 描述 |
| [晴()](../python/methods/clear) | 清除字典中的所有项目 |
| 复制() | 返回字典的一个简单副本 |
| fromkeys(seq[，v]) | 返回一个新字典，其中包含来自 seq 的键和相关值 v。 |
| 得到(钥匙[d]) | 返回键的关联值。 |
| 项目() | 返回键值对格式的列表 |
| 按键() | 返回字典中的键列表 |
| 砰的一声 | 移除字典中引用其键的元素 |
| popitem() | 移除并返回最后插入的条目 |
| setdefault（key[，d]） | 如果密钥不可用，则将密钥设置为默认值 |
| 更新() | 用新条目或替换现有条目返回更新的字典。 |
| 值() | 返回字典中的值列表 |