# Python 决策语句

> 原文：<https://learnetutorials.com/python/decision-making-statements>

在本 python 决策语句教程中，我们将掌握 python 编程中使用的所有决策结构，如 if、if-else、if elif 等。此外，我们将通过示例讨论决策语句的语法和流程图。

为了便于理解，让我们以交通信号的真实场景为例。当交通信号灯变红时会发生什么？所有车辆将停止。绿灯亮时，车辆将开始行驶。因此，道路上的车辆流量由交通信号控制。

类似地，在编程世界中，决策结构被用来控制程序的流程。它预测结果并基于结果执行程序代码。条件语句的结果是类似`True`或`False`的布尔值。

注意:Python 将非零值读取为真，而将无和零读取为假。

## python 中的 if 条件语句

简单地说，单词`if `表示一个条件或假设。类似地，在 python 编程语言中`if `是一个引用条件语句的决策构造。

在决策中，构造`if` 是最基本的一个。`If`评估应用于它的表达式，并检查该表达式是否满足条件。当表达式满足条件时，结果将为真，python 将执行结果后面的语句块。否则，它会跳过该块并跳到该块之后的语句。

## python 中 IF 条件语句的语法

```py
if condition:
   #body of if 

```

## python 中 IF 条件语句的流程图

使用下面给出的流程图可以最好地可视化 if 条件语句。

![Python If Flowchart](img/3db901c1c2ec5a2bf3314c58e211f958.png)

### 示例:显示“如果”工作的程序

```py
 a = 20;

if a>10:
 print('a is greater than 10')

print('Bye!!!!') 

```

**输出:**

```py
 A is greater than 10
Bye!!!! 
```

在上面的示例中，评估条件`a>10`以找出变量`a` 是否具有大于`10`的值。在我们的例子中，变量`‘a’`保持大于 10 的值`20` ，因此条件为`True`。因此，程序控制指向 if 的下一个语句，并将结果打印为 **a 大于 10** 。然后程序控制被转移到语句中的“if”缩进之外。

注:决策声明依赖缩进。

单个 if 语句的限制是它只执行 True 之后的语句。虚假情况不会在单个 if 语句中解决。

## python 中的 If else 语句

为了克服单个“if”语句的限制，我们使用了“else”语句。具体来说，在 if-else 语句中，python 计算条件并输出结果，如下所示:

*   如果条件为**真**，则执行 if 的主体
*   如果条件为**假**，则执行 else 的主体。

## python 中 if-else 条件语句的语法

```py
 if Condition:
#execute body of if
else:
 #execute body of else 

```

## python 中 if else 语句的流程图

![Python If Syntax](img/cdff4139fcd1ee0aa252333172c5d6e4.png)

现在我们可以检查 if else 语句在 python 程序中是如何工作的

### 例子:如果没有别的程序

```py
a = 20;

if a<10:
 print('a is less than 10')
else:
 print('a is greater than 10') 

```

**输出:**

```py
 a is greater than 10
```

上面的例子评估了条件`a<10`。如果条件评估为`True` ，则打印`a is less than 10`，或者如果条件评估为假，则程序控制转移到其他部分并打印`a is greater than 10`。在这种情况下，变量“a”包含大于 10 的值 20，因此结果是 else part 语句 ie。a 大于 10。

## 中频 ELIF 语句

这是 if else 的复杂版本。在这里`elif` 是一个 python 关键字，指的是`else..if`。简而言之，如果 elif else 是一串条件语句。它有时被称为 **if elif else** 梯子。

## python 中 IF ELIF ELSE 条件语句的语法

```py
 if Condition1:
#execute body of if
elif Condtion2:
 #execute body of elif
elif Condition3:
 #execute body if elif
else:
#execute body if else 

```

## elif 流程图

![Python IF ELIF ELSE Flowchart](img/397f6f7ede99dd84b1ee7624f00f8487.png)

下面是 if 的例子.. 否则如果..else 语句。

### 示例:如果... 否则如果...其他

```py
a = 10
b = 20

if a==b:
    print('a is equal to b')
elif a < b:
    print("a is less than b")
else: 
    print("a is greater than b")
print('Exit') 
```

**输出:**

```py
a is less than b
Exit 
```

在上面的例子中，条件`a== b`被评估。如果 a 和 b 保持相同的值，则执行 If 部分的主体并打印`a is equal to b`。但是在我们的例子中，条件的计算结果为假，因此，如果执行了部分，它将再次计算条件 a 是否小于 b。由于变量 a 的值为 10，而 b 的值为 20，因此条件评估为真，并打印`a is less than b`作为结果。

如果 a 为 20，b 为 10，则条件失败，否则部分执行，结果为`a is greater than b`。

## 嵌套 If

在某些情况下，即使表达式的计算结果为真，我们也需要检查其他条件。在这种情况下，我们使用嵌套 if，尽管它是多么复杂。嵌套 if 的复杂性取决于包含的嵌套级别。

一个包含另一个 if 语句的 if 语句称为**嵌套 if** 。我们可以嵌套一个简单的 if 或 if else 语句或 if elif else 语句。这纯粹是程序员的选择，因此没有通用的语法或流程图可用。但是，为了更好地理解，请考虑下面的语法和流程图。

## 嵌套 if 的语法

```py
 if Condition1:
#execute body of if(condition1)
    if Condtion2:
 #execute body of if (condition 2)
    elif Condition3:
 #execute body if elif
    else:
#execute body of else (nested)
else:
   #execute body of else 

```

## 嵌套 if 的流程图

![Python Nested If](img/4af70ea792c50d81f52508308a4c618e.png)

### 示例:嵌套 if

```py
a = 25
b = 20

if a > 0:
 if a==b:
     print('a is equal to b')
 elif a < b:
     print("a is less than b")
 else: 
     print("a is greater than b")
else:
 print("a is less than 0")
print('Exit') 
```

**输出:**

```py
a is greater than b
Exit 
```

在上面的例子中，最初`a >0`被评估。
如果`a>0`为真，则程序控制移到嵌套 if。在这种情况下，a 保持值 25，因此 a 大于零，并移动到嵌套的 if。
现在评估条件 `a==b`，其结果对于我们的场景是错误的 `a=25`和`b=20`。
因此流程转移到 elif，在此检查条件 a **。所以我们的案例打印 a 大于 b**