# Python 类和对象

> 原文：<https://learnetutorials.com/python/classes-objects-oops>

在本教程中，您将掌握面向对象编程(OOPs)的基本概念。此外，您将通过示例了解对象、定义类、什么是实例等。

## python 中的 oops 简介

Python 作为一种多范例编程语言，使开发人员能够选择他希望的任何脚本编写方法，包括过程、函数、命令和面向对象的风格。面向对象编程，通常缩写为 OOPS，因其简单性和结构的独特性而被普遍接受。顾名思义，对象和类一样是 **OOPS** 概念的中枢。换句话说，面向对象编程语言的基础是对象和类。

## python 中的面向对象编程

面向对象编程是一种编程范式，它通过使用“**对象**的思想来实现一种结构化程序的方式。对象的两个重要特征是**属性**和**行为**。

例如，学生可以是一个具有姓名、班级、id_no 等属性以及说话、唱歌、跳舞等行为的对象。类似地，移动电话可以被表示为具有诸如名称、型号、颜色等属性以及诸如呼叫、消息传递、上传、下载等行为的对象。

在编程中，对象可以用来表示与代码相关联的数据和方法。通过将属性和行为绑定到单个对象中，OOPS 方法促进了代码的整洁和组织。此外，它还通过实现代码可重用性来减少冗余。关注代码可重用性的概念被称为“ **DRY** ，意思是不要重复代码。

在进入细节之前，让我们看看面向对象编程和面向过程编程有什么不同。

| 面向对象编程 | 面向过程的编程。 |
| 处理数据 | 处理算法 |
| 程序被分成对象 | 程序分为功能 |
| 遵循自下而上的方法 | 遵循自上而下的方法 |
| 对象可以在成员函数中自由移动 | 数据可以在程序内的函数之间移动 |
| 包含访问说明符，如私有、公共和受保护 | 不包含访问说明符 |
| 支持继承 | 不支持继承 |
| 支持重载 | 不支持重载 |
| 数据隐藏是可能的 | 数据隐藏是不可能的 |
| 需要更多内存 | 需要较少的内存 |
| 高度安全 | 不太安全 |
| 例如:C++、Java、Python 等 | 例:c、FORTRAN、Pascal 等等 |

## 什么是阶级

在面向对象编程中，类是用于创建对象的用户定义的数据结构。用户可以定义一组**属性**和函数，称为方法，与类中的对象相关联。类中的方法标识在类中创建的对象需要对其数据执行的行为和动作。简而言之，我们可以说一个类是定义共同属性和方法的对象的集合或对象的蓝图。

## 如何定义一个类？

所以现在你很清楚什么是类了。现在我们来看看如何定义一个**类**。
一个**类**的定义总是以关键字类开始，后跟`class_name`和一个冒号。类的主体按照缩进规则编写在下面。

**语法如下**:

```py
class Class_name:
 . . . . . . . . 
 class_body 
 #Here you can define all attributes and methods
 . . . . . . . . 

```

本教程将教您创建一个名为 Student 的类来存储学生的一些基本特征，如姓名、年龄、身份证号和学生可能具有的素质。这里有一个例子:

```py
class Student:

    #class attribute
    Dept = 'Computer Science'

     #instance attribute
    def __init__(self,name,age):
        self.name=name
        self.age=age 

```

现在，让我们仔细检查一下这个例子，以更清楚地了解类的概念。在这个例子中，

*   我们和学生一起创建了一个**班级**。
*   一个类可以包含两种类型的属性，即实例属性和类属性。
    *   实例属性是显示学生对象属性(姓名、年龄和卷号)的属性。实例属性总是在名为。`__init__()`。一旦创建了对象，此方法就初始化实例属性。您可以将任意数量的参数传递给`.__init__`方法，但是要考虑的第一个参数应该始终是一个名为 self 的变量。
        *   **自身参数**用于用参数初始化属性。
        *   `self.name = name`表示创建名为 name 的实例属性，参数值被分配给该属性。
        *   `self.age = age`表示创建名为的实例属性
    *   **类属性**是对类中的所有实例保持相同值的属性，这些实例总是在之外声明。`__init__ ()`方法。在我们这里，所有的学生都属于计算机科学系。因此`Dept`就在前面被声明为类属性。`__init__()`法。

本质上，类属性用于定义对所有类实例保持相同值的属性，而实例属性用于定义对每个类实例保持唯一值的属性。

在用 python 编写类时，必须小心缩进，因为缩进在构建程序中起着至关重要的作用。在上面的示例中，您可以发现每个组件的结构以及缩进是如何保持的:

*   就在类下面定义的类属性由**四个空格**指定。
*   那个。 **__init__()** 方法由四个空格组成，而方法体使用 **8 空格**缩进。

如果您没有使用正确的缩进，您将收到一个缩进错误。
那么我们现在已经定义了学生类。让我们创造一些学生作为班级的对象。

## 什么是对象

对象，也称为实例，是类的实例化。更具体地说，对象意味着类的实例。

通过定义一个类，我们只创建了对象的描述。尚未分配内存或空间。让它意味着你需要实例化一个对象。这可以通过使用 class_name 后跟包含要传递给的值的括号来实现。`__init__()`方法。

**语法为**:

```py
obj = Class_name() #S1 = Student() 

```

其中 obj 是类的对象。

现在考虑您忘记提供要传递给的参数的场景。实例化对象时使用`__init__()`方法。Python 将简单地引发一个名为`TypeError`的错误，如下图所示。

```py
class Student:

    #class attribute
    Dept = 'Computer Science'

     #instance attribute
    def __init__(self,name,age):
        self.name=name
        self.age=age

S1 = Student()
S2 = Student()

```

**输出误差:**

```py
Traceback (most recent call last):
  File "oops_ex.py", line 11, in <module>S1=Student()
TypeError: __init__() missing 2 required positional arguments: 'name' and 'age'</module> 
```

为了避免这个错误，您需要在实例化对象时在括号内传递参数。以下示例显示了这一点:

```py
class Student:

    #class attribute
    Dept = 'Computer Science'

     #instance attribute
    def __init__(self,name,age):
        self.name=name
        self.age=age

S1 = Student("Chris", 17)
S2 = Student("Debora",16) 

```

在我们的例子中`S1` 和`S2` 是类的两个实例。`S1`是包含两个属性`Chris`和`17`的类的对象。类似地，`S2`表示包含两个属性`Debora`和`16`的类的对象。

## 如何使用对象访问属性

从类中访问属性根本不是什么大任务。可以使用**点运算符**和对象一起访问。下面的示例显示了访问实例属性和类属性的方式。

在点运算符的帮助下，使用对象`S1`访问类属性 Dept，点运算符将结果输出为计算机科学。

```py
>>> print(S1.Dept)
Computer Science 

```

类似地，实例属性可以使用对象的点运算符来访问。参考下面的例子来理解这个概念。

```py
class Student:

    #class attribute
    Dept = 'Computer Science'

     #instance attribute
    def __init__(self,name,age):
        self.name=name
        self.age=age

S1 = Student("Chris", 17)
S2 = Student("Debora",16)

print('Hi I am',S1.name,'and I am',S1.age,'years old')
print('Hi I am',S2.name,'and I am',S2.age,'years old')

```

**输出:**

```py
Hi I am Chris and I am 17 years old
Hi I am Debora and I am 16 years old 
```

这里，`S1.name`和`S1.age`表示在点运算符的帮助下，从实例`S1`的类中访问实例属性名称和年龄，产生结果`Chris`和`17`。类似地`S2.name`和`S2.age`访问例如`S2`的属性。

## 如何动态修改属性

在面向对象编程中，我们可以通过添加新属性、改变属性值或删除属性本身来动态修改属性。

### 添加新属性

我们稍微修改了一下我们的例子，增加了一个新的属性`S1.idno = 10001`。当您观察该示例时，您可以注意到新属性不是在类内部定义的，而是在类外部动态定义的。

```py
class Student:

    Dept = 'Computer Science'

    def __init__(self,name,age):
        self.name=name
        self.age=age

S1 = Student("Chris", 17)
S1.idno = 10001

print('Hi Iam',S1.name,'and Iam',S1.age,'years old holding idno:',S1.idno) 

```

**输出:**

```py
Hi Iam Chris and Iam 17 years old holding idno: 10001 
```

### 改变属性值

还可以动态改变属性值。请参见下面我们更改了的程序。`S1`到`Tom`的名称属性，之前分配给`Chris`。以类似的方式修改了类属性。计算机科学系。

```py
class Student:

    #class attribute
    Dept = 'Computer Science'

     #instance attribute
    def __init__(self,name,age):
        self.name=name
        self.age=age

S1 = Student("Chris", 17)
S1.name ='Tom'
S1.Dept ='Science'

print('Hi I am',S1.name,'and I am',S1.age,'years old')

```

**输出:**

```py
Hi Iam Tom and Iam 17 years old.
Science 
```

最突出的一点是，默认情况下，所有自定义对象都是可变的。具体来说，我们可以说可变对象可以动态改变，而不可变对象不能。所以列表和字典是可变的，而字符串和元组是不可变的。

### 删除属性

您也可以使用后跟点运算符的`del`关键字删除属性。

```py
S1.idno = 10001
del S1.idno

```

这里它删除了属性 id.no。

## 内置类属性

下面列出了 python 中的内置属性。它们可以使用点符号来访问，如下例所示。

*   __dict__:命名空间字典
*   __ 文档 _ _:给出了 sting 文档
*   __name__:给出类名
*   __module__:给出在其中定义类的模块名称
*   _ _ bases _ _:给出基类元组

```py
class Student:

    #class attribute
    Dept = 'Computer Science'

     #instance attribute
    def __init__(self,name,age):
        self.name=name
        self.age=age

print("Student.__dict__:",Student.__dict__)
print("Student.__doc__:",Student.__doc__)
print("Student.__name__:",Student.__name__)
print("Student.__module__:",Student.__module__)
print("Student.__bases__:",Student.__bases__) 

```

**输出:**

```py
Student.__dict__: {'__module__': '__main__', 'Dept': 'Computer Science', '__init__': <function at="" student.__init__="">, '__dict__': <attribute>, '__weakref__': <attribute>, '__doc__': None}
Student.__doc__: None
Student.__name__: Student
Student.__module__: __main__
Student.__bases__: (<class>,)</class></attribute></attribute></function> 
```

## 糟糕-实例方法

面向对象编程支持在类中使用方法。实例方法可以称为在类中定义的函数，用于指定对象的行为。要记住的要点是，始终确保从该特定类本身的实例中调用实例方法。此外，实例方法的第一个参数始终是`self`，如。`__init__()`方法。

让我们通过仔细观察下面的例子来看看如何创建一个实例方法。在我们的学生课上，我们有两种实例方法，即

*   **student details()**:给出学生的详细信息
*   **StudAct()** :赋予学生的技能

```py
class Student:

    #class attribute
    Dept = 'Computer Science'

     #instance attribute
    def __init__(self,name,age):
        self.name=name
        self.age=age

  #instance Methods
    def StudDetails(self):
        print('Hi Iam',self.name,'and Iam',self.age,'years old. ') 

    def StudAct(self, activity):
        print(self.name,'is good at',activity)

S1 = Student("Chris", 17)
S2 = Student('Debora',16)

S1.StudDetails()  #calling instance method StudDetails()
S2.StudDetails()

S1.StudAct("Football") #calling instance method StudAct()
S2.StudAct('Tennis') 

```

在本例中，`StudDetails()`方法被定义为打印学生的姓名和年龄。`StudAct()`方法打印特定学生擅长的活动。例如，在调用`S1.StudDetails()`方法时，控制转移到函数 StudDetails，该函数在类 Student 中定义，执行打印功能。学生详细信息中定义的参数是自我的，它给出了`.__init__()`方法中定义的值。因此，我们可以访问实例属性`.name`和`.age`。最后，输出打印为 Hi Iam Chris 和 Iam 17 岁。

以同样的方式`S1.StudAct("Football")`打印输出，因为克里斯擅长足球，其中参数“足球”被传递给方法定义中的“活动”参数。

**输出:**

```py
Hi Iam Chris and Iam 17 years old.
Hi Iam Debora and Iam 16 years old.
Chris is good at Football
Debora is good at Tennis 
```