# python 中的迭代器

> 原文：<https://learnetutorials.com/python/iterators>

在本 python 教程中，您将掌握 python 中迭代器的优雅概念。您还将在`__iter__()`和`__iter__()`方法的帮助下，用 python 构建自己的迭代器，并提供非常方便的示例。

在进入主题之前，让我们快速回顾一下什么是迭代，什么是 python 中的可迭代，我们已经在教程 [Python 循环](../python/python-loop-tutorials)中讨论过了。**迭代**是为多个实例重复一组代码的过程，或者直到它们满足特定条件(例如:for 循环和 while 循环)。 **Iterables** 是指可以重复或迭代的对象(例如:字符串、列表、元组等)。

## 什么是迭代器

python 编程语言中的**迭代器**是一个用于在迭代中对可迭代对象进行迭代的对象。迭代器存储迭代的状态，因此它一次返回一个项目。在 python 中，迭代器本质上是为循环、理解、生成器等实现的。

## 如何创建迭代器

从技术上讲，迭代器对象必须使用迭代器协议，该协议包含两个函数`__iter__()`和`__iter__()`。`iter()`函数将 iterable 转换为迭代器，而`__iter__()`函数调用 iterable 中的下一项。

```py
Str_list = ['Yellow','Orange','Red']

it_obj = iter(Str_list)

print(it)

print(next(it_obj))
print(next(it_obj))
print(next(it_obj))
print(next(it_obj)) 

```

**输出:**<samp><list_iterator at="" object=""></list_iterator></samp>

```py
<list_iterator at="" object="">Yellow
Orange
Red
Traceback (most recent call last):
  File "iter_ex.py", line 17, in <module>print(next(it))
StopIteration</module></list_iterator> 
```

在上面的代码片段中，您可以看到迭代器的创建及其实现。

*   最初，我们定义了一个名为`Str_list`的列表，它包含三个字符串元素“`Yellow`”、“`Orange`”和“`Red`”。
*   其次，我们借助`iter()`函数创建了迭代器`it_obj`，该函数将列表转换为迭代器。
*   第三，我们使用函数`print(it)`，假设结果将是迭代器值，即列表中的第一个元素(黄色)。相反，它打印迭代器的对象。
*   为了获得迭代器值，python 有一个名为`next()`的内置函数。`print(next(it_obj))`打印列表中的第一个元素，即黄色。
*   下一个`print(next(it_obj))`打印列表中的下一个元素，即橙色。
*   后面的`print(next(it_obj))`打印列表中的下一个元素，即红色。
*   最后一个和`final  print(next(it_obj))`以异常**结束迭代**，因为列表已经结束，没有更多的值可以返回。

由此，我们了解到，通过使用`next()`函数，我们**手动**迭代可迭代表中的项目。

为了更方便，我们有另一种优雅的迭代方式，这就是循环迭代的**。使用如下所示的 for 循环，同样的例子可以自动实现**。****

```py
Str_list = ['Yellow','Orange','Red']

for i in Str_list:
 print(i) 

```

**输出:**

```py
Yellow
Orange
Red 
```

## for 循环如何在内部工作

在解释 FOR 循环如何在 Python 内部工作之前，只需看看下面的代码片段并对其进行分析。

```py
Str_list = ['Yellow','Orange','Red']

it_ob = iter(Str_list)

while True:
 try:
     i = next(it_ob)
     print(i)
 except StopIteration:
     break 

```

**输出:**

```py
Yellow
Orange
Red 
```

循环的[就是这样在内部实现的。for 循环本质上创建了一个迭代器对象，然后在](../python/python-loop-tutorials#for) [while 循环](../python/python-loop-tutorials#while)中使用`next()`函数迭代类似 list 的迭代器。当迭代表到达末尾并试图再次迭代时，程序将停止并引发异常。

## 如何用 python 创建自己的迭代器

我们已经看到迭代器在内置结构上的工作。现在让我们尝试创建我们自己的迭代器，即用户定义的版本。我们需要记住的一点是，在创建迭代器时，我们必须实现迭代器协议。具体来说，我们必须使用`iter()`和`iter()`
所以我们创建一个迭代器来产生一个偶数平方的结果。输出将采用以下形式。

```py
class Pow:
    def __iter__(self):
    self.a = 0
    return self

  def __next__(self):
     x = self.a**2
     self.a =  self.a + 2
     return x

even = Pow()
it_ob = iter(even)

print(next(it_ob))
print(next(it_ob))
print(next(it_ob))
print(next(it_ob))
print(next(it_ob)) 

```

**输出:**

```py
0
4
16
36
64 
```

## 什么是无限迭代器

当您观察上面的代码时，您可以注意到代码中没有包含终止步骤，这意味着迭代器将无限迭代。为了清楚地理解它，让我们使用“for 循环”来迭代我们的类`Pow`。

```py
for i in Pow():
 print(i) 

```

**输出:**

```py
0
4
16
36
64
100
.
.
. 
```

那些无限迭代的迭代器称为无限迭代器。虽然编码这不是一个公平的做法，因此我们必须小心将终止语句包含在程序中。

## 如何停止迭代

所以现在我们意识到我们需要停止迭代来防止永无止境的迭代。为此，我们在`next()`函数中使用了一个 StopIteration 语句，如下面的代码片段所示。

```py
class Pow:
  def __init__(self, max =0):
     self.max = max

  def __iter__(self):
    self.a = 0
    return self

  def __next__(self):
    if self.a<=self.max:
     x = self.a**2
     self.a =  self.a + 2
     return x
    else:
     raise StopIteration

even = Pow(5)
it_ob = iter(even)

print(next(it_ob))
print(next(it_ob))
print(next(it_ob))
print(next(it_ob))
print(next(it_ob)) 

```

**输出:**

```py
0
4
16
Traceback (most recent call last):
  File "iter_ex.py", line 47, in <module>print(next(it_ob))
  File "iter_ex.py", line 39, in __next__
    raise StopIteration
StopIteration</module> 
```

用 for 循环实现的相同代码如下:

```py
 for i in Pow(8):
 print(i) 

```

**输出:**

```py
0
4
16
36
64 
```

在程序中使用迭代器的主要好处是它们节省了资源，这意味着除了一个内存之外，不需要特殊的内存来获取所有的元素。理论上，它说无限的元素可以存储在有限的内存中。**