# Python 生成器

> 原文：<https://learnetutorials.com/python/generators>

在本教程中，您将掌握 python 中关于生成器的一切。借助简单的例子，您将探索什么是生成器，如何创建和操作生成器，关键字 yield 的意义，生成器在 python 中有多有用等。

## python 中的生成器是什么？

从我们之前的教程中，您已经获得了在 python 中创建[迭代器的知识，这使您能够理解后端的循环工作。使用`iter()`方法和`next`方法、停止迭代异常等使得代码更加拉长。此外，记住大型数据集或程序的事实似乎违反直觉，在这种情况下，自动化对有效执行更受欢迎。](../python/iterators)

在 python 编程中，生成器是一种特殊的函数或表达式，它在迭代生成器对象时一次生成一个结果。使生成器比迭代器更有效的一个重要特性是内存空间的利用率。生成器通常对虚拟序列进行操作，不一定需要将整个序列存储在内存中。

## 我们如何用 python 创建生成器？

在 python 中，创建生成器的两种很酷的方法是使用:

*   生成器表达式
*   使用 yield 关键字的生成器函数

## 使用生成器表达式创建生成器

生成器表达式的使用是在 python 中构建生成器的一种方式。这种方法对于像 python 中的列表这样的小数据集更方便。生成器表达式遵循列表理解的语法，因此我们可以在使用列表理解的区域使用生成器表达式，这样可以减少内存消耗。序列或序列被虚拟地维护，并且不需要将整个序列保存在存储器中。

为了更清楚地理解生成器表达式的概念，让我们来看看下面这个简单而优雅的例子，它展示了列表和生成器之间的区别。

### 程序 1

```py
Str_list = ['Yellow','Orange','Red']

#  list comprehension
list = [x for x in Str_list]

# print the type
print(type(list))

# Iterate over items in list and print -1st time
for item in list:
    print(item)

# Iterate over items in list and print -2nd time
for item in list:
    print(item) 

```

**输出:**<samp><class></class></samp>

```py
<class>Yellow
Orange
Red

Yellow
Orange
Red</class> 
```

### 程序 2

```py
 Str_list = ['Yellow','Orange','Red']

# Creating a generator using generator expression
gen = (x for x in Str_list)

# Print the type
print(type(gen))

# Iterate over items in generator object and print -1st time 
for item in gen:
    print(item)

# Iterate over items in generator object and print -2nd time 
for item in gen:
    print(item) 

```

**输出:**<samp><class></class></samp>

```py
<class>Yellow
Orange
Red</class> 
```

从上面的代码片段中，您可以观察到以下内容:

1.  在这两种情况下，我们都使用相同的列表`Str_list` ，其中包含黄色、橙色和红色等颜色串。
2.  在程序 1 的第二行，我们创建了一个名为 list 的[列表](../python/python-lists)对象，而在程序 2 中，我们创建了一个名为 **gen** 的生成器对象。
    *   当你仔细观察时，你可以发现**第一个区别**，即创建列表时使用方括号，而创建生成器时我们使用括号或圆括号。
3.  第三，我们尝试检查创建的对象类型并打印它们。所以我们会得到列表对象的`<class></class>`和生成器对象的`<class></class>`。
4.  在第四步中，在 for 循环的帮助下，我们遍历列表对象和生成器对象中的每一项，并打印出相应的结果。两者显然产生相同的结果。
    *   **第二个主要区别**在于列表和生成器在内存中保存项目的方式。List 一次将所有项目存储在内存中，而 generator 不会一次存储所有项目，而是一个接一个地创建项目，并在存储项目状态时显示它，在下一次调用时，它会从内存中删除上一个项目。
    *   为了验证这一点，我们可以使用`len()`方法来检查我们创建的列表和生成器的长度。`len(list)`会给你 3 个结果，因为列表包含 3 个项目，但是`len(gen)`会抛出一个类型错误，说明生成器对象没有长度。
5.  最后，我们尝试迭代并打印列表和生成器。
    *   令人惊讶的是，这导致了**第三个区别** -迭代可以在一个列表上尽可能多次执行，另一方面，在一个生成器上的迭代被限制为一次。

## 使用关键字产量创建生成器

关键字产量在构建 python 中的生成器函数时起着至关重要的作用。包含关键字 yield 的语句称为 yield 语句。生成器函数中的 yield 语句用于控制函数的执行流程，就像普通函数中的 return 语句一样。

为了更清楚，让我们使用 yield 创建一个生成器函数来打印颜色列表。

```py
colours = ["Yellow", "Orange", "Red"]

def print_colours(colours):
 for c in colours:
  yield c

colour_generator = print_colours(colours)

for c in colour_generator:
 print(c) 

```

**输出:**

```py
Yellow
Orange
Red 
```

在上面的代码片段中，我们在 yield 语句的帮助下创建了一个生成器函数 print _ colours。colour _ generator 是生成器函数的对象，它存储由生成器函数返回的名为 generator 的特殊迭代器。要打印生成器中的元素，我们必须使用 loops 或`next()`函数，这里我们使用“for loop”，因此生成器中的所有值都会同时列出。

## 发电机功能与正常功能有何不同

在讨论差异之前，检查以下代码以打印颜色列表:

### 正常功能

```py
clr_list =["Yellow", "Orange", "Red"]

def print_colours(clrs):

    for c in clrs:
        return c

C_List = print_colours(clr_list)

print(C_List) 

```

**输出:**

```py
['Yellow', 'Orange', 'Red'] 
```

### 发电机功能

```py
clr_list =["Yellow", "Orange", "Red"]
def print_colours(clrs):

    for c in clrs:
        yield c

C_gen = print_colours(clr_list)

print(C_gen)
print(next(C_gen))
print(next(C_gen))
print(next(C_gen))
print(next(C_gen)) 

```

**输出:**<samp><generator at="" object="" print_colours=""></generator></samp>

```py
<generator at="" object="" print_colours="">Yellow
Orange
Red
Traceback (most recent call last):
  File "gen_ex.py", line 62, in <module>print(next(C_gen))
StopIteration</module></generator> 
```

当您观察这两个代码片段时，您将看到以下发现。

*   生成器函数在函数 print _ `colors()`中包含 yield 语句，而普通函数在函数 print _ `colors()`中包含 return 语句。
*   在函数调用时，生成器函数返回生成器，而普通函数返回列表。
*   return 和 yield 语句都用于控制执行流程，关键区别在于:
    *   return 语句将通过返回列表中的完整值来终止整个函数。
    *   yield 语句将只通过返回 yield 值来暂停函数。
*   C_List 包含完整的列表，而 C_gen 包含称为生成器的特殊迭代器。这可以通过打印它们来验证
    *   当执行 print(C_List)语句时，我们得到整个列表[“黄色”、“橙色”、“红色”]，而当执行 print(C_gen)时，我们得到输出<generator object="" print_colours="" at="">。这意味着列表中没有元素存储在内存中，只有一个迭代器被创建。</generator>
*   在生成器函数中，我们需要像`next()`这样的特殊方法来激活函数的执行，而普通函数不需要。
    *   当遇到下一个()函数时，生成器函数 print _ colours 将开始执行，直到遇到 yield 语句。
    *   yield 语句将向调用方返回 yield 值，同时暂停函数的执行。yield 语句将始终保存该函数的状态，因此不会迭代已经访问过的元素。
    *   这将重复进行，直到下一个()函数在列表中没有元素时抛出一个 StopIteration 异常。
    *   在上面的例子中，您可以看到我们已经使用了`next()`函数 4 次，而列表只包含 3 个元素，因此前三个`next()`函数返回 3 个元素(黄色、橙色和红色)，第四个`next()`函数引发 StopIteration 异常。

## 生成器函数和 for 循环

现在我们非常熟悉发电机以及它在幕后是如何工作的。使用`next()`功能并不是一个公平的做法，因为我们需要多次提及。循环可以重写`next()`函数，因为它更方便。请参见下面的示例来反转列表。

```py
# generator to reverse a list
def reverse_list(clr_list):
    length = len(clr_list)
    for i in range(length-1, -1, -1):
        yield clr_list[i]

# using for loop to reverse the list
for list in reverse_list(["Yellow", "Orange", "Red"]):
    print(list) 

```

**输出:**

```py
Red
Orange
Yellow 
```

在此脚本中，执行从调用循环中的生成器函数 reverse_list 开始。生成器功能将借助`range()`功能反转给定列表。for 循环中的`range()`函数用于以相反的顺序获取列表的索引。因此，我们以相反的顺序产生列表元素。因为函数调用是在 for 循环中编写的，所以它会一直执行到遇到最后一个元素。

注意:Python 生成器适用于所有 iterables。

## 使用发电机的优势

使用发电机的两个主要优点是:

*   与[迭代器相比](../python/iterators)生成器**效率更高，更容易用几行代码实现**。
*   由于生成器使用虚拟空间来存储函数的状态，因此当涉及到大数据集时，我们可以说生成器是**内存高效的**。