# Python 闭包

> 哎哎哎:# t0]https://learnetauthorities . com/python/closures

在本 python 教程中，您将了解关于闭包的一切，闭包是函数式编程中的重要工具之一。您将看到 python 中有哪些闭包，它们是如何实现的，以及使用闭包的好处。首先，您将掌握嵌套函数和非局部变量的概念，它们是实现闭包的基本构造。

## 具有非局部变量的嵌套函数

简单来说，嵌套函数是在另一个函数中定义的函数。内部定义的函数称为**内部函数**，包围内部函数的函数称为**外部函数**。

以下是嵌套函数的示例

```py
def OuterFunction(msg): 

                def Innerfunction():  
                                print(msg)
                InnerFunction() 

OuterFunction('Welcome to Learn eTutorials') 

```

在上面的代码片段中，我们定义了一个`OuterFunction`，它接受一些文本或消息，这里是`msg`作为参数。我们还在`OuterFunction`内部定义了另一个函数，并将其命名为`InnerFunction`。`InnerFunction`打印了`msg`，我们在`OuterFunction`中将其作为参数通过。最后我们从`OuterFunction`的范围调用了内部函数。本质上，`OuterFunction`封闭了`InnerFunction`，因此也被称为封闭函数，而内部函数是外部函数的局部函数，因此也被称为嵌套函数。

上述代码的调用顺序总是从调用`OuterFunction(‘Learn eTutorial!!!’)`的主函数开始，主函数将控制转移到遇到函数调用`InnerFunction()`的函数`OuterFunction(msg)`。函数调用序列可以最好地可视化如下:

![Calling Sequence of nested function](img/f59a703af9bb7437266a5146074684f3.png)

### 嵌套函数的调用序列

当一个函数在另一个函数中声明时，就会发生函数嵌套。嵌套可以在任何级别进行，但是增加级别会导致很高的复杂性。

## 非局部变量

在上面的代码中,“msg”是唯一声明的变量。从我们前面的内容中，我们知道变量可以根据函数或程序中存在的变量的范围和生存期在函数中声明为全局变量或局部变量。在整个程序中有生命的变量被称为[全局变量](../python/identifiers-variables)，而那些范围被限制在一个函数内的变量被称为[局部变量](../python/identifiers-variables)。但是还有第三种变体叫做非局部变量，它主要用于 python 中的嵌套函数。

![Non Local Variables](img/732c0b41ad1f88267468a74de3768238.png)

当一个变量被定义在一个封闭函数中时，它被称为对其嵌套函数具有非局部作用域。这类变量被称为非局部变量。定义非局部变量的函数及其所有嵌套函数都可以访问非局部变量。

前一个代码片段的非局部变量的范围可以最好地可视化如下:

![Non Local Variables](img/51e455137a4f43baac17dd6464159f42.png)

这里，变量`msg`是这个程序中唯一声明的变量。`msg`是全局变量还是局部变量或非局部变量？。

*   `msg`不是全局变量，因为它没有在 main 函数中声明，也没有全局关键字。
*   由于`msg`是在封闭函数中声明的，这里`OuterFunction()`,“msg”是其封闭函数的局部变量。
*   但是你可以看到`msg`可以被嵌套函数`InnerFunction()`访问。那么，我们能声称‘msg’是一个局部变量吗？答案是否定的。这里的“msg”是其嵌套函数的非局部变量。

现在让我们看看如何通过对前面的代码片段进行一些更改来区分局部变量和非局部变量。

### 示例:局部变量与非局部变量

```py
def OuterFunction(): 
    msg = 'Welcome to Learn eTutorials' #Local Variable

    def InnerFunction(): # Nested Function

        msg = 'PYTHON' # Non Local Variable
        print('Inner: ',msg)

    InnerFunction() 
    print('Outer: ',x)           

OuterFunction() # Main Function 

```

请记住，封闭函数的局部变量对于其内部函数来说是非局部的，对内部函数中的“msg”所做的任何更改都不会反映到外部函数中的“msg”上。

**输出:**

```py
Inner:  PYTHON
Outer:  Welcome to Learn eTutorials 
```

从上面的输出可以清楚地看出，函数`InnerFunction()`可以访问变量“msg”，但不能更改它们。内部函数刚刚用新值重新分配了变量。这意味着在嵌套函数中创建了一个同名的新局部变量。

### 如何修改非局部变量？

要修改非局部变量，我们必须用关键字 nonlocal 显式声明它。通过这种方式，我们可以很容易地识别一个非局部变量。让我们看看非本地关键字的重要性，以及如果我们使用它们，我们以前的代码会发生什么变化。

### 示例:非本地变量

```py
def OuterFunction(): #Enclosed Function
    msg = 'Welcome to Learn eTutorials' #Local Variable

    def InnerFunction(): # Nested Function

        nonlocal msg 
        msg = 'PYTHON' # Non Local Variable
        print('Inner: ',msg)

    InnerFunction() 

OuterFunction() # Main Function 

```

这里，在这个例子中，我们在内部函数 inner `function()`中用关键字 non-local 显式地声明了 msg，并为其分配了一个字符串值。嵌套函数中对 msg 的修改也反映在封闭函数中。

**输出:**

```py
Inner:  PYTHON
Outer:  PYTHON 
```

从输出来看，很明显变量 msg 既不是全局变量，也不是局部变量。

### python 中的闭包

现在我们可以了解 python 中的闭包了。为此，我们可以考虑前面的嵌套函数示例，让我们看看嵌套函数到闭包的转换。

为了将嵌套函数转换成闭包，我们只需要**返回嵌套函数，而不需要括号**。闭包函数的结构如下所示。

![Python Closure Strucuture](img/d96e01d7eb7aef5e5df25c78c60848ec.png)

### 封闭结构

当一个函数的返回值依赖于在函数外部声明的一个或多个变量的值时，那么这个函数被称为闭包函数。在上面的例子中，InnerFunction 的返回值依赖于在 InnerFunction 外部声明的“msg”变量

## 闭包的重要特性

### 闭包将数据与代码绑定在一起

python 中闭包的首要特性是闭包用代码封装数据。闭包名称背后的事实是，它绑定了内部函数代码中的非本地数据。

在上面的代码中，返回 InnerFunction 语句不仅仅是返回任何值；相反，当调用外部函数时，它会返回函数本身。因此需要变量声明来存储这个函数。

在我们的例子中，我们已经声明了一个新的变量`get`，它存储了由`OuterFunciton`返回的`InnerFunction`。由于`get`包含函数，我们可以使用`get`作为函数，并且可以调用函数作为`get()`。由于 InnerFunction 没有任何参数，因此我们不需要在`get()`中传递任何参数。

### 示例:关闭

```py
def OuterFunction(msg): 

    def InnerFunction():  
        print('Inner: ',msg)
    return InnerFunction

get = OuterFunction('Welcome to Learn eTutorials') 

print(get)

print(get()) 

```

现在，当我们运行上面的代码时，我们会得到下面的输出:

**输出:**

```py
<function outerfunction.="">.InnerFunction at 0x01DF6148>
Inner:  Welcome to Learn eTutorials
None</function> 
```

从输出中可以清楚地看到，`get()`作为一个函数工作，并打印绑定到代码的数据。

### 闭包记住它的上下文

闭包可以定义为一个函数对象，它存储封闭范围内的非局部变量，而不管它是否在内存中。

### 示例:关闭

```py
def OuterFunction(msg): 

    def InnerFunction():  
        print('Inner: ',msg)
    return InnerFunction

get = OuterFunction('Welcome to Learn eTutorials') 

del OuterFunction
OuterFunction('Welcome to Learn eTutorials') 

```

在这段代码中，外部函数是使用关键字 del 删除的封闭范围。删除后不久，我们尝试再次调用外部函数。产出会是什么？

很明显，python 编译器会引发一个名称错误，声明外部函数没有定义，如下所示。

**输出误差:**

```py
OuterFunction('Welcome to Learn eTutorials')
NameError: name 'OuterFunction' is not defined 
```

它神奇的记忆能力带来了结束的力量。

### 示例:关闭

```py
def OuterFunction(msg): 

    def InnerFunction():  
        print('Inner: ',msg)
    return InnerFunction

get = OuterFunction('Welcome to Learn eTutorials') 

del OuterFunction
get() 

```

**输出:**

```py
Inner:  Welcome to Learn eTutorials 
```

这意味着，即使外部函数被删除，变量“get”也会记住内部函数的某些状态。

## 带参数的闭包

为了更好地理解闭包，让我们再看一个例子，它为 InnerFuction 提供了一个参数。到目前为止，我们还没有向 InnerFunction 传递任何参数。

### 示例:使用闭包求一个数的 n 次方

```py
def n_pow(exp):
    def pow_of(base):
        return pow(base,exp)
    return pow_of

 sec
print(second_pow(3))
print(second_pow(4))
print(second_pow(5))
print("\n")

third_pow = n_pow(3)
print(third_pow(3))
print(third_pow(4))
print(third_pow(5))
print("\n")

fifth_pow =n_pow(5)
print(fifth_pow(2))
print(fifth_pow(3)) 

```

**输出:**

```py
9
16
25

27
64
125

32
243 
```

在这个例子中，我们有一个名为`n_pow`的外部函数，它传递一个名为`exp`的参数。我们还在`n_pow`中定义了一个函数`pow_of`，这个函数也接受一个参数`base`。`pow_of`函数是外部函数`n_pow`的局部或嵌套函数，它返回我们在这里传递的任何参数的幂。需要注意的重要一点是，参数 exp 在封闭范围内。最后，外部函数返回没有括号的内部函数，这使得该函数成为一个闭包。

变量`second_pow`存储函数调用时内部函数的状态，2 作为参数传递。现在指数的值变成了 2。所以每当我们对任何一个数调用`second_pow`函数时，它都会产生那个基数的平方。这里`second_pow(3)`在内部函数中传递 3 作为基的参数，函数返回 3 的平方，即 9。类似地，函数调用中的`third_pow`变量将给出指定数字的立方，如示例所示。

## 使用闭包的好处

*   闭包是类的完美替代品，尤其是当类只有一个方法或很少方法时。
*   闭包有助于减少全局变量的使用
*   闭包用作回调函数，从而在某种程度上提供数据隐藏。
*   闭包用于替换硬编码的常数
*   [python 装饰者](../python/decorators)广泛使用闭包，您将在接下来的教程中了解到这一点。
*   闭包被用来解决数学函数，如组合、局部应用、currying 等。