# Python `@Property`装饰器

> 原文：<https://learnetutorials.com/python/property>

在本教程中，您将借助简单易举的例子，了解`@Property`装饰器，何时以及如何在 python 中使用`@Property`装饰器。
从我们之前的教程中，我们知道装饰器的主要目的是修改函数或类属性的行为，使得类的用户不必进行任何更改。我们在上一个教程中讨论的装饰者是用户定义的装饰者。为了使装饰更加简单，python 有三个基本的内置装饰器，如@classmethod、@staticmethod 和@property method。在本教程中，我们将关注 Python @ property 装饰器。

## 什么是@物业装饰师？

**属性装饰器`@Property`装饰器 基本上是一个内置的装饰器，它的主要目的之一是使用类方法作为属性，尽管它是一个带有括号()**的方法。

让我们通过创建一个名为`License`的类来尝试理解这一点。我们的`License`类包含`name`、`age`和`data`作为属性。

```py
 class License:

    def __init__(self,name,age):
        self.name=name
        self.age=age
        self.data = '{} is {} years old'.format(self.name,self.age) 

```

现在我们已经创建了类，下一步是我们想要为类 License 创建一个实例。这里是有两个值的实例，并借助点运算符(。)我们可以访问类中的属性值，如下所示。

现在我们已经创建了类，下一步是我们想要为类 License 创建一个实例。这里是有两个值的实例，并借助点运算符(。)我们可以访问类中的属性值，如下所示。

```py
 L = License('Tom',25)
print(L.name)
print(L.age)
print(L.data) 

```

**输出:**

```py
 Tom
25
Tom is 25 years old 
```

当您观察代码片段时，您可以看到`self.name`和`self.age`是主要属性，而`self.data`是派生属性。

## 何时使用@ property

假设在某个阶段，您希望更改类中任何属性的值，预计您所做的更改将反映在程序中您使用该属性的任何地方(已更改)。但实际上，这种情况并没有发生。

在我们的例子中，假设您希望在实例化后更改`age`，为此，我们为`L.age`分配`15`，如下所示。

```py
 L = License('Tom',25)
print(L.name)

L.age = 15  #assigned new age
print(L.age)
print(L.data) 

```

实际上，预期产量会是这样的:`L.age`为`15`，`L.data`为`Tom is 15` 岁。但是我们得到的结果是:

```py
 Tom
15
Tom is 25 years old 
```

在这里，你可以看到年龄属性变为 15。而是自我的年龄。数据属性保持不变，不会被更新。
**这个问题背后的原因是在类中，如果你改变一个属性的值，从那个类派生的其他属性不会自动更新。**

因此，如果对类所做的更改不会在其派生类中自动更新，则破解代码的几率很高。

那么我们如何解决这个问题呢？

## 属性到方法的转换

解决这个问题的一种方法是将类中的 `self.data`属性转换为方法`getdata()`，如下例所示。

```py
 class License:

    def __init__(self,name,age):
        self.name=name
        self.age=age

    def getdata(self):
        return '{} is {} years old'.format(self.name,self.age ) 

```

现在，该类已经通过移除属性和添加新方法进行了修改。所以实际上，我们的类现在没有名为`self.data`的属性，尽管如此，我们有一个方法`getdata()`。

由于`getdata()`是一个方法，我们在调用这个方法的时候要小心。因为如果我们调用如下所示的不带括号的方法，我们将会导致属性错误。

```py
 L = License('Tom',25)   # Instance 
print(L.name)

L.age = 15
print(L.age)
print(L.getdata)   # missing parantheses,getdata is a method not an attribute 

```

您收到的输出如下所示:

```py
 Tom
15
<bound method License.getdata of <__main__.License object at 0x038CB580>> 
```

所以整个程序应该是这样的:

```py
 class License:

    def __init__(self,name,age):
        self.name=name
        self.age=age

    def getdata(self):
        return '{} is {} years old'.format(self.name,self.age )
L = License('Tom',25)
print(L.name)

L.age = 15
print(L.age)
print(L.getdata())  #calling method 

```

**输出:**

```py
 Tom
15
Tom is 15 years old 
```

简而言之，所有实现上述类的程序在遇到带有`getdata()`的`self.data`时都必须修改它们的代码。如果客户端代码有成百上千行，那么肯定会很麻烦。

## 使用`@Property`装饰器 解决

所以 python 提供的完美解决方案是将方法转换为属性。这可以通过在方法定义之前添加一个**@属性**装饰器来实现，该装饰器允许将方法用作属性。因此，`getdata()`方法可以作为属性来访问，而不是使用()的方法。下面的示例说明了@属性的用法。

```py
 class License:

    def __init__(self,name,age):
        self.name=name
        self.age=age

    @property 
    def getdata(self):
        return '{} is {} years old'.format(self.name,self.age )

L = License('Tom',25)
print(L.name)

L.age = 15
print(L.age)
print(L.getdata)  #calling method as attribute 

```

这段代码片段将给出相同的输出，但是在这里您可以看到，我们在调用用@propertyi.e `getdata()`修饰的方法时删除了括号()。因为通过使用@property，`getdata()`方法作为属性被访问，从而使我们的代码能够与客户端代码松散耦合。上面代码中的以下序列通常称为 getter 方法，用于检索属性中的值。

```py
 @property 
    def getdata(self):
        return '{} is {} years old'.format(self.name,self.age ) 

```

## 设置方法

像 getter 方法一样，在 python 中，我们有一个 setter 方法，用于为类中的属性设置值，从而确保数据封装的原则。
在定义设置器方法时，您需要遵循下面列出的一些规则:

*   setter 方法的语法是`@{methodname}.setter`
*   setter 和 getter 方法的名称应该相同
*   用户设置的值在 setter 方法中始终被接受为参数。

假设我们的客户希望在他达到 18 岁时改变他的年龄，为了从客户端实现这一需求，我们需要向我们的类灌输 setter 方法属性，从而在不知不觉中帮助客户。我们的计划也将发生如下变化:

```py
 class License:

    def __init__(self,name,age):
        self.name=name
        self.__age=age

    @property 
    def getdata(self):
        return self.name,self.__age

    @getdata.setter
    def getdata(self,age):
        if age < 18:
            print('Sorry {}, You are ineligible for License.'.format(self.name))
            self.__age=age
        else:
            print('Congrats {},You are eligible for License'.format(self.name))
            self.__age=age

L1 = License('Tom',25)
print('Before setting',L1.getdata)

L1.getdata=15 #age set to 15
print('After setting values changed to',L1.getdata)

print('-'*30)

L2 = License('Chris',17)
print('Before setting',L2.getdata)

L2.getdata=18 #age set to 18
print('After setting values changed to',L2.getdata) 

```

**输出:**

```py
 Before setting ('Tom', 25)
Sorry Tom, You are ineligible for License.
After setting values changed to ('Tom', 15)
------------------------------
Before setting ('Chris', 17)
Congrats Chris,You are eligible for License
After setting values changed to ('Chris', 18) 
```

在这个程序中，我们添加了验证年龄的 setter 方法。通过检查`age`是否低于 18。如果年龄低于 18 岁，班级将打印信息，说明此人没有资格获得许可证，如果年龄高于 18 岁，则此人有资格获得许可证。

语句`self._age = age`将客户端给定的更新时间设置为私有属性，从而提供数据隐藏功能。在我们的输出中，您可以观察到最初汤姆的年龄是 25 岁，后来客户将年龄设置为 15 岁。这同样反映在我们的私人属性上。

因此，现在我们的类将在对基本属性进行更改时自动更新派生属性，反之亦然。

## deleter 方法

与@property 关联的另一个方法是**删除器方法**，用于从内存中删除属性。

让我们对 getdata 实现 deleter 方法。和 setter 方法一样，实现 deleter 的特殊语法是`@{methodname}.setter`，应该在 deleter 方法之前提到。删除器方法的名称应与适用于`@decorator`的方法相同。

这里我们计划从内存中删除不需要的数据。在我们的案例中，我们正在删除没有资格获得许可证的人员的数据。现在，在前面的示例中，我们添加了 deleter 方法，如下例所示

```py
 class License:

    def __init__(self,name,age):
        self.name=name
        self.__age=age

    @property 
    def getdata(self):
        return self.name,self.__age

    @getdata.setter
    def getdata(self,age):
        if age < 18:
            print('Sorry {}, You are ineligible for License.'.format(self.name))
            self.__age=age
        else:
            print('Congrats {},You are eligible for License'.format(self.name))
            self.__age=age

    @getdata.deleter
    def getdata(self):
        del self.name
        self.__age=None

L1 = License('Tom',25)
L2 = License('Chris',35)

print('Deleting....')
print(L1.getdata)
del L1.getdata

print(L2.name)
print(L1.age) 

```

这里我们定义了删除器方法，用`del`关键字删除`name`属性，另一种删除属性的方法是用`None`分配属性`age`。

使用`del`关键字，我们删除了我们的一个实例`L1`，为了确认删除，我们尝试在该实例中打印`age`。以下输出将消除所有疑虑。

```py
 Deleting....
('Tom', 25)
Chris
Traceback (most recent call last):
  File "C:\Users\TP-E540\Desktop\PY PRO\atpro_ex.py", line 188, in <module>print(L1.age)
AttributeError: 'License' object has no attribute 'age'</module> 
```

## 属性函数

在 python 中，我们有`property()`函数，可以用来代替@ property decorator。`property()`函数是一个内置函数，它在 getter、setter 和 deleter 前面返回一个属性属性。

语法
`property()`的语法是

```py
 property(fget=None, fset=None, fdel=None, doc=None) 

```

哪里，

*   **fget()** :是用来获取属性值的函数
*   **fset()** :是用来给属性设置值的函数
*   **fdel()** :是用来删除属性值的函数
*   **文档**:是用于属性文档的字符串

这四个函数参数是可选的。因此我们也可以创建一个简单的属性对象作为`property()`。

下面给出了一个简单的示例说明:

```py
 class License:
    def __init__(self, name,age):
        self._name = name
        self._age = age

    def get_name(self):
        print('Getting name and age')
        return self._name ,self._age

    def set_name(self, val):
        print('Setting name to ', val)
        self._name = val

    def del_name(self):
        print('Deleting name and age')
        self._name = None
        self._age = None

    # Set property to use get_name, set_name
    # and del_name methods
    name = property(get_name, set_name, del_name, 'Data property')

L = License('Tom',25)
print(L.name)
L.name = 'Jerry'
del L.name 

```

**输出:**

```py
 Getting name and age
('Tom', 25)
Setting name to  Jerry
Deleting name and age 
```