# Python `min()`

> 原文：<https://learnetutorials.com/python/methods/min>

内置函数`min()`有助于返回给定 iterable 中的最小元素。也可以在两个或多个参数之间找到最小的元素。

```py
 # to find the smallest item in an iterable
**min(iterable, *iterables, key, default)** 

```

```py
 # to find the smallest item between two or more objects
**min(arg1, arg2, *args, key)** 

```

## 最小()参数:

带有 iterable 的`min()`函数具有以下参数。

**分钟(可重复，*可重复，键，默认)**

| 参数 | 描述 | 必需/可选 |
| --- | --- | --- |
| 可迭代的 | 诸如列表、元组、集合、字典等可条目。 | 需要 |
| *可重复 | 任意数量的可滴定物；可以不止一个 | 可选择的 |
| 键 | 传递数据项并进行比较的一种关键功能 | 可选择的 |
| 系统默认值 | 如果给定的 iterable 为空，则为默认值 | 可选择的 |

不带`iterable()`的`iterable()`函数有以下参数。

【t0 min(arg1、arg2、*args、键)】的缩写

| 参数 | 描述 | 必需/可选 |
| --- | --- | --- |
| arg1 | 一个对象；可以是数字、字符串等 | 需要 |
| arg2 | 一个对象；可以是数字、字符串等 | 需要 |
| *参数 | 任意数量的对象 | 可选择的 |
| 键 | 传递每个参数并进行比较的一个关键函数 | 可选择的 |

## 最小()返回值

在传递空迭代器的情况下，它会引发 ValueError 异常。为了避免这种情况，我们可以传递默认参数。
如果我们传递多个迭代器，那么从给定的迭代器中返回最小的项。

| 投入 | 返回值 |
| 整数 | 最小整数 |
| 线 | 具有最小 Unicode 值的字符 |

## Python 中`min()`方法的示例

### 示例 1:获取列表中最小的项目

```py
 number = [13, 2, 8, 25, 10, 46]
smallest_number = min(number);

print("The smallest number is:", smallest_number)
Output 

```

**输出:**

```py
The smallest number is: 2 
```

### 示例 2:列表中最小的字符串

```py
 languages = ["Python", "C Programming", "Java", "JavaScript"]
smallest_string = min(languages);

print("The smallest string is:", smallest_string) 

```

**输出:**

```py
The smallest string is: C Programming 
```

### 示例 3:在字典中查找`min()`

```py
 square = {2: 4, 3: 9, -1: 1, -2: 4}

# the smallest key
key1 = min(square)
print("The smallest key:", key1)    # -2

# the key whose value is the smallest
key2 = min(square, key = lambda k: square[k])

print("The key with the smallest value:", key2)    # -1

# getting the smallest value
print("The smallest value:", square[key2])    # 1 

```

**输出:**

```py
TThe smallest key: -2
The key with the smallest value: -1
The smallest value: 1 
```

### 例 4:在给定的数字中找出最小值

```py
 result = min(4, -5, 23, 5)
print("The minimum number is:", result) 

```

**输出:**

```py
The minimum number is -5 
```

### 示例 5:查找对象的最小值()

```py
 class Data:
    id = 0

    def __init__(self, i):
        self.id = i

    def __str__(self):
        return 'Data[%s]' % self.id

def get_data_id(data):
    return data.id

# min() with objects and key argument
list_objects = [Data(1), Data(2), Data(-10)]

print(min(list_objects, key=get_data_id)) 

```

**输出:**

```py
Data[-10] 
```