# R 中的输入和输出

> 原文：<https://learnetutorials.com/r-programming/input-output-functions>

在本教程中，您将熟悉基本的输入和输出功能。

## 如何在 R 中接受用户的输入？

在 R 语言中，来自用户的输入通过两种方法从控制台获取。他们是

1.  `readline()`功能:以字符串形式接受用户输入。
2.  `scan()`功能:从用户控制台或文件读取数据

## R 中的`readline()`是什么？

`readline()`函数从用户控制台获取或读取字符串格式的输入。

### `readline()`的语法

```r
 <variable_name>  <- readline()
<variable_name>  <- as.integer(<variable_name>) 

```

`readline()`以字符或字符串形式从用户处获取输入，并将其分配给任何声明的数据类型的变量。下一行`as. integer()`方法**根据预定义的变量数据类型，将`readline()`方法读取的字符串数据类型转换为整数**类型或任何其他类型。然后将转换后的值赋给一个变量。

### `readline()`示例

```r
 a <- readline()
a <- as.integer(a) 

```

在给定的示例中，变量声明为。方法`readline()`读取输入，将其转换为整数数据类型，并将值存储到变量 a 中

### 使用`readline()`读取用户输入的程序

```r
 # Program to read input from user using readline()

#  readline() reads input from user console

a = readline();

# convert the inputted value to integer
a = as.integer(a);

# print the value
print(a) 

```

**输出:**

```r
 5
[1] 5 
```

### 有哪些函数用于转换字符串数据类型的变量？

下表给出了将字符串数据类型的变量转换为相应数据类型(如整数、浮点、复数等)的一些函数。a 是一个变量。

| 转换类型 | 使用 |
| 整数(a) | 获取从字符串转换为整数的 |
| s.numeric(a) | 从字符串转换为数字类型。 |
| 复杂的 | a 被转换成复数 |
| 作为。日期(a) | a 被转换为日期 |

注意:R 中没有字符串类型转换，因为 readline 以字符串格式从控制台获取输入或读取数据。

### 显示转换的程序

```r
 # Program to read input from user using readline()

#  readline() reads input from user console as string
a = readline("Enter a value of floating type :")   #4.3
b = readline("Enter a value of complex type :")   #4+2i

# convert the inputted value to float ,complex
a = as.numeric(a)
b = as.complex(b)

# print the value
print(a)
print(b) 

```

**输出:**

```r
 Enter a value of floating type :4.5
Enter a value of complex type :4+2i
[1] 4.5
[1] 4+2i 
```

## R 中的`prompt()`函数是什么？

`prompt()`函数是一个内置函数，它在控制台中显示文本消息，用户可以在其中阅读消息并执行相应的操作。

### 提示的语法()

```r
 <variable_name>  <- readline(prompt = “              “)
<variable_name>  <- as.integer(<variable_name>) 

```

### 例子

```r
 a <- readline(prompt = "Enter value of a : ")
a <- as.integer(a) 

```

变量 **a** 通过`readline()`方法赋值。`readline()` 方法从用户控制台或屏幕读取数据。您可以看到突出显示的部分( **prompt =“输入值 a:“**)。`prompt()`函数将引号内的给定字符串打印到用户控制台中。用户可以看到输入值为的消息，用户将输入相应的数字。读取到 a 的数字是字符串类型，在下一行使用 **as.integer(a)** 转换为整数类型，并存储在 **a** 本身。

同样，在下面的程序中读取变量 b。执行加法操作，并使用`cat()`功能将值输出到控制台。

### 使用`readline()`和`readline()`从用户处获取输入的程序

```r
 a <- readline(prompt = "Enter value of a : ")
a <- as.integer(a)

b <- readline(prompt = "Enter value of b :  ")
b<- as.integer(b)

add = a + b
cat("The sum after addition is ",add) 

```

**输出:**

```r
 Enter value of a : 6
Enter value of b :  6
The sum after addition is  12 
```

## R 中的`scan()`函数是什么？

在 R 程序中`scan()`功能是从用户控制台读取数据或输入的内置功能。

### 使用扫描()进行编程

```r
 # R program to illustrate
# taking input from the user

# taking input using scan()
A = scan()
B = scan(what = " ")
c = scan(what = character())

# print the inputted values
print(A) #integer
print(B) # string
print(c) # character 

```

**输出:**

```r
 1: 4 5 6 7
5: 8 9 10 11
9: 
Read 8 items
1: hello welcome to Rlanguage
1: hello welcome to Rlanguage
5: enjoy learning
7: 
Read 6 items
1: 
Read 0 items
[1]  4  5  6  7  8  9 10 11
[1] "hello"     "welcome"   "to"        "Rlanguage" "enjoy"     "learning" 
character(0) 
```

## R 中的输出函数

r 程序支持向用户控制台或屏幕显示输出的内置功能。他们是

1.  打印()
2.  cat()

在 R 中，`print()`和 cat 功能在向用户控制台显示内容方面具有几乎相似的功能。也就是说，`print()`和`print()`充当为用户提供相应输出的函数。

### 打印语法()

```r
 print(arguments)                     #print arguments to console 

```

### `cat()`的语法

```r
 cat(any_text)                              #print text to console 

```

### 在 R 中使用`print()`和`print()`进行编程

```r
 language <- "R programming language"    #created a string language
print(language)                         #Apply print to character string language

cat(language)                           #Apply cat to character string 

```

**输出:**

```r
 [1] "R programming language"
R programming language 
```

**注**:

**print()** 函数将传递给函数的对象或字符向量返回到控制台。

**cat()** 函数返回字符串或打印不带引号的参数，`cat()`函数只是向屏幕或控制台显示内容(文本)。