# 计算机网络中的 OSI 模型层和协议

> 原文：<https://learnetutorials.com/cyber-security/osi-model-layers>

正如我们所知，计算机通过彼此连接，形成了一个计算机网络。网络中的通信和数据传输是通过使用数据包进行的。数据包具有报头和数据部分，其中报头包含发送方和接收方信息，数据部分包含数据。发送和接收这些数据包时包含许多协议和层。

OSI 或开放系统互连模型，可称为描述这些层和协议的参考模型，与发送和接收数据包相关联。它从这样一个问题开始:一台计算机的应用程序如何通过物理层向另一台计算机的应用程序发送和接收数据包。

OSI 模型是由 ISO 组织在 1984 年开发的，它由七层组成，每一层都是独立的，在发送和接收数据包时都有自己的功能。

## 为什么需要 OSI 模型？

它有许多不同的点描述了网络中参考模型的需求，这些点是

1.  易于学习和理解各层功能
2.  易于维护和排除功能故障
3.  易于添加开发的新技术
4.  能够检查各层功能的比较。

## OSI 模型的特点

OSI 模型是网络中的国际模型，因此必须按照国际准则制作。

每一层在功能上都必须是独立的，这样一层中的更改就不会影响另一层中的更改。

在不同的层做不同的功能，同一层不应该有不同的功能。也不要做太多的层来使架构变得复杂。

OSI 模型中的总层分为两层，即应用层(上层)和其他网络层(下层)。

应用层靠近用户或应用程序，它处理所有与应用程序相关的问题。应用层主要是处理或通信网络系统中运行的应用程序。

![layers ](img/26a5b51cc0a5d845f34439de98fdf5d9.png)

OSI 模型的较低层设计有数据传输的网络和物理介质。物理层是 OSI 模型的低端，处理所有物理介质问题。

## OSI 模型的历史

它始于 1970 年，当时国际标准化组织举办了一个研讨会，制定一些网络国际标准规则

1973 年，在分组交换系统的一次实验中，发现了对更高级协议的需求。

1983 年，第一个 OSI 模型被初步开发出来，但在 1984 年，国际标准化组织接受了 OSI 模型架构。

## OSI 模型层的职责

正如我们所说的，在数据传输中，不同的层是独立的，并被赋予不同的功能。让我们详细研究 OSI 层及其功能，这对了解网络和网络安全至关重要。

## OSI 模型层

![Mlayers ](img/26a5b51cc0a5d845f34439de98fdf5d9.png)

1.  物理层
2.  数据链路层
3.  网路层
4.  传输层
5.  会话层
6.  表示层
7.  应用层

### 物理层

这是 OSI 模型中与数据传输物理介质相关的最低层。物理层不像 OSI 模型中的更高层那样依赖于任何协议。该层负责建立和维护物理介质和系统之间的连接，以进行数据传输。物理层负责定义传输所需的电气和机械规格。

#### 物理层的职责

1.  它帮助我们物理连接一个或多个设备。
2.  它定义了数据在网络中如何从一台设备传输到另一台设备，可以是单工、半双工、全双工
3.  它帮助我们了解网络的拓扑结构，这意味着设备在网络中是如何排列的。
4.  它定义了数据传输中使用的信号类型。

### 数据链路层

这是物理层上的下一层，因此来自物理层的数据进入数据链路层，在此发生数据帧的无差错传输。

数据链路层为数据制定格式，并为网络中设备的数据传输和通信建立协议。

在这一层，我们有一个设备的 IP 地址来标识网络中的每个唯一设备(逻辑寻址)。

为了便于理解数据链路层的功能，它分为两个子层

1.  逻辑链路控制层
2.  媒体访问控制层

#### 逻辑链路控制层

1.  它帮助我们进行流量控制和错误检测
2.  这一层涉及到向接收器的数据包传输。
3.  它检查数据包的报头以找到网络层协议的地址

#### 媒体存取控制

1.  这一层的职责是通过网络传输数据
2.  它帮助我们控制设备如何到达物理介质并传输数据。

#### 数据链路层的功能

1.  **成帧:**这一层负责制作有头部、尾部和数据部分的数据包进行数据传输。
2.  **物理寻址:**数据链路层将地址添加到数据包的报头部分，即接收方地址
3.  **流量控制:**数据发送和接收一定要同速率，可能数据发送速率必须和接收方处理能力匹配，否则数据会被破坏。数据链路层负责维护数据流并检查传输速率。
4.  **差错控制:**数据链路层负责通过 CRC 进行差错校验，即循环冗余校验。该层添加的尾部用于进行错误检查。如果数据不完美，接收器会将确认作为尾部发送，以便重新发送。
5.  **访问控制**:如果有多个设备连接到同一个通道，则有助于我们控制当时拥有控制权的访问。

### 网路层

网络层是 OSI 模型的第三层，位于数据链路层之上。网络层负责正确路由和转发数据。

该层能够找到并定位网络中的设备，并能够在分析网络条件后，使用最佳路由将数据发送到接收器。

在这一层中，我们使用 IP、IPV4 和 IPV6 等协议来正确路由称为网络协议的数据包。

#### 网络层的功能

**寻址:**网络层在数据帧的报头中添加发送方和接收方地址。

**路由:**正如我们所说，路由是一个寻找向接收方发送数据的完美路径的过程。这一层使用不同的路由协议

**网络互联:**它通过给网络中的所有对象一个逻辑连接来构成一个网络

**打包:**通过使用 IP 协议，网络层将其从上层接收的数据包称为打包。

### 传输层

传输层是 OSI 模型的第四层，也被称为 OSI 模型的核心。传输层负责完整无损地发送数据。

这一层确保数据以发送时的完美顺序传输，没有任何重复的内容。

传输层是与发送方和接收方进行端到端连接以确保数据可靠发送的层。

传输层将数据包分成更小的部分，称为数据段。

正如我们所说的，传输层负责端到端连接和数据传输，没有任何丢失或复制。这一层使用两种不同的协议。

1.  三氯苯酚
2.  用户数据报协议(User Datagram Protocol)

#### 传输控制协议:

TCP 是一种协议，有助于通过网络发送数据，并允许网络中的设备进行通信。它建立连接并保持发送方和接收方之间的连接。

#### 如何使用 TCP 协议发送数据？

在 TCP 协议中，数据被分成不同的小部分，我们称之为段；使用最佳路由将这些数据段发送给接收器。不同的路段走不同的路线，到达目的地的顺序也不同。TCP 对它们重新排序以获得正确的数据。

#### 用户数据报协议

UDP 是传输层中使用的另一种协议，但它不是一种可靠的协议，因此它不太像 TCP 那样使用。

UDP 协议的问题是，接收方将没有确认机制来通知发送方数据已正确到达。这种缺乏确认使得这个 UDP 不太可靠。

#### 传输层的功能

**端口寻址:**在一个系统中，多个进程需要向使用不同端口或服务点的浏览器、ftp 等其他系统发送数据。传输层负责将数据从一个进程传输到另一个进程。

传输层添加一个端口地址到达包含发送方和接收方进程地址的数据包，以便它能够正确到达不同计算机的进程。

**分段和重组:**正如我们已经讨论过的，传输层在将数据发送到接收器之前，会将数据分成不同的段，并带有一个序列号。在发送到上层之前，接收器将使用序列号重新组装这些片段。

**连接控制:**传输层可以建立 2 个连接

1.  面向连接:在这种连接中，发送方和接收方的传输层之间将有牢固的连接，数据包通过单一路由传输。
2.  无连接:这里每个包都被认为是一个单独的自由包，它可以通过任何路由到达接收者。

**流量控制:**维持数据包从端到端连接的流量

**错误控制**:使用端到端连接进行错误检查。传输层确保所有数据包都毫无差错地到达接收器。

### 会话层

会话层位于传输层之上，该层与系统上运行的应用程序和进程关系更为密切。

会话层对于建立和维护发送方和接收方应用程序之间的连接和通信非常重要。

会话层负责处理所有的登录及其凭证。

#### 会话层的职责

**同步**:会话层负责在传输数据的同时，在数据中增加一些检查点。这种检查点的用途是，如果在传输过程中发生任何错误或数据丢失，则从该检查点重新发送数据。

**通信控制**:会话层负责允许发送方和接收方系统的两个进程之间的通信。

会话创建、维护和关闭会话。

### 表示层

表示层位于会话层之上，会话层也称为语法层，因为它主要关注传输数据的语法和语义。

表示层是操作系统的一部分，它会将数据从一种格式转换为另一种格式，然后将其发送给接收者，这称为加密。

#### 表示层的功能

**翻译:**发送方和接收方系统可能没有使用相同类型的编码。表示层将数据从源编码格式转换为通用格式，该通用格式由接收者表示层转换回接收者格式。

**加密:**加密是将数据从一种形式转换为另一种形式的处理，以维护数据的隐私和安全。在传输数据时，表示层位于数据加密的后面。

**压缩:**压缩是使数据的发送变得简单一点(减少数据中的比特)的过程，主要用于多媒体传输。表示层负责数据压缩。

### 应用层

这是 OSI 模型中最上面的一层，将作为用户和网络使用过程的接口。这一层的职责包括透明度和资源分配。该层为终端用户使用网络提供服务，例如文件传输、电子邮件、远程登录等。

#### 应用层的功能

**文件传输、访问和管理:**应用层负责允许用户在远程系统中访问文件。还管理另一个系统中的另一个进程并与之交互。

**邮件:**应用层是邮件服务背后要发生的网络

它允许远程登录和使用该系统，并在互联网上提供大量的数据库资源。